/*************************************************************
*  File name: IGCINC.H                                       *
*                                                            *
*  Description:                                              *
*    Data structure declarations for Myriad integration.     *
*                                                            *
**************************************************************/

#ifndef INC_IGCINC_H
#define INC_IGCINC_H

#define MAX_DESCRIPTION_SIZE            (256)
#define MAX_INI_STRING_SIZE             (512)
#define MAX_EXPORT_DELIMITER_SIZE       (128)
#define EXECUTE_SET_RETURN_DATA_SIZE    (256)
#define MAX_PATH_FILENAME               (256)
#define MAX_ISO_STRING_SIZE             (256)
#define MAX_ASSOCIATED_FILE_TYPE        (128)
#define MAX_MENU_TEXT_SIZE              (50)
#define MAX_CHANGEMARK_TEXT_SIZE        (512)
#define AUTHOR_LAYER_NAME_SIZE          (128)  /* Maximum possible layer name size */
#define MAX_ISO_BORDER_LINES            (10)
#define INQUIRE_DESCRIPTION_SIZE        (256)
#define IGC_NOTIFY_CALLBACK_MESSAGE     (WM_USER+10000)
#define INTG_EXECUTE_UNKNOWN_COMMAND    (-1)
#define INTG_EXECUTE_INTERNAL_COMMAND   (-1)

#ifndef IGENUM    
#  ifdef __WIN32
    typedef int IGENUM;
#  else
    typedef long IGENUM;
#  endif
#endif

#ifndef IGINT
#  ifdef __WIN32
    typedef int IGINT;
#  else
    typedef long IGINT;
#  endif
#endif

/* This enumerated type is used to identify the execution command */
typedef enum {INTG_EXECUTE_NOTIFY_RETURN,
              INTG_EXECUTE_SET_NOTIFICATIONS,
              INTG_EXECUTE_ALTERNATEVIEW,
              INTG_EXECUTE_CLIP,
              INTG_EXECUTE_CLOSEALL,
              INTG_EXECUTE_CLOSEMARKUP,
              INTG_EXECUTE_CLOSESESSION,
              INTG_EXECUTE_DELETEITEM,
              INTG_EXECUTE_DISABLEALTVIEW,
              INTG_EXECUTE_FOLDERCLEAR,
              INTG_EXECUTE_INITFOLDERFILE,
              INTG_EXECUTE_LOADFOLDERFILE,
              INTG_EXECUTE_INVERTCOLORS,
              INTG_EXECUTE_LOCKWINDOW,
              INTG_EXECUTE_OPENMARKUP,
              INTG_EXECUTE_PAGE,
              INTG_EXECUTE_PANDISPLACEMENT,
              INTG_EXECUTE_PRINTVIEWPORT,
              INTG_EXECUTE_RASTER,
              INTG_EXECUTE_REPAINT,
              INTG_EXECUTE_ROTATE,
              INTG_EXECUTE_SAVEMARKUP,
              INTG_EXECUTE_SETFRAMEWINDOW,
              INTG_EXECUTE_SETMARKUPCOLOR,
              INTG_EXECUTE_SETRETURNDATA,
              INTG_EXECUTE_TOGGLETOOLBAR,
              INTG_EXECUTE_WINDOW,
              INTG_EXECUTE_ZOOM,
              INTG_EXECUTE_REMOVEMENU,
              INTG_EXECUTE_ENABLEMENUITEM,
              INTG_EXECUTE_ENABLECOLORSEL,
              INTG_EXECUTE_SETAUTHORNAME,
              INTG_EXECUTE_SETLAYERNAME,
              INTG_EXECUTE_GETLAYERINFO,
              INTG_EXECUTE_ENABLEDOCMODIFY,
              INTG_EXECUTE_REDLINETOOL,
              INTG_EXECUTE_AUTHORTOOL,
              INTG_EXECUTE_EYEGLASSTOOL,
              INTG_EXECUTE_BIRDSEYETOOL,
              INTG_EXECUTE_CHANGEMARKTOOL,
              INTG_EXECUTE_SELECTTOOL,
              INTG_EXECUTE_ZOOMTOOL,
              INTG_EXECUTE_PREVIOUSDOC,
              INTG_EXECUTE_NEXTDOC,
              INTG_EXECUTE_MONOCHROME,
              INTG_EXECUTE_REDLINECHANGEMARK,
              INTG_EXECUTE_DOCSTACKTOOL,
              INTG_EXECUTE_SIDEBYSIDE,
              INTG_EXECUTE_SETISOSTRING,
              INTG_EXECUTE_GETISOSTRING,
              INTG_EXECUTE_SET_FOCUS,
              INTG_EXECUTE_ADDUDMENU,
              INTG_EXECUTE_REMOVEUDMENU,
              INTG_EXECUTE_CLEARUDMENU,
              INTG_EXECUTE_ENABLEUDMENU,
              INTG_EXECUTE_SET_ON_TOP,
              INTG_EXECUTE_EXPORT_TO_FILE,
              INTG_EXECUTE_INQUIRE_DOCUMENT,
              INTG_EXECUTE_INQUIRE_SYSTEM,
              INTG_EXECUTE_RENAME,
              INTG_EXECUTE_PRINTSETTINGS,
              INTG_EXECUTE_CLOSEVIEWPORT,
              INTG_EXECUTE_CLEARCOMMANDQUEUE,
              INTG_EXECUTE_MAINWINDOW,
              INTG_EXECUTE_CLOSEDOCUMENT,
              INTG_EXECUTE_SELECTAUTHOR,
              INTG_EXECUTE_GETAUTHORS,
              INTG_EXECUTE_SETDOCUMENTFOCUS,
              INTG_EXECUTE_VIEWCHANGEMARK,
              INTG_EXECUTE_GETCHANGEMARKS,
              INTG_EXECUTE_FILEOPENTOOL,
              INTG_EXECUTE_NEWMARKUP,
              INTG_EXECUTE_DISPLAYISOTOOL,
              INTG_EXECUTE_EXPORTCHANGEMARKS,
              INTG_EXECUTE_PRINTDOCSTACK,
              INTG_EXECUTE_NEWDOCSTACK,
              INTG_EXECUTE_OPENDOCSTACK,
              INTG_EXECUTE_SAVEDOCSTACK,
              INTG_EXECUTE_RUNSILENT,
              INTG_EXECUTE_USEINTEGRATIONOPEN,
              INTG_EXECUTE_SETWYSIWYG,
              INTG_EXECUTE_SETDEFAULTLAYERNAME,
              INTG_EXECUTE_INTEGRATIONENABLED,
              INTG_EXECUTE_GETPROCESSEDISOSTRING,
              INTG_EXECUTE_MODIFYINIVALUE,
              INTG_EXECUTE_ADDPAGE,
              INTG_EXECUTE_ADDMANYPAGES,
              INTG_EXECUTE_PUBLISH3DASSEMBLY,
              INTG_EXECUTE_SET3DRENDERMODE,
              INTG_EXECUTE_SET3DPROJECTIONMODE,
              INTG_EXECUTE_DISABLE3DVIEWSET,
              INTG_EXECUTE_SET3DVIEW,
              INTG_EXECUTE_NEW3DVIEW,
              INTG_EXECUTE_SAVEVIEWSET,
              INTG_EXECUTE_DELETEALL3DVIEWS
             }ExecutionCommandType;

struct ExecuteHeader{
    unsigned long        FullPacketLength;   /* The length of the entire packet including header     */
    unsigned long        DataPacketLength;   /* The length of the data portion of the packet         */
    IGENUM               MessageType;        /* The message type                                     */
    char                 Data[1];            /* The data packet address (i.e. &Data is the address   */
                                             /* of the data for this message)                        */
};

/* These are the notification request types used to indicate which      */
/* notification messages the integrating application wishes to receive. */
typedef enum {INTG_NOTIFY_REQUEST_NONE               =0x0000,
              INTG_NOTIFY_REQUEST_ALL                =0x0001,
              INTG_NOTIFY_REQUEST_EXECUTION_RETURNS  =0x0002,
              INTG_NOTIFY_REQUEST_MOUSE              =0x0004,
              INTG_NOTIFY_REQUEST_INTELLIGENTOBJ     =0x0008,
              INTG_NOTIFY_REQUEST_MARKUP             =0x0010,
              INTG_NOTIFY_REQUEST_FILE_LOAD          =0x0020,
              INTG_NOTIFY_REQUEST_VIEWPORT           =0x0040,
              INTG_NOTIFY_REQUEST_EXIT               =0x0080,
              INTG_NOTIFY_REQUEST_DATABASE_LOOKUP    =0x0100,
              INTG_NOTIFY_REQUEST_PRINT              =0x0200,
              INTG_NOTIFY_REQUEST_ISO_BANNER         =0x0400,
              INTG_NOTIFY_REQUEST_UD_MENU            =0x0800,
              INTG_NOTIFY_REQUEST_CHANGEMARK         =0x1000,
              INTG_NOTIFY_REQUEST_RUN_SILENT         =0x2000,
              INTG_NOTIFY_REQUEST_INTOBJ_LOAD_LAUNCH =0x4000,
              INTG_NOTIFY_REQUEST_3D                 =0x8000
             }NotificationRequestType;

/* These are the notification message types which identify the type of  */
/* data packet being received by the integrating application            */
typedef enum {INTG_NOTIFY_NONE,
              INTG_NOTIFY_EXECUTION_RETURN,
              INTG_NOTIFY_MOUSEMOVE,
              INTG_NOTIFY_LBUTTONDOWN,
              INTG_NOTIFY_LBUTTONUP,
              INTG_NOTIFY_LBUTTONDBLCLICK,
              INTG_NOTIFY_EXIT,
              INTG_LOAD_FILEBEGIN,
              INTG_LOAD_BLOCKBEGIN,
              INTG_LOAD_ATTRIBUTE,
              INTG_LOAD_BLOCKEND,
              INTG_LOAD_FILEEND,
              INTG_DISPLAY_FILEBEGIN,
              INTG_DISPLAY_BLOCKBEGIN,
              INTG_DISPLAY_ATTRIBUTE,
              INTG_DISPLAY_BLOCKEND,
              INTG_DISPLAY_FILEEND,
              INTG_LAUNCH_ATTRIBBLOCK,
              INTG_NOTIFY_SET_RETURN_DATA,
              INTG_NOTIFY_FILE_LOADED,
              INTG_NOTIFY_VIEWPORT_CLOSE,
              INTG_NOTIFY_OPEN_MARKUP,
              INTG_NOTIFY_SAVE_MARKUP,
              INTG_NOTIFY_MARKUP_SAVED,
              INTG_NOTIFY_CLOSE_MARKUP,
              INTG_NOTIFY_IMAGE_CHANGE,
              INTG_NOTIFY_GET_LAYER_INFO,
              INTG_NOTIFY_GET_ISO_STRING,
              INTG_NOTIFY_DATABASE_LOOKUP,
              INTG_NOTIFY_PRINT,
              INTG_NOTIFY_PRINT_COMPLETE,
              INTG_NOTIFY_UD_MENU,
              INTG_NOTIFY_OPEN_MARKUP_REQUEST,
              INTG_NOTIFY_DOCUMENT_INFO,
              INTG_NOTIFY_SYSTEM_INFO,
              INTG_NOTIFY_SAVEAS_MARKUP_REQUEST,
              INTG_NOTIFY_GET_AUTHORS,
              INTG_NOTIFY_CHANGEMARK_VIEWED,
              INTG_NOTIFY_GET_CHANGEMARKS,
              INTG_NOTIFY_NEW_MARKUP,
              INTG_NOTIFY_RUN_SILENT_MSG,
              INTG_NOTIFY_ISO_DISPLAY,
              INTG_NOTIFY_ISO_EDIT,
              INTG_NOTIFY_DATABASE_ISO_LOOKUP,
              INTG_NOTIFY_INTEGRATION_ENABLED,
              INTG_NOTIFY_3D_MODEL_LOADED,
              INTG_NOTIFY_3D_COMPONENT_SELECTION_CHANGED,
              INTG_NOTIFY_3D_COMPONENT_LIST_ENABLED,
              INTG_NOTIFY_PRINT_PREVIEW_COMPLETE,	/* Add Koji Ogawa Mar/11/1999 - print preview complete.	*/
              INTG_NOTIFY_OPEN_MVS_REQUEST,
              INTG_NOTIFY_SAVEAS_MVS_REQUEST,
              INTG_NOTIFY_MVS_SAVED,
              INTG_NOTIFY_CLOSE_MVS,
              INTG_NOTIFY_HTML_EXPORT_FILE_WRITTEN,
              INTG_NOTIFY_MVS_VIEW_CREATED,
              INTG_NOTIFY_VIEW_SET_FILE_LOADED,
              INTG_NOTIFY_VIEW_SET_NEEDS_SAVING
             }NotifyMessageType;

/* These are used to indicate the status of the data which the          */
/* integrating application has received.                                */
typedef enum {INTG_STATUS_COMPLETE_DATA,
              INTG_STATUS_PARTIAL_DATA,
              INTG_STATUS_NO_DATA,
              INTG_STATUS_REPLY_REQUESTED
             }DataStatusType;

/* This is the header structure which is appears at the beginning of    */
/* all data packets received by the integrating application from Myriad */

struct NotifyHeader{
    unsigned long      FullPacketLength;    /* The length of the entire packet including header       */
    unsigned long      DataPacketLength;    /* The length of the data portion of the packet           */
    IGENUM             MessageType;         /* The message type                                       */
    IGENUM             DataStatus;          /* The status of the data in the packet                   */
    char               Data;                /* The data packet address (i.e. &Data is the address     */
                                            /* of the data for this message)                          */
};

/* This structure is used to retrieve the data passed from Myriad in the form of a notification message */
struct NotifyCallbackRecord{
  IGBOOL               Message;             /* The message ID for the notification                    */
  IGBOOL               DataStatus;          /* The status of the data attached to the notification    */
  char                 Data;                /* The address of the data attached to the notification   */
};

/*------------------------------------------------------------------------------------------------------*/
/* The following structure definitions represent the data which is passed to Myriad from a client       */
/* application (execution commands).                                                                    */
/*------------------------------------------------------------------------------------------------------*/

/* This data structure is prepended to all execution notification return messages to indicate which     */
/* notify message is being replied to.                                                                  */
typedef struct ExecuteNotifyReturn{
  IGENUM          ReplyMessage;
}ExecuteNotifyReturn, *pExecuteNotifyReturn;

/*------------------------------------------------------------------------------------------------------*/
/* The following structure definition is for internal use only.                                         */
/*------------------------------------------------------------------------------------------------------*/
struct ExecuteParseFailure{
  IGENUM          Message;
};

/* This structure is passed to the Myriad application when an exit has been requested. It is sent to    */
/* Myriad as an execution notification command.                                                         */
struct NotifyExitReturn{
  struct ExecuteNotifyReturn Header;
  IGBOOL                     bOKToExit;
};

struct NotifyDatabaseLookupReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifyOpenMarkupRequestReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifySaveAsMarkupRequestReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifyMarkupSavedReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifyOpenMVSRequestReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifySaveAsMVSRequestReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifyMVSSavedReturn{
  struct ExecuteNotifyReturn Header;
  char                       Filename[MAX_PATH_FILENAME];
};

struct NotifyDatabaseISOLookupReturn{
  struct ExecuteNotifyReturn Header;
  char Returnstring[MAX_INI_STRING_SIZE];
};

struct NotifyPrintReturn{
  struct ExecuteNotifyReturn Header;
  IGBOOL                     bOKToPrint;
};

struct NotifyRunSilentMessageReturn{
  struct ExecuteNotifyReturn Header;
  IGBOOL                     bDisplayMessage;       /* Whether or not Myriad is to put up the default message box for this message */
  IGINT                      Result;                /* The message box result if bDisplayMessage is FALSE */
};

struct NotifyISODisplayReturn{
  struct ExecuteNotifyReturn Header;
  IGBOOL                     bOKToDisplay;          /* Whether or not it is OK to display the ISO information */
};

struct NotifyViewSetNeedsSavingReturn{
  struct ExecuteNotifyReturn Header;
  char                       MVSFilename[MAX_PATH_FILENAME];         /* The filename to use for the view set file */
  char                       MVSMarkupFilename[MAX_PATH_FILENAME];   /* The filename to use for the associated markup */
  IGBOOL                     bPerformMVSSave;                        /* Whether or not to perform the saving of the view set */
  IGBOOL                     bPerformMarkupSave;                     /* Whether or not to perform the saving of any markup file associated with the view set */
  IGBOOL                     bUpdateAllModifiedViews;                /* If all the modified view set views are to be updated before saving */
  IGBOOL                     bRestoreAllModifiedViews;               /* If all the modified view set views are to be restored before saving */
};

struct ExecuteSetNotifications{
  long     NotificationTypes;
};

/////Guido's Hint Line, issue #8399//////////////////////////////////////////
//
// While updating the Agile integration, I discovered, that the 'dbdesc:' 
// string for describing the display name of the loaded document is now also 
// required in the 'Filename' portion of the structure.
//
// Example:
// strcpy( ffload.Description, "dbdesc:Gunk.DWG" );
// but also!
// strcpy( ffload.Filename, "dbms:C:\Green\Sloshy\Gunk.DWG:dbdesc:Gunk.DWG" );
// 
// The extra 'dbdesc:' is needed for instance in the building of the layer
// tree (see CLayerPage::buildImageLayerList), when the option 'Hide Paths'
// is switched on.
//
// For questions or fan mail write to: guidos@infograph.com
/////////////////////////////////////////////////////////////////////////////
struct ExecuteFFLoad{
  char     Filename[MAX_PATH_FILENAME];
  char     Description[MAX_DESCRIPTION_SIZE];
  char     RedlineFilename[MAX_PATH_FILENAME];
  char     AssociatedFileType[MAX_ASSOCIATED_FILE_TYPE];
  IGBOOL   bAddToFolderOnly;
  IGBOOL   bForceNewDocument;
  char     OverlayFilename[MAX_PATH_FILENAME];
};

struct ExecuteFFInit{
  char     Filename[MAX_PATH_FILENAME];
  IGBOOL   bShowOpenDialog;
};

struct ExecuteOpenMarkup{
  char     Filename[MAX_PATH_FILENAME];         /* Filename of markup file to open on current image */
};

typedef enum {MARKUPFORMAT_DEFAULT, MARKUPFORMAT_MRK, MARKUPFORMAT_DXF, MARKUPFORMAT_XML, MARKUPFORMAT_TXT}ExecuteSaveMarkupTypes;

struct ExecuteSaveMarkup{
   IGENUM   SaveMarkupType;
   char     Filename[MAX_PATH_FILENAME];         /* Filename of markup file to save to */
};

typedef enum {VIEW3D_ISOMETRIC,
              VIEW3D_DIMETRIC,
              VIEW3D_TRIMETRIC,
              VIEW3D_FRONT,
              VIEW3D_BACK,
              VIEW3D_LEFT,
              VIEW3D_RIGHT,
              VIEW3D_TOP,
              VIEW3D_BOTTOM
             }ExecuteView3DTypes;

struct ExecuteSet3DView{
   IGENUM   View3DType;
};

struct ExecuteNew3DView{
   char     name[MAX_DESCRIPTION_SIZE];
   char     note[MAX_CHANGEMARK_TEXT_SIZE];
};

struct ExecuteSaveViewset{
   char     Filename[MAX_PATH_FILENAME];         /* Filename of viewset file to save to */
};

struct ExecuteDeleteAll3DViews{
   IGBOOL   WarnOnDelete;                       /* Whether or not to warn the user that the views are about to be deleted */
};

typedef enum {EXECUTE_ZOOM_IN,    EXECUTE_ZOOM_OUT,   EXECUTE_ZOOM_EXTENTS, EXECUTE_ZOOM_PREVIOUS,
              EXECUTE_ZOOM_POINT, EXECUTE_ZOOM_WIDTH, EXECUTE_ZOOM_WORLD}ExecuteZoomTypes;

struct ExecuteZoom{
  double MinX;         /* Minimum X of zoom window (only required for world coordinate zoom) */
  double MinY;         /* Minimum Y of zoom window (only required for world coordinate zoom) */
  double MaxX;         /* Maximum X of zoom window (only required for world coordinate zoom) */
  double MaxY;         /* Maximum Y of zoom window (only required for world coordinate zoom) */
  IGENUM ZoomType;     /* Type of zoom to perform */
};

typedef enum {EXECUTE_RASTER_SAMPLE_DRAW, EXECUTE_RASTER_FULL_DRAW, EXECUTE_RASTER_SCALE_TO_GRAY}ExecuteRasterTypes;

struct ExecuteRaster{
  IGENUM RasterType;
};

typedef enum {EXECUTE_ROTATE_PREVIOUS, EXECUTE_ROTATE_NEXT, EXECUTE_ROTATE_0, EXECUTE_ROTATE_90, EXECUTE_ROTATE_180,
              EXECUTE_ROTATE_270}ExecuteRotateTypes;

struct ExecuteRotate{
  IGENUM RotateType;
};

typedef enum {EXECUTE_WINDOW_TILE_HORZ,     EXECUTE_WINDOW_TILE_VERT, EXECUTE_WINDOW_CASCADE,  
              EXECUTE_WINDOW_FIT,           EXECUTE_WINDOW_MAXIMIZE,  EXECUTE_WINDOW_MINIMIZE, 
              EXECUTE_WINDOW_RESTORE,       EXECUTE_WINDOW_ARRANGE_ICONS}ExecuteWindowTypes;

struct ExecuteWindow{
  IGENUM WindowType;
};

typedef enum {EXECUTE_MAIN_WINDOW_MINIMIZE, EXECUTE_MAIN_WINDOW_MAXIMIZE, EXECUTE_MAIN_WINDOW_RESTORE}ExecuteMainWindowTypes;

struct ExecuteMainWindow{
  IGENUM WindowType;
};

typedef enum {EXECUTE_SET_RETURN_DATA_SET, EXECUTE_SET_RETURN_DATA_GET}ExecuteSetReturnDataTypes;

struct ExecuteSetReturnData{
  IGENUM SetType;
  char   Data[EXECUTE_SET_RETURN_DATA_SIZE];
};

typedef enum {EXECUTE_PAGE_NEXT,  EXECUTE_PAGE_PREVIOUS,
              EXECUTE_PAGE_FIRST, EXECUTE_PAGE_LAST,
              EXECUTE_PAGE_SPECIFIC}ExecutePageTypes;

struct ExecutePage{
  IGENUM         PageType;
  unsigned short PageNumber;  /* Only specified if type is EXECUTE_PAGE_SPECIFIC */
};

struct ExecuteSetFrameWindow{
  unsigned short    Left;
  unsigned short    Top;
  unsigned short    Width;
  unsigned short    Height;
};

struct ExecuteDisableAltView{
  IGBOOL bDisableView;
};

typedef enum {EXECUTE_CLIP_ALL, EXECUTE_CLIP_ASK}ExecuteClipTypes;

struct ExecuteClip{
  IGENUM ClipType;
};

struct ExecuteLockWindow{
  IGBOOL bLockWindow;
};      

typedef enum {EXECUTE_PRINT_QUICK, EXECUTE_PRINT_DIALOG}ExecutePrintTypes;

struct ExecutePrint{
  IGENUM PrintType;                  /* The type of print to perform */
  IGBOOL bPrintCancelDialog;         /* If the print cancellation dialog is to be displayed (optional) - Default is TRUE */
  IGBOOL bOverlayISOBanners;         /* If ISO banners are to be overlayed on the image (optional) - Default is FALSE */
};

typedef enum {
              EXECUTE_EMENU_SECTION,
              EXECUTE_EMENU_FILE_OPEN,
              EXECUTE_EMENU_DOCSTACK,
              EXECUTE_EMENU_ASSOC,
              EXECUTE_EMENU_PRINT_SETUP,
              EXECUTE_EMENU_RECENT_FILE,
              EXECUTE_EMENU_APP_EXIT,
              EXECUTE_EMENU_CHANGEMARKS,
              EXECUTE_EMENU_OPTIONS,
              EXECUTE_EMENU_SIDE_BY_SIDE,
              EXECUTE_EMENU_VIEW_TOOLBAR,
              EXECUTE_EMENU_VIEW_STATUS_BAR,
              EXECUTE_EMENU_HELP_CONTENTS,
              EXECUTE_EMENU_HELP_SEARCH,
              EXECUTE_EMENU_HELP_SUPPORT,
              EXECUTE_EMENU_HELP_ABOUT,
              EXECUTE_EMENU_REDLINE_NEW,
              EXECUTE_EMENU_REDLINE_OPEN,
              EXECUTE_EMENU_REDLINE_SAVE,
              EXECUTE_EMENU_REDLINE_SAVEAS,
              EXECUTE_EMENU_REDLINE_CLOSE,
              EXECUTE_EMENU_NEXT_DOC,
              EXECUTE_EMENU_PREV_DOC,
              EXECUTE_EMENU_PRINT,
              EXECUTE_EMENU_PRINT_PREVIEW,
              EXECUTE_EMENU_PRINT_QUEUE,
              EXECUTE_EMENU_PRINT_QUEUE_SETUP,
              EXECUTE_EMENU_SEND_MAIL,
              EXECUTE_EMENU_UNDO,
              EXECUTE_EMENU_REDO,
              EXECUTE_EMENU_MYRIAD_FILE,
              EXECUTE_EMENU_MYRIAD_EDIT,
              EXECUTE_EMENU_MYRIAD_VIEW,
              EXECUTE_EMENU_MYRIAD_REDLINE,
              EXECUTE_EMENU_MYRIAD_TOOLS,
              EXECUTE_EMENU_MYRIAD_ANALYZE,
              EXECUTE_EMENU_MYRIAD_WINDOW,
              EXECUTE_EMENU_MYRIAD_HELP,
              EXECUTE_EMENU_MYRIAD_EDIT_REDLINE,
              EXECUTE_EMENU_DELETE,
              EXECUTE_EMENU_CAPTURE,
              EXECUTE_EMENU_SELECT,
              EXECUTE_EMENU_BIRDSEYE,
              EXECUTE_EMENU_EYEGLASS,
              EXECUTE_EMENU_ZOOM,
              EXECUTE_EMENU_ZOOM_WIDTH,
              EXECUTE_EMENU_ZOOM_EXTENTS,
              EXECUTE_EMENU_PAN,
              EXECUTE_EMENU_FIND,
              EXECUTE_EMENU_REDRAW,
              EXECUTE_EMENU_CONSOLIDATE,
              EXECUTE_EMENU_SET_REDLINE_LAYER,
              EXECUTE_EMENU_CREATE_SYMBOL,
              EXECUTE_EMENU_REMOVE_SYMBOL,
              EXECUTE_EMENU_AUTHOR_TOOL,
              EXECUTE_EMENU_REDLINE_TOOL,
              EXECUTE_EMENU_CHANGE_MARKS,
              EXECUTE_EMENU_REDLINE,
              EXECUTE_EMENU_LAYERING,
              EXECUTE_EMENU_CALIBRATE,
              EXECUTE_EMENU_MEASURE,
              EXECUTE_EMENU_TOOLBAR,
              EXECUTE_EMENU_STATUS_BAR,
              EXECUTE_EMENU_PAGE_CONTROL,
              EXECUTE_EMENU_NEW_WINDOW,
              EXECUTE_EMENU_FIT_WINDOW,
              EXECUTE_EMENU_CASCADE,
              EXECUTE_EMENU_TILE_HORZ,
              EXECUTE_EMENU_TILE_VERT,
              EXECUTE_EMENU_ARRANGE_ICONS,
              EXECUTE_EMENU_CLOSE_ALL,
              EXECUTE_EMENU_QUICK_PRINT,
              EXECUTE_EMENU_MONOCHROME,
              EXECUTE_EMENU_FULL_DRAW,
              EXECUTE_EMENU_INVERT,
              EXECUTE_EMENU_THUMB_NAIL,
              EXECUTE_EMENU_FIRST_PAGE,
              EXECUTE_EMENU_PREV_PAGE,
              EXECUTE_EMENU_NEXT_PAGE,
              EXECUTE_EMENU_LAST_PAGE,
              EXECUTE_EMENU_ZOOM_IN,
              EXECUTE_EMENU_ZOOM_OUT,
              EXECUTE_EMENU_TOOLBAR_ORIENT,
              EXECUTE_EMENU_MRU,
              EXECUTE_EMENU_FILE_CLOSE,
              EXECUTE_EMENU_REDLINE_POSTIT,
              EXECUTE_EMENU_REDLINE_HILITE,
              EXECUTE_EMENU_REDLINE_SEARCH,
              EXECUTE_EMENU_REDLINE_CARET,
              EXECUTE_EMENU_REDLINE_LINE,
              EXECUTE_EMENU_REDLINE_TEXT,
              EXECUTE_EMENU_REDLINE_CROSSOUT,
              EXECUTE_EMENU_REDLINE_SIZEUP,
              EXECUTE_EMENU_REDLINE_SIZEDOWN,
              EXECUTE_EMENU_REDLINE_ENT_FBOX,
              EXECUTE_EMENU_REDLINE_ENT_FPGON,
              EXECUTE_EMENU_REDLINE_ENT_CIRCLE,
              EXECUTE_EMENU_REDLINE_ENT_RECT,
              EXECUTE_EMENU_REDLINE_ENT_CLOUD,
              EXECUTE_EMENU_REDLINE_ENT_CROSSOUT,
              EXECUTE_EMENU_REDLINE_ENT_BOX,
              EXECUTE_EMENU_REDLINE_ENT_LINE,
              EXECUTE_EMENU_REDLINE_ENT_SKETCH,
              EXECUTE_EMENU_REDLINE_ENT_TEXT,
              EXECUTE_EMENU_REDLINE_ENT_TEXT_INS,
              EXECUTE_EMENU_REDLINE_ENT_TEXT_CROSSOUT,
              EXECUTE_EMENU_REDLINE_ENT_TEXT_LEADER,
              EXECUTE_EMENU_FILE_UPDATE,
              EXECUTE_EMENU_FILE_NEW,
              EXECUTE_EMENU_SAVE_COPY_AS,
              EXECUTE_EMENU_CUT,
              EXECUTE_EMENU_COPY,
              EXECUTE_EMENU_PASTE,
              EXECUTE_EMENU_ARRANGE_WINDOW,
              EXECUTE_EMENU_CASCADE_WINDOW,
              EXECUTE_EMENU_TILE_WINDOW_HORZ,
              EXECUTE_EMENU_HELP_USING,
              EXECUTE_EMENU_VIEW_TEXT_TOOLBAR,
              EXECUTE_EMENU_SHOW_PAGE_CONTROL,
              EXECUTE_EMENU_ZOOM_PREVIOUS,
              EXECUTE_EMENU_ZOOM_POINT,
              EXECUTE_EMENU_ROTATE_NEXT,
              EXECUTE_EMENU_ROTATE_PREVIOUS,
              EXECUTE_EMENU_EYEGLASS_CLOSE,
              EXECUTE_EMENU_EYEGLASS_CLOSE_SYNC,
              EXECUTE_EMENU_BIRDSEYE_CLOSE,
              EXECUTE_EMENU_BIRDSEYE_STICKAROUND,
              EXECUTE_EMENU_REDLINE_SYNC_COLOR,
              EXECUTE_EMENU_REDLINE_SYNC_LINE_WIDTH,
              EXECUTE_EMENU_REDLINE_SYNC_ARROW_SIZE,
              EXECUTE_EMENU_REDLINE_PALETTE,
              EXECUTE_EMENU_REDLINE_CHANGE,
              EXECUTE_EMENU_REDLINE_SYMBOL,
              EXECUTE_EMENU_ISO_DISPLAY,
              EXECUTE_EMENU_ISO_EDIT,
              EXECUTE_EMENU_PRINT_REGION,
              EXECUTE_EMENU_SYSTEM_ADMIN,
              EXECUTE_EMENU_MYRIAD_FILE_DOCSTACK,
              EXECUTE_EMENU_3D_VIEWING,           
              EXECUTE_EMENU_3D_NAV_TOOLBAR,   
              EXECUTE_EMENU_3D_ANALYZE_TOOLBAR,   
              EXECUTE_EMENU_3D_COMP_TOOLBAR,      
              EXECUTE_EMENU_REDLINE_REVIEW,
              EXECUTE_EMENU_REDLINE_ADDTOFILE,
              EXECUTE_EMENU_REDLINE_REMOVEFROMFILE,
              EXECUTE_EMENU_3D_LOAD_TOOLBAR,
              EXECUTE_EMENU_PUBLISH,
              EXECUTE_EMENU_VIEWSET_OPEN,
              EXECUTE_EMENU_VIEWSET_SAVE,
              EXECUTE_EMENU_VIEWSET_SAVEAS,
              EXECUTE_EMENU_VIEWSET_TOOLBAR,
              EXECUTE_EMENU_VIEWSET_NEW_VIEW,
              EXECUTE_EMENU_VIEWSET_MODIFY_VIEW,
              EXECUTE_EMENU_VIEWSET_NEW_REDLINE_VIEW
             }ExecuteEnableMenuTypes;

struct ExecuteEnableMenuItem{
  IGENUM Menu;
  IGBOOL bEnable;
  IGBOOL bRemove; // TRUE, by default
};

typedef enum {EXECUTE_REMOVE_MENU_FILE,    EXECUTE_REMOVE_MENU_EDIT,
              EXECUTE_REMOVE_MENU_VIEW,    EXECUTE_REMOVE_MENU_TOOLS,
              EXECUTE_REMOVE_MENU_REDLINE, EXECUTE_REMOVE_MENU_WINDOW,
              EXECUTE_REMOVE_MENU_HELP,    EXECUTE_REMOVE_MENU_ANALYZE}ExecuteRemoveMenuTypes;

struct ExecuteRemoveMenu{
  IGENUM RemoveMenu;
};

struct ExecuteDeleteItem{
  char    Filename[MAX_PATH_FILENAME];
};

struct ExecuteSetMarkupColor{
  unsigned short          LayerID;
  unsigned short          LayerColor;
};

struct ExecuteSetAuthorName{
  char                    AuthorName[AUTHOR_LAYER_NAME_SIZE];
};

struct ExecuteSetLayerName{
  unsigned short          LayerID;
  char                    LayerName[AUTHOR_LAYER_NAME_SIZE];
};

struct ExecuteEnableDocModify{
  IGBOOL                  bEnable;
};

struct ExecuteMonochrome{
  IGBOOL                  bEnable;
};

struct ExecuteRedlineChangeMark{
  IGBOOL                  bEnable;
};

struct ExecuteSideBySide{
  char                    LeftFilename[MAX_PATH_FILENAME];          /* Left side image */
  char                    RightFilename[MAX_PATH_FILENAME];         /* Right side image */
  IGBOOL                  bOpenOriginals;                           /* If the original file should be loaded */
  IGBOOL                  bGhostVisible;                            /* If ghosting is visible or not */
};

struct ExecuteEnableColorSel{
  IGBOOL                  bEnable;
};

typedef enum {EXECUTE_ISO_FONT,       EXECUTE_ISO_CLEAR_ALL,    EXECUTE_ISO_RESTORE_DEFAULTS,
              EXECUTE_ISO_TOPLEFT,    EXECUTE_ISO_TOPCENTER,    EXECUTE_ISO_TOPRIGHT,
              EXECUTE_ISO_BOTTOMLEFT, EXECUTE_ISO_BOTTOMCENTER, EXECUTE_ISO_BOTTOMRIGHT,
              EXECUTE_ISO_LEFTTOP,    EXECUTE_ISO_LEFTCENTER,   EXECUTE_ISO_LEFTBOTTOM,
              EXECUTE_ISO_RIGHTTOP,   EXECUTE_ISO_RIGHTCENTER,  EXECUTE_ISO_RIGHTBOTTOM,
              EXECUTE_ISO_WATERMARK} ExecuteISOStringTypes;

struct ExecuteSetISOString{
  IGENUM                  StringType;                   /* The type of ISO string this is ExecuteISOStringTypes */
  unsigned short          StringNumber;                 /* The index of this string within the string type         */
  char                    String[MAX_ISO_STRING_SIZE];  /* The string itself                                       */
};

struct ExecuteGetISOString{
  IGENUM                  StringType;                   /* The type of ISO string this is ExecuteISOStringTypes */
  unsigned short          StringNumber;                 /* The index of this string within the string type         */
};

struct ExecuteGetProcessedISOString{
  IGENUM                  StringType;                   /* The type of ISO string this is ExecuteISOStringTypes */
  unsigned short          StringNumber;                 /* The index of this string within the string type         */
};

typedef enum {EXECUTE_UD_MENU_MAIN_STARTUP, EXECUTE_UD_MENU_MAIN_DOC_VIEW, EXECUTE_UD_MENU_RIGHT_POPUP} ExecuteUDMenuLocationTypes;

typedef enum {EXECUTE_UD_MENU_MENU, EXECUTE_UD_MENU_SUBMENU, 
              EXECUTE_UD_MENU_MENUITEM, EXECUTE_UD_MENU_SEPARATOR} ExecuteUDMenuTypes;

#define EXECUTE_UD_MENU_NULL_PARENT   (-1)

struct ExecuteAddUDMenu{
  IGENUM                  MenuLocation;                 /* The location of the menu */
  IGENUM                  MenuType;                     /* The type of the menu */
  char                    Text[MAX_MENU_TEXT_SIZE];     /* The text of the menu */
  IGINT                   MenuID;                       /* User defined menu ID */  
  IGINT                   MenuOffset;                   /* Zero based offset of the menu item (Main menu only) */
  IGINT                   ParentID;                     /* ID of parent menu to contain this menu - Optional */
};

struct ExecuteRemoveUDMenu{
  IGINT                   MenuID;                       /* User defined menu ID */  
};

struct ExecuteEnableUDMenu{
  IGINT                   MenuID;                       /* User defined menu ID */  
  IGBOOL                  bEnable;                      /* Whether to enable or disable the menu element */
};

struct ExecuteSetOnTop{
  IGBOOL                  bAlwaysOnTop;                 /* Whether to make Myriad's window always on top or not */
};

typedef enum {EXECUTE_EXPORT_BMP, EXECUTE_EXPORT_JPG, EXECUTE_EXPORT_PNG, EXECUTE_EXPORT_DLS} ExecuteExportTypes;

struct ExecuteExportToFile{
  char                    FileName[MAX_PATH_FILENAME];  /* Filename to write to */
  IGENUM                  FileType;                     /* Type of file to export */
};

struct ExecuteRename{
  char                    OldFileName[MAX_PATH_FILENAME]; /* Name of the existing file in the document stack */
  char                    NewFileName[MAX_PATH_FILENAME]; /* New name for the existing file */
};

/* These declarations are for the printer specification support. They are used by both INTG_EXECUTE_PRINT_SETTINGS, 
   and INTG_NOTIFY_SYSTEM_INFO.
*/

#define MAX_PRINTER_NAME           (256)
#define MIN_PRINT_SCALE_PERCENT    (0.0001)
#define MAX_PRINT_SCALE_PERCENT    (1000.0)

typedef enum {EXECUTE_PRINT_RANGE_ALL, EXECUTE_PRINT_RANGE_PAGES, EXECUTE_PRINT_RANGE_CURRENT} ExecutePrintRangeTypes;

typedef enum {EXECUTE_PRINT_SCALE_PAGE, EXECUTE_PRINT_SCALE_TO_SCALE} ExecutePrintScaleTypes;

typedef enum {EXECUTE_PRINT_ORIENT_PORTRAIT, EXECUTE_PRINT_ORIENT_LANDSCAPE} ExecutePrintOrientTypes;

typedef enum {EXECUTE_PRINT_DOCUMENT, EXECUTE_PRINT_NOTES} ExecutePrintWhatTypes;

typedef enum {EXECUTE_PRINT_SIZE_DEFAULT,
              EXECUTE_PRINT_SIZE_LETTER,             
              EXECUTE_PRINT_SIZE_LEGAL,        
              EXECUTE_PRINT_SIZE_A4,          
              EXECUTE_PRINT_SIZE_CSHEET,     
              EXECUTE_PRINT_SIZE_DSHEET,
              EXECUTE_PRINT_SIZE_ESHEET,             
              EXECUTE_PRINT_SIZE_LETTERSMALL,  
              EXECUTE_PRINT_SIZE_TABLOID,     
              EXECUTE_PRINT_SIZE_LEDGER,     
              EXECUTE_PRINT_SIZE_STATEMENT,
              EXECUTE_PRINT_SIZE_EXECUTIVE,          
              EXECUTE_PRINT_SIZE_A3,           
              EXECUTE_PRINT_SIZE_A4SMALL,     
              EXECUTE_PRINT_SIZE_A5,         
              EXECUTE_PRINT_SIZE_B4, 
              EXECUTE_PRINT_SIZE_B5,                 
              EXECUTE_PRINT_SIZE_FOLIO,        
              EXECUTE_PRINT_SIZE_QUARTO,      
              EXECUTE_PRINT_SIZE_10X14,      
              EXECUTE_PRINT_SIZE_11X17,    
              EXECUTE_PRINT_SIZE_NOTE,               
              EXECUTE_PRINT_SIZE_ENV9,         
              EXECUTE_PRINT_SIZE_ENV10,       
              EXECUTE_PRINT_SIZE_ENV11,      
              EXECUTE_PRINT_SIZE_ENV12,        
              EXECUTE_PRINT_SIZE_ENV14,              
              EXECUTE_PRINT_SIZE_ENVDL,        
              EXECUTE_PRINT_SIZE_ENVC5,       
              EXECUTE_PRINT_SIZE_ENVC3,      
              EXECUTE_PRINT_SIZE_ENVC4, 
              EXECUTE_PRINT_SIZE_ENVC6,              
              EXECUTE_PRINT_SIZE_ENVC65,       
              EXECUTE_PRINT_SIZE_ENVB4,       
              EXECUTE_PRINT_SIZE_ENVB5,      
              EXECUTE_PRINT_SIZE_ENVB6, 
              EXECUTE_PRINT_SIZE_ENVITALY,           
              EXECUTE_PRINT_SIZE_ENVMONARCH,   
              EXECUTE_PRINT_SIZE_ENVPERSONAL, 
              EXECUTE_PRINT_SIZE_FANFOLD_US, 
              EXECUTE_PRINT_SIZE_FANFOLD_STDGERMAN,
              EXECUTE_PRINT_SIZE_FANFOLD_LGLGERMAN,  
              EXECUTE_PRINT_SIZE_ISOB4,       
              EXECUTE_PRINT_SIZE_JAPANESE_POSTCARD,  
              EXECUTE_PRINT_SIZE_9X11,
              EXECUTE_PRINT_SIZE_10X11,
              EXECUTE_PRINT_SIZE_15X11,
              EXECUTE_PRINT_SIZE_ENV_INVITE,
              EXECUTE_PRINT_SIZE_LETTER_EXTRA,
              EXECUTE_PRINT_SIZE_LEGAL_EXTRA,
              EXECUTE_PRINT_SIZE_TABLOID_EXTRA,
              EXECUTE_PRINT_SIZE_A4_EXTRA,
              EXECUTE_PRINT_SIZE_LETTER_TRANSVERSE,
              EXECUTE_PRINT_SIZE_A3_TRANSVERSE,
              EXECUTE_PRINT_SIZE_A3_EXTRA_TRANSVERSE,
              EXECUTE_PRINT_SIZE_A4_TRANSVERSE,
              EXECUTE_PRINT_SIZE_LETTER_EXTRA_TRANSVERSE,
              EXECUTE_PRINT_SIZE_A5_TRANSVERSE,
              EXECUTE_PRINT_SIZE_B5_TRANSVERSE,
              EXECUTE_PRINT_SIZE_A_PLUS,
              EXECUTE_PRINT_SIZE_B_PLUS,
              EXECUTE_PRINT_SIZE_LETTER_PLUS,
              EXECUTE_PRINT_SIZE_A4_PLUS,
              EXECUTE_PRINT_SIZE_A3_EXTRA,
              EXECUTE_PRINT_SIZE_A5_EXTRA,
              EXECUTE_PRINT_SIZE_B5_EXTRA,
              EXECUTE_PRINT_SIZE_A2,
              EXECUTE_PRINT_SIZE_USER
             } ExecutePrintPaperSizeTypes;

struct PrintSettings{
  char                    PrinterName[MAX_PRINTER_NAME];      /* The name of the printer to use */
  IGENUM                  PaperSize;                          /* The paper size to use */
  IGINT                   Copies;                             /* Number of copies to print */
  IGENUM                  ScaleType;                          /* What type of image scaling to use */
  double                  ScalePercent;                       /* Percentage to scale (1-999) */
  IGBOOL                  bGenerateBitmap;                    /* Whether to generate bitmap output or not */
  IGBOOL                  bBlackAndWhite;                     /* Whether to print black and white or not */
  IGBOOL                  bOutlineFills;                      /* Whether to print with filled entities outlined or not */
  IGENUM                  Orientation;                        /* The orientation of the printed output */
  IGENUM                  PrintWhat;                          /* What to print (document or notes) */
  IGENUM                  PrintRange;                         /* The print range */
  IGINT                   FromPage;                           /* From page (only used for EXECUTE_PRINT_RANGE_PAGES */
  IGINT                   ToPage;                             /* To page (only used for EXECUTE_PRINT_RANGE_PAGES */
  IGINT                   UserPaperWidth;                     /* Custom paper width (only for EXECUTE_PRINT_SIZE_USER*/
  IGINT                   UserPaperHeight;                    /* Custom paper height (only for EXECUTE_PRINT_SIZE_USER*/
};

struct ExecutePrintSettings{
   IGBOOL                 bSetPrintSettings;                  /* Whether to set print settings (TRUE) or clear print settings (FALSE) */
   struct PrintSettings   PrintSettings;                      /* The PrintSettings structure to use for subsequent prints */
};

struct ExecuteCloseDocument{
  char                    Filename[MAX_PATH_FILENAME];        /* The name of the view to close */
};

struct ExecuteSelectAuthor{
  char                    AuthorName[AUTHOR_LAYER_NAME_SIZE]; /* The name of the author to select or deselect */
  IGBOOL                  bSelect;                            /* Select the author (TRUE) or deselect the author (FALSE) */
};

struct ExecuteSetDocumentFocus{
  char                    Filename[MAX_PATH_FILENAME];        /* The name of the view to set focus to */
};

struct ExecuteViewChangemark{
  char                    Title[MAX_DESCRIPTION_SIZE];        /* The title of the changemark to view */
};

struct ExecuteGetChangemarks{
  IGBOOL                  bFilteredOnly;                      /* Get only the filtered changemarks (TRUE) or all changemarks (FALSE) - Default is FALSE */
};

struct ExecuteExportChangemarks{
  char                    Filename[MAX_PATH_FILENAME];                 /* File to export the changemark information to */
  IGBOOL                  bFilteredOnly;                               /* Get only the filtered changemarks (TRUE) or all changemarks (FALSE) - Default is FALSE */
  char                    FieldDelimiter[MAX_EXPORT_DELIMITER_SIZE];   /* The delimiter to use between fields in the output file */
  char                    StringDelimiter[MAX_EXPORT_DELIMITER_SIZE];  /* The delimiter to use to indicate string fields in the output file */
};

struct ExecutePrintDocstack{
  char                    Filename[MAX_PATH_FILENAME];                 /* The DSF file to print (optional) - Default is to use current Document Stack */
};

struct ExecuteOpenDocstack{
  char                    Filename[MAX_PATH_FILENAME];                 /* The DSF file to open. If no file specified, then the Open Document Stack dialog is displayed */
  IGBOOL                  bShowDialog;                                 /* If the Document Stack Dialog is to be shown - default TRUE */
};

struct ExecuteSaveDocstack{
  char                    Filename[MAX_PATH_FILENAME];                 /* The DSF file to save Document Stack to. If no file specified, then the SaveAs dialog is displayed */
};

struct ExecuteRunSilent{
  IGBOOL                  bRunSilent;       /* Run Myriad in silent mode - Default is TRUE */
};

struct ExecuteUseIntegrationOpen{
  IGBOOL                  bUseIntegrationOpen;   /* Use the integration's open dialog - Default is TRUE */
};

typedef enum {EXECUTE_FILEOPEN_IMAGE, EXECUTE_FILEOPEN_REDLINE, EXECUTE_FILEOPEN_REDLINE_REVIEW} ExecuteFileOpenTypes;

struct ExecuteFileOpenTool{
  IGENUM                  FileOpenType;
};

struct ExecuteSetWYSIWYG{
  IGBOOL bWYSIWYGMarkup;         // If allowing markup on WYSIWYG images. - Default FALSE
};      

struct ExecuteSetDefaultLayerName{
  char LayerName[AUTHOR_LAYER_NAME_SIZE];
};

typedef enum {EXECUTE_USER_INI,  
              EXECUTE_MYRIAD_INI,
              EXECUTE_DRIVER_INI // not allowed
             }ExecuteIniFileTypes;

struct ExecuteModifyIniValue{
   IGENUM   IniFileType;
   char     section[MAX_INI_STRING_SIZE];
   char     key[MAX_INI_STRING_SIZE];
   char     value[MAX_INI_STRING_SIZE];
};

struct ExecuteAddPage{
   char     Filename[MAX_PATH_FILENAME];
   char     Description[MAX_DESCRIPTION_SIZE];
   char     AssociatedFileType[MAX_ASSOCIATED_FILE_TYPE];
   int      Page;
   int      SubPage;
};

struct ExecuteAddManyPages{
   char     BaseName[MAX_PATH_FILENAME];
   char     Description[MAX_DESCRIPTION_SIZE];
   char     AssociatedFileType[MAX_ASSOCIATED_FILE_TYPE];
   int      Pages;
};

typedef enum {EXECUTE_PUBLISH_DEFAULT                =0x0000,
              EXECUTE_PUBLISH_ISOMETRIC              =0x0001,
              EXECUTE_PUBLISH_DIMETRIC               =0x0002,
              EXECUTE_PUBLISH_TRIMETRIC              =0x0004,
              EXECUTE_PUBLISH_FRONT                  =0x0008,
              EXECUTE_PUBLISH_BACK                   =0x0010,
              EXECUTE_PUBLISH_LEFT                   =0x0020,
              EXECUTE_PUBLISH_RIGHT                  =0x0040,
              EXECUTE_PUBLISH_TOP                    =0x0080,
              EXECUTE_PUBLISH_BOTTOM                 =0x0100,
              EXECUTE_PUBLISH_VIEWSET_VIEWS          =0x0200,
              EXECUTE_PUBLISH_MODEL_PARTS            =0x0400,
              EXECUTE_PUBLISH_ALL_VIEWS              =0x07FF
             }ExecutePublish3DAssemblyType;

typedef enum {EXECUTE_PUBLISH_EXPLODE_NONE                   =0x0000,
              EXECUTE_PUBLISH_EXPLODE_ISOMETRIC              =0x0001,
              EXECUTE_PUBLISH_EXPLODE_DIMETRIC               =0x0002,
              EXECUTE_PUBLISH_EXPLODE_TRIMETRIC              =0x0004,
              EXECUTE_PUBLISH_EXPLODE_FRONT                  =0x0008,
              EXECUTE_PUBLISH_EXPLODE_BACK                   =0x0010,
              EXECUTE_PUBLISH_EXPLODE_LEFT                   =0x0020,
              EXECUTE_PUBLISH_EXPLODE_RIGHT                  =0x0040,
              EXECUTE_PUBLISH_EXPLODE_TOP                    =0x0080,
              EXECUTE_PUBLISH_EXPLODE_BOTTOM                 =0x0100,
              EXECUTE_PUBLISH_EXPLODE_REVERSE_VIEWS          =0x0200,
              EXECUTE_PUBLISH_EXPLODE_ALL_VIEWS              =0x03FF
             }ExecutePublishExplode3DAssemblyType;

struct ExecutePublish3DAssembly{
   char     OutputFileName[MAX_PATH_FILENAME];
   IGENUM   Publish3DAssemblyType;
   IGENUM   PublishExplode3DAssemblyType;
};

typedef enum {EXECUTE_SET_WIREFRAME,                
              EXECUTE_SET_HIIDENLINE,  
              EXECUTE_SET_SHADED,                   
              EXECUTE_SET_COMPOSITE,           
              EXECUTE_SET_BREP,              
              EXECUTE_SET_BREP_HIDDEN,          
              EXECUTE_SET_BREP_COMPOSITE                     
             }ExecuteSet3DRenderModeType;

struct ExecuteSet3DRenderMode{
   IGENUM   Set3DRenderModeType;
};

typedef enum {EXECUTE_SET_PERSPECTIVE,                
              EXECUTE_SET_ORTHOGRAPHIC                                   
             }ExecuteSet3DProjectionModeType;

struct ExecuteSet3DProjectionMode{
   IGENUM   Set3DProjectionModeType;
};

/*------------------------------------------------------------------------------------------------------*/
/* The following structure definitions represent the data which is passed to the client application     */
/* by way of notification messages.                                                                     */
/*------------------------------------------------------------------------------------------------------*/

typedef enum {NOTIFY_EXECUTION_RC_OK,
              NOTIFY_EXECUTION_RC_FAILED,
              NOTIFY_EXECUTION_RC_REFUSED
             }NotifyExecutionRCTypes;

struct NotifyExecutionReturn{
  IGENUM Command;
  IGENUM ReturnCode;
};

typedef struct NotifyIntegrationEnabled{
  IGBOOL bIntegrationEnabled;
}NotifyIntegrationEnabled, *pNotifyIntegrationEnabled;

struct NotifyUDMenu{
  char   Text[MAX_MENU_TEXT_SIZE];     /* The text of the menu */
  IGINT  MenuID;                       /* User defined menu ID */  
};

struct NotifySetReturnData{
  char Data[EXECUTE_SET_RETURN_DATA_SIZE];
};

typedef enum {NOTIFY_FILE_LOAD_OK, NOTIFY_FILE_LOAD_INVALID_FILE, NOTIFY_FILE_LOAD_ERROR}NotifyFileLoadedTypes;
typedef enum
{
   NOTIFY_OPENMARKUP_OK,
   NOTIFY_OPENMARKUP_INVALID_FILE,
   NOTIFY_OPENMARKUP_ERROR
} NotifyOpenMarkupTypes;

struct NotifyFileLoaded{
  char    Filename[MAX_PATH_FILENAME];
  IGENUM  LoadReturnCode;
};

typedef enum
{
   NOTIFY_FILE_CONTEXT_READ_VIEW,
   NOTIFY_FILE_CONTEXT_READ_EDIT,
   NOTIFY_FILE_CONTEXT_SAVE_EDIT
} NotifyDatabaseLookupFileContextTypes;

struct NotifyDatabaseLookup{
  char Filename[MAX_PATH_FILENAME];
  IGENUM FileContext;
};

struct NotifyDatabaseISOLookup{
  char Filename[MAX_PATH_FILENAME];
  char Lookupstring[MAX_INI_STRING_SIZE];
};

struct NotifyOpenMarkupRequest{
  IGBOOL bEdit;
  char   Filename[MAX_PATH_FILENAME];
};

struct NotifySaveAsMarkupRequest{
  IGBOOL bNew;
  char   SourceFilename[MAX_PATH_FILENAME];
  char   Filename[MAX_PATH_FILENAME];
};

struct NotifyOpenMVSRequest{
  char   Filename[MAX_PATH_FILENAME];
};

struct NotifySaveAsMVSRequest{
  char   SourceFilename[MAX_PATH_FILENAME];
  char   Filename[MAX_PATH_FILENAME];
};

struct NotifyViewSetNeedsSavingRequest{
  char   ModelFilename[MAX_PATH_FILENAME];
  char   MVSFilename[MAX_PATH_FILENAME];
  char   MVSMarkupFilename[MAX_PATH_FILENAME];
  IGINT  NumberStandardViews;
  IGINT  NumberMarkupViews;
};

struct NotifyPrint{
  char Filename[MAX_PATH_FILENAME];
  char Description[MAX_PATH_FILENAME];
};

typedef enum
{
   NOTIFY_PRINT_COMPLETE_NO_ERROR,
   NOTIFY_PRINT_COMPLETE_ERROR_CREATING_DC_WITH_SPECIFIED_PRINTER
} NotifyPrintCompleteErrorTypes;

struct NotifyPrintComplete{
  IGBOOL                  bCancelled;
  IGENUM                  ErrorType;
  IGINT                   WindowsErrorNumber;
};

struct NotifyViewportClose{
  char                    Filename[MAX_PATH_FILENAME];
};

struct NotifyOpenMarkup{
  char     Filename[MAX_PATH_FILENAME];
  IGENUM   OpenMarkupReturnCode;
};

struct NotifySaveMarkup{
   char                    Sourcename[MAX_PATH_FILENAME];
   char                    Filename[MAX_PATH_FILENAME];
};

typedef enum {NOTIFY_MARKUP_SAVED_OK, NOTIFY_MARKUP_SAVED_ERROR, NOTIFY_MARKUP_SAVED_CANCELLED}NotifyMarkupSavedTypes;

struct NotifyMarkupSaved{
   char    Sourcename[MAX_PATH_FILENAME];
   char    Filename[MAX_PATH_FILENAME];
  IGENUM  SaveReturnCode;
};

typedef enum {NOTIFY_MVS_SAVED_OK, NOTIFY_MVS_SAVED_ERROR, NOTIFY_MVS_SAVED_CANCELLED}NotifyMVSSavedTypes;

struct NotifyMVSSaved{
   char    Sourcename[MAX_PATH_FILENAME];
   char    Filename[MAX_PATH_FILENAME];
  IGENUM   SaveReturnCode;
};

typedef enum {NOTIFY_MVS_VIEW_STANDARD, NOTIFY_MVS_VIEW_MARKUP}NotifyMVSViewTypes;

struct NotifyMVSViewCreated{
   char    Sourcename[MAX_PATH_FILENAME];
   char    Viewname[MAX_DESCRIPTION_SIZE];
  IGENUM   ViewType;
};

struct NotifyCloseMarkup{
  char                    Filename[MAX_PATH_FILENAME];
};

struct NotifyCloseMVS{
  char                    Filename[MAX_PATH_FILENAME];
};

struct NotifyImageChange{
  char                    Filename[MAX_PATH_FILENAME];
};

struct NotifyGetISOString{
  IGENUM                  StringType;                   /* The type of ISO string this is ExecuteISOStringTypes */
  unsigned short          StringNumber;                 /* The index of this string within the string type         */
  char                    String[MAX_ISO_STRING_SIZE];  /* The string itself                                       */
};

struct NotifyGetLayerInfoEntry{
  unsigned short     LayerID;
  IGBOOL             bVisible;
  char               LayerName[AUTHOR_LAYER_NAME_SIZE];
  char               AuthorName[AUTHOR_LAYER_NAME_SIZE];
};

struct NotifyGetLayerInfo{
  unsigned short     NumberLayers;
  char               LayerEntryArray;   /* Used to gain addressability to layer entry array */
};

struct NotifyMouseMove{
  unsigned short     x;
  unsigned short     y;
};

struct NotifyLButtonDown{
  unsigned short     x;
  unsigned short     y;
};

struct NotifyLButtonUp{
  unsigned short     x;
  unsigned short     y;
};

struct NotifyLButtonDblClick{
  unsigned short     x;
  unsigned short     y;
};

/* for INTG_LOAD_FILEBEGIN */
typedef struct NotifyLoadFileB{
  IGINT     symbolID;
  IGINT     filehandle;
  char      filepathname[1];
}NotifyLoadFileB, *pNotifyLoadFileB;

/* for INTG_LOAD_BLOCKBEGIN */
typedef struct NotifyLoadBlockB{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
  char      blockname[1];
}NotifyLoadBlockB, *pNotifyLoadBlockB;

/* for INTG_LOAD_ATTRIBUTE */
typedef struct NotifyLoadAttrib{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
  IGINT     attribhandle;
  IGINT     blobsize;
  char      blob[1];
}NotifyLoadAttrib, *pNotifyLoadAttrib;

/* for INTG_LOAD_BLOCKEND */
typedef struct NotifyLoadBlockE{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
}NotifyLoadBlockE, *pNotifyLoadBlockE;

/* for INTG_LOAD_FILEEND */
typedef struct NotifyLoadFileE{
  IGINT     symbolID;
  IGINT     filehandle;
}NotifyLoadFileE, *pNotifyLoadFileE;

/* for INTG_DISPLAY_FILEBEGIN */
typedef struct NotifyDisplayFileB{
  IGINT     symbolID;
  IGINT     filehandle;
}NotifyDisplayFileB, *pNotifyDisplayFileB;

/* for INTG_DISPLAY_BLOCKBEGIN */
typedef struct NotifyDisplayBlockB{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
  IGINT     extents[4];
  /*
  Extents are in pixel units.
  They are offset from origin in upper-left corner of viewport.
  0 = upper-left  x
  1 = upper-left  y
  2 = lower-right x
  3 = lower-right y
  */
}NotifyDisplayBlockB, *pNotifyDisplayBlockB;

/* for INTG_DISPLAY_ATTRIBUTE */
typedef struct NotifyDisplayAttrib{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
  IGINT     attribhandle;
}NotifyDisplayAttrib, *pNotifyDisplayAttrib;

/* for INTG_DISPLAY_BLOCKEND */
typedef struct NotifyDisplayBlockE{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
}NotifyDisplayBlockE, *pNotifyDisplayBlockE;

/* for INTG_DISPLAY_FILEEND */
typedef struct NotifyDisplayFileE{
  IGINT     symbolID;
  IGINT     filehandle;
}NotifyDisplayFileE, *pNotifyDisplayFileE;

/* for INTG_LAUNCH_ATTRIBBLOCK */
typedef struct NotifyLaunchBlock{
  IGINT     symbolID;
  IGINT     filehandle;
  IGINT     blockhandle;
  IGINT     extents[4];
  /*  Extents are in the same format as they are for NotifyDisplayBlockB  */
}NotifyLaunchBlock, *pNotifyLaunchBlock;

typedef enum {
	MONOCHROME_RASTER, 
	COLOR_RASTER, 
	VECTOR, 
	TEXT
} ImageTypesEnum;

typedef struct {
  IGENUM Type;
} ImageType;

typedef enum {
    DEGREES_0,
    DEGREES_90,
    DEGREES_180,
    DEGREES_270
} OrientTypesEnum;

typedef struct {
	IGENUM Type;
} OrientType;

typedef enum {
  WINDOW_MINIMIZED,
  WINDOW_MAXIMIZED,
  WINDOW_WINDOWED
} WindowStateEnum;

typedef struct {
	IGENUM State;
} WindowState;

typedef struct {
	double WorldScale;
	char   Filename[MAX_PATH_FILENAME];
} ImageInfo, *pImageInfo;

typedef struct NotifyInquireDocument{
	double      Clip[4];                               /* current viewed area */
	double      Limits[4];                             /* limits of the document */
	char        MarkupFile[MAX_PATH_FILENAME];         /* The editable markup file if one opened, NULL if no markup opened */
  IGBOOL      MarkupChanged;                         /* If the current editable markup has been changed */
	char        Description[INQUIRE_DESCRIPTION_SIZE]; /* extracted from the folder file */	
	IGINT       DocWindowSize[4];                      /* The RECT associated with the image window */
	IGINT       DocWindowPosition[4];                  /* The device location of the window image (RECT) */
  WindowState DocWindowState;                        /* The state of the image window */
	IGINT       MyrWindowSize[4];                      /* The RECT associated with Myriad's main window */
	IGINT       MyrWindowPosition[4];                  /* The device location of Myriad's main window */
  WindowState MyrWindowState;                        /* The state of Myriad's main window */
	IGINT       NumberOfPages;                         /* The number of pages in the image */
	IGINT       ActivePage;                            /* Currently displayed page */
	ImageType   ImageType;                             /* Monochrome Raster, Color Raster, Vector, Text */
	OrientType  Orientation;                           /* Orientation (rotation)*/
	IGINT       Resolution;                            /* DPI */
	IGINT       Reserved;                              /* Four byte field for correct compiler structure padding in 16 and 32 bit environments */
	IGINT       NumberOfFiles;                         /* Number of entries in the filepath array of files */
	ImageInfo   ImageInfo[1];                          /* For all images (first entry and subsequent overlays): full path and worldscale */
} NotifyInquireDocument, *pNotifyInquireDocument;

struct ProductVersion{
  IGINT       Major;                                 /* The major number of the release */
  IGINT       Minor1;                                /* The primary minor number of the release */
  IGINT       Minor2;                                /* The secondary minor number of the release */
  IGINT       Build;                                 /* The build number of the release */
};

typedef enum {DOCUMENT_MAIN_IMAGE, DOCUMENT_READONLY_OVERLAY, DOCUMENT_EDITABLE_MARKUP}NotifyDocumentStackImageType;

typedef struct NotifyDocumentStackImage{
	char   FileName[MAX_PATH_FILENAME];                          /* The filename of the image */
  IGENUM FileType;                                             /* The file type NotifyDocumentStackImageType */
} NotifyDocumentStackImage, *pNotifyDocumentStackImage;

typedef struct NotifyDocumentStackDocument{
  char                    DocumentName[MAX_DESCRIPTION_SIZE];  /* The document name */
  IGINT                   NumberImages;                        /* The number of images contained in the document. This many
                                                                  ImageInfo structures will follow this NotifyDocumentStackDocument
                                                                  structure.
                                                               */
}NotifyDocumentStackDocument, *pNotifyDocumentStackDocument;

typedef struct NotifyInquireSystem{
   struct ProductVersion        Version;                   /* Myriad's product version */
   WindowState                  MyrWindowState;            /* The state of Myriad's main window */
   struct PrintSettings         PrintSettings;             /* The PrintSettings structure currently being used */
   char                         CurrentAuthor[AUTHOR_LAYER_NAME_SIZE]; /* The name of the current author */
   IGINT                        NumberDocumentsInStack;    /* The number of documents in the current document stack */
   NotifyDocumentStackDocument  DocumentInfo[1];           /* For every document in the current document stack */
} NotifyInquireSystem, *pNotifyInquireSystem;


typedef struct NotifyAuthorEntry{
  char                    AuthorName[AUTHOR_LAYER_NAME_SIZE]; /* The name of the author */
  IGBOOL                  bSelect;                            /* Select the author (TRUE) or deselect the author (FALSE) */
}NotifyAuthorEntry, *pNotifyAuthorEntry;

typedef struct NotifyGetAuthors{
  IGINT                   NumberAuthors;                      /* Number of NotifyAuthorEntry records */
  NotifyAuthorEntry       Authors[1];                          /* Start of array of NotifyAuthorEntry records */
}NotifyGetAuthors, *pNotifyGetAuthors;


typedef struct NotifyChangemarkViewed{
  char                    Filename[MAX_PATH_FILENAME];               /* The base (parent) file the changemark is associated with */
  char                    ChangemarkTitle[MAX_DESCRIPTION_SIZE];     /* The title of the changemark */
}NotifyChangemarkViewed, *pNotifyChangemarkViewed;

typedef struct NotifyGetChangemarksEntry{
  char                    Filename[MAX_PATH_FILENAME];                  /* The base (parent) file the changemark is associated with */
  char                    ChangemarkTitle[MAX_DESCRIPTION_SIZE];        /* The title of the changemark */
  char                    ChangemarkText[MAX_CHANGEMARK_TEXT_SIZE];     /* The text of the changemark */
  char                    ChangemarkAuthor[AUTHOR_LAYER_NAME_SIZE];     /* The author who created this changemark */
  char                    ChangemarkLayerName[AUTHOR_LAYER_NAME_SIZE];  /* The name of the layer the changemark resides on */
  IGBOOL                  bChangemarkLayerVisible;                      /* If the changemark's layer is visible */
}NotifyGetChangemarksEntry, *pNotifyGetChangemarksEntry;

typedef struct NotifyGetChangemarks{
  IGINT                         NumberChangemarks;                   /* The number of NotifyGetChangemarksEntry structures in the Changemark array */
  NotifyGetChangemarksEntry     Changemark[1];                       /* The array of NotifyGetChangemarksEntry structures, one for each changemark */
}NotifyGetChangemarks, *pNotifyGetChangemarks;

typedef struct NotifyNewMarkup{
  char                    Filename[MAX_PATH_FILENAME];               /* The base (parent) file the markup is associated with */
  char                    Authorname[AUTHOR_LAYER_NAME_SIZE];        /* The name of the author who created the markup */
  char                    Layername[AUTHOR_LAYER_NAME_SIZE];         /* The name of the layer created */
}NotifyNewMarkup, *pNotifyNewMarkup;

typedef struct NotifyRunSilentMessage{
  char                    Text[MAX_PATH_FILENAME];                   /* The message text that would appear in the message dialog */
  char                    Caption[MAX_PATH_FILENAME];                /* The message caption that would appear in the message dialog */
  IGINT                   Style;                                     /* The style parameter for the message box */
}NotifyRunSilentMessage, *pNotifyRunSilentMessage;

typedef struct Notify3DModelLoadEntity{
  IGINT                   EntityID;                                  /* The ID the entity is known by in the system */
  char                    EntityName[MAX_PATH_FILENAME];             /* The name of the component entity */
  IGINT                   NumberChildren;                            /* The number of children the entity has */
  IGBOOL                  ContainsGeometry;                          /* Whether or not the entity contains geometry */
}Notify3DModelLoadEntity, *pNotify3DModelLoadEntity;

typedef struct Notify3DModelLoaded{
  IGINT                   EntityID;                                  /* The ID the entity is known by in the system */
  char                    Filename[MAX_PATH_FILENAME];               /* The filename of the model being loaded */
  IGINT                   NumberModelEntities;                       /* The total number of Notify3DModelLoadEntity structures contained in the ModelEntities array */
  Notify3DModelLoadEntity ModelEntities[1];                          /* The array of Notify3DModelLoadEntity structures for the model */
}Notify3DModelLoaded, *pNotify3DModelLoaded;

typedef struct Notify3DComponentSelectionChanged{
  IGINT                   EntityID;                                  /* The ID the component list is known by in the system */
  char                    EntityName[MAX_PATH_FILENAME];             /* The name of the component */
  IGBOOL                  ContainsGeometry;                          /* Whether or not the component contains geometry */
  IGBOOL                  Selected;                                  /* If the component is selected */
  IGBOOL                  GeometryVisible;                           /* If the geometry for the component is visible (not hidden) */
}Notify3DComponentSelectionChanged, *pNotify3DComponentSelectionChanged;

typedef struct Notify3DComponentListEnabled{
  IGINT                   EntityID;                                  /* The ID the component list is known by in the system */
  char                    Filename[MAX_PATH_FILENAME];               /* The name of the component */
}Notify3DComponentListEnabled, *pNotify3DComponentListEnabled;

typedef enum {HTML_EXPORT_FILE_HTML, HTML_EXPORT_FILE_IMAGE, HTML_EXPORT_FILE_SUPPORT} HTMLExportFileTypes;

struct NotifyHTMLExportFileWritten{
  char                    Filename[MAX_PATH_FILENAME];
  IGENUM                  FileType;
};

typedef struct Notify3DViewSetLoadEntity{
  char                    ViewName[MAX_DESCRIPTION_SIZE];            /* The name of the view set view */
  IGENUM                  ViewType;                                  /* The NotifyMVSViewTypes for this view indicating view type */
}Notify3DViewSetLoadEntity, *pNotify3DViewSetLoadEntity;

typedef struct Notify3DViewSetLoaded{
  char                      ModelFilename[MAX_PATH_FILENAME];          /* The filename of the model the view set is being loaded against */
  char                      MVSFilename[MAX_PATH_FILENAME];            /* The filename of the view set being loaded */
  IGINT                     NumberViewEntities;                        /* The total number of Notify3DViewSetLoadEntity structures contained in the ViewSetEntities array */
  Notify3DViewSetLoadEntity ViewSetEntities[1];                        /* The array of Notify3DViewSetLoadEntity structures for the view set */
}Notify3DViewSetLoaded, *pNotify3DViewSetLoaded;

#endif /* INC_IGCINC_H */

