/***********************************************************************
**                                                                    **
**  Copyright (c) 1996 Informative Graphics Corp.                     **
**      706 E. Bell Rd.  Suite 207                                    **
**      Phoenix, AZ  85022                                            **
**                                                                    **
**      ALL RIGHTS RESERVED.                                          **
**                                                                    **
**      March 11, 1996                                                **
**                                                                    **
**      This source code can be used and distributed by ANYONE.  No   **
**      warranties of any kind are offered by Informative Graphics    **
**      as to the useability of this software.  USE AT YOUR OWN RISK! **
**                                                                    **
**  File: myrdata.h                                                   **
**  Written By: Scott Willis                                          **
**  Purpose:                                                          **
**                                                                    **
**    This module contains the data structure and routine prototype   **
**    definitions for the test application.                           **
**                                                                    **
************************************************************************/

#ifndef INC_MYRDATA_H
#define INC_MYRDATA_H
 
#include <windows.h>
#include <stdio.h>
#include <commdlg.h>
#include <string.h>
#include <ddeml.h>
#include <stdlib.h>
#include <malloc.h>
#include "myrcmd.h"
#include "myrtest.h"
#include "myrintob.h"

/* These constants are used to read the initialization file containing the 
   filenames to use for the drawing and redline files for testing purposes.
*/
#define  MYRIAD_INTEGRATION_TEST_APPLICATION      "Myriad Test Application"
#define  MYRIAD_INTEGRATION_TEST_INI              "MYRTEST.INI"
#define  MYRIAD_FFLOAD_FILENAME                   "FFLOAD_FILENAME"
#define  MYRIAD_REDLINE_FILENAME                  "REDLINE_FILENAME"
#define  MYRIAD_FFINIT_FILENAME                   "FFINIT_FILENAME"
#define  MYRIAD_DELETE_ITEM_FILENAME              "DELETE_ITEM_FILENAME"
#define  MYRIAD_SIDE_BY_SIDE_LEFT_FILENAME        "SIDE_BY_SIDE_LEFT_FILENAME"
#define  MYRIAD_SIDE_BY_SIDE_RIGHT_FILENAME       "SIDE_BY_SIDE_RIGHT_FILENAME"
#define  MYRIAD_EXPORT_FILENAME                   "EXPORT_FILENAME"
#define  MYRIAD_AUTHOR_NAME                       "MYAUTHORNAME"
#define  MYRIAD_LAYER_NAME                        "My Layer Name"
#define  MYRIAD_INTOBJ                            "Intelligent Objects"
#define  MYRIAD_TAGSIZE                           "TAGsize"

#define  FFLOAD_FILENAME                          "TEST.DWG"
#define  FFINIT_FILENAME                          "TEST.DSF"
#define  FFLOAD_REDLINE_FILENAME                  "TEST.MRK"
#define  DELETE_ITEM_FILENAME                     "TEST.DWG"
#define  SIDE_BY_SIDE_FILENAME                    "TEST.DWG"
#define  EXPORT_FILENAME                          "TEST.XXX"
#define  SET_RETURN_DATA_TEST_STRING              "** This the test string for set_return_data **"

#define PROCESS_MVS_SERIES_STEP_MESSAGE          (WM_USER+6369)

typedef enum {IntgExMain, IntgExPopup} IntExMenuType;

typedef enum 
{
   // CSMVS = "Command Series MVS"
   CSMVS_SERIES_NOT_RUNNING = 0,
   CSMVS_LOAD_ASM_FILE     = 1,
   CSMVS_NEWVIEW_TOP       = 2,
   CSMVS_SETVIEW_TOP       = 3,
   CSMVS_NEWVIEW_BOTTOM    = 4,
   CSMVS_SETVIEW_BOTTOM    = 5,
   CSMVS_NEWVIEW_LEFT      = 6,
   CSMVS_SETVIEW_LEFT      = 7,
   CSMVS_NEWVIEW_RIGHT     = 8,
   CSMVS_SETVIEW_RIGHT     = 9,
   CSMVS_NEWVIEW_FRONT     = 10,
   CSMVS_SETVIEW_FRONT     = 11,
   CSMVS_NEWVIEW_BACK      = 12,
   CSMVS_SETVIEW_BACK      = 13,
   CSMVS_NEWVIEW_ISOMETRIC = 14,
   CSMVS_SETVIEW_ISOMETRIC = 15,
   CSMVS_NEWVIEW_DIMETRIC  = 16,
   CSMVS_SETVIEW_DIMETRIC  = 17,
   CSMVS_NEWVIEW_TRIMETRIC = 18,
   CSMVS_SETVIEW_TRIMETRIC = 19,
   CSMVS_SAVE_VIEWSET      = 20
} CSMVS_Type;

long FAR PASCAL WndProc(HWND, unsigned, WORD, LONG);
void WriteOutputLine(char *outline);
void PrintLine(char *outline);
void PrintBlankLine(void);
void PaintWindow(void);
void FreeOutputLines(void);
int  FindMaxLines(void);
void DumpDisplay(void);
void GetFilenames(void);

void doAlternateView(BOOL bUseCommandString);
void doClip(BOOL bUseCommandString, ExecuteClipTypes cType);
void doCloseAll(BOOL bUseCommandString);
void doCloseMarkup(BOOL bUseCommandString);
void doCloseSession(BOOL bUseCommandString);
void doDeleteItem(BOOL bUseCommandString);
void doDisableAltview(BOOL bUseCommandString, BOOL bDisableView);
void doFolderClear(BOOL bUseCommandString);
void doFolderInit(BOOL bUseCommandString);
void doFolderLoad(BOOL bUseCommandString);
void doInvertColors(BOOL bUseCommandString);
void doLockWindow(BOOL bUseCommandString, BOOL bLock);
void doNewMarkup(BOOL bUseCommandString);
void doOpenMarkup(BOOL bUseCommandString);
void doPage(BOOL bUseCommandString, ExecutePageTypes pType);
void doPanDisplacement(BOOL bUseCommandString);
void doPrintViewport(BOOL bUseCommandString, ExecutePrintTypes pType);
void doRaster(BOOL bUseCommandString, ExecuteRasterTypes rType);
void doRepaint(BOOL bUseCommandString);
void doRotate(BOOL bUseCommandString, ExecuteRotateTypes rType);
void doSaveMarkup(BOOL bUseCommandString);
void doSetFrameWindow(BOOL bUseCommandString);
void doSetMarkupColor(BOOL bUseCommandString);
void doSetReturnData(BOOL bUseCommandString, ExecuteSetReturnDataTypes sType);
void doToggleToolbar(BOOL bUseCommandString);
void doWindow(BOOL bUseCommandString, ExecuteWindowTypes wType);
void doMainWindow(BOOL bUseCommandString, ExecuteMainWindowTypes wType);
void doZoom(BOOL bUseCommandString, ExecuteZoomTypes zType);
void doEnableColorSelection(BOOL bUseCommandString, BOOL bEnable);
void doSetAuthorName(BOOL bUseCommandString);
void doSetLayerName(BOOL bUseCommandString);
void doGetLayerInfo(BOOL bUseCommandString);
void doEnableMenuItem(BOOL bUseCommandString, BOOL bEnable);
void doEnableDocModify(BOOL bUseCommandString, BOOL bEnable);
void doRemoveMenu(BOOL bUseCommandString, ExecuteRemoveMenuTypes rType);
void doSetNotifications(BOOL bUseCommandStirng, NotificationRequestType nType);
void doRedlineTool(BOOL bUseCommandString);
void doAuthorTool(BOOL bUseCommandString);
void doEyeGlassTool(BOOL bUseCommandString);
void doBirdsEyeTool(BOOL bUseCommandString);
void doChangeMarkTool(BOOL bUseCommandString);
void doDocstackTool(BOOL bUseCommandString);
void doSelectTool(BOOL bUseCommandString);
void doZoomTool(BOOL bUseCommandString);
void doPreviousDoc(BOOL bUseCommandString);
void doNextDoc(BOOL bUseCommandString);
void doMonochrome(BOOL bUseCommandString, BOOL bEnable);
void doRedlineChangeMark(BOOL bUseCommandString, BOOL bEnable);
void doSideBySide(BOOL bUseCommandString);
void doSetISOString(BOOL bUseCommandString);
void doGetISOString(BOOL bUseCommandString);
void doSetDocumentFocus(BOOL bUseCommandString);
void doSetFocus(BOOL bUseCommandString);
void doAddUDMenu(BOOL bUseCommandString, ExecuteUDMenuLocationTypes lType, ExecuteUDMenuTypes tType);
void doRemoveUDMenu(BOOL bUseCommandString, ExecuteUDMenuLocationTypes);
void doClearUDMenu(BOOL bUseCommandString);
void doEnableUDMenu(BOOL bUseCommandString, ExecuteUDMenuLocationTypes, BOOL bEnable);
void doAddUDMainMenuItem(BOOL bUseCommandString);
void doRemoveUDMainMenuItem(BOOL bUseCommandString);
void doSetOnTop(BOOL bUseCommandString, BOOL bAlwaysOnTop);
void doExportToFile(BOOL bUseCommandString, ExecuteExportTypes tType);
void doInquireDocument(BOOL bUseCommandString);
void doInquireSystem(BOOL bUseCommandString);
void doGetAuthors(BOOL bUseCommandString);
void doGetChangemarks(BOOL bUseCommandString);
void doViewChangemark(BOOL bUseCommandString);
void doFileOpenTool(BOOL bUseCommandString);
void doDisplayISOTool(BOOL bUseCommandString);
void doPrintDocstack(BOOL bUseCommandString);
void doRunSilent(BOOL bUseCommandString, BOOL bRunSilent);
void doOpenDocstack(BOOL bUseCommandString);

void doSeriesMVS(void);
void ProcessCSMVSStep(void);

void doSetServerName(void);
void doGetServerName(void);
void doGetTopicName(void);
void doGetItemName(void);
void doOnetimeCommand(BOOL bStartMyriad);
void doOnetimeString(BOOL bStartMyriad);
BOOL connectToMyriad(BOOL bStartMyriad);

/* The following structure is used to maintain the output lines in the client area */

struct OutputLineRecord{
    struct OutputLineRecord  *Next;
    char                     *Line;
};

void NotifyCallbackHandler(struct NotifyCallbackRecord *pCallbackRecord);
void HandleExecutionReturnPrint(void *pData);
void HandleMouseMovePrint(void *pData);
void HandleLButtonDownPrint(void *pData);
void HandleLButtonUpPrint(void *pData);
void HandleLButtonDblClickPrint(void *pData);
void HandleExitPrint(void *pData);
void HandleLoadFileBeginPrint(void *pData);
void HandleLoadBlockBeginPrint(void *pData);
void HandleLoadAttributePrint(void *pData);
void HandleLoadBlockEndPrint(void *pData);
void HandleLoadFileEndPrint(void *pData);
void HandleDisplayFileBeginPrint(void *pData);
void HandleDisplayBlockBeginPrint(void *pData);
void HandleDisplayAttributePrint(void *pData);
void HandleDisplayBlockEndPrint(void *pData);
void HandleDisplayFileEndPrint(void *pData);
void HandleLaunchAttribBlockPrint(void *pData);
void HandleSetReturnDataPrint(void *pData);
void HandleFileLoadedPrint(void *pData);
void HandleViewportClosePrint(void *pData);
void HandleNewMarkupPrint(void *pData);
void HandleOpenMarkupPrint(void *pData);
void HandleSaveMarkupPrint(void *pData);
void HandleMarkupSavedPrint(void *pData);
void HandleMVSSavedPrint(void *pData);
void HandleCloseMarkupPrint(void *pData);
void HandleImageChangePrint(void *pData);
void HandleGetLayerInfoPrint(void *pData);
void HandleGetISOStringPrint(void *pData);
void HandleDatabaseLookupPrint(void *pData);
void HandleNotifyPrintPrint(void *pData);
void HandleNotifyPrintPrintComplete(void *pData);
void HandleNotifyUDMenuPrint(void *pData);
void HandleInquireDocumentPrint(void *pData);
void HandleInquireSystemPrint(void *pData);
void HandleOpenMarkupRequestPrint(void *pData);
void HandleSaveAsMarkupRequestPrint(void *pData);
void HandleSaveAsMVSRequestPrint(void *pData);
void HandleGetAuthorsPrint(void *pData);
void HandleChangemarkViewedPrint(void *pData);
void HandleGetChangemarksPrint(void *pData);
void HandleISODisplayPrint(void *pData);
void HandleISOEditPrint(void *pData);
void HandleRunSilentMsgPrint(void *pData);
void HandleIntegrationEnabledPrint(void *pData);
void HandleModelLoaded(void *pData);
void HandleComponentSelectionChanged(void *pData);
void HandleComponentListEnabled(void *pData);
void HandleMVSViewCreated(void *pData);
void Handle3DViewSetLoadedCreated(void *pData);
void HandleViewSetNeedsSaving(void *pData);

#endif /* INC_MYRDATA_H */
