/***********************************************************************
**                                                                    **
**  Copyright (c) 1996 Informative Graphics Corp.                     **
**      706 E. Bell Rd.  Suite 207                                    **
**      Phoenix, AZ  85022                                            **
**                                                                    **
**      ALL RIGHTS RESERVED.                                          **
**                                                                    **
**      March 11, 1996                                                **
**                                                                    **
**      This source code can be used and distributed by ANYONE.  No   **
**      warranties of any kind are offered by Informative Graphics    **
**      as to the useability of this software.  USE AT YOUR OWN RISK! **
**                                                                    **
**  File: myrexec.c                                                   **
**  Written By: Scott Willis                                          **
**  Purpose:                                                          **
**                                                                    **
**     This module contains the calls to the API routines for the     **
**     Myriad integration. Each routine handles both the string and   **
**     structure form of the commands.                                **
**                                                                    **
************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "myrdata.h"
#include "resource.h"

extern HWND hWnd;
extern char pDrawingFilename[MAX_STRING];
extern char pFolderFilename[MAX_STRING];
extern char pRedlineFilename[MAX_STRING];
extern char pDeleteItemFilename[MAX_STRING];
extern char pSideBySideLeftFilename[MAX_STRING];
extern char pSideBySideRightFilename[MAX_STRING];
extern char pExportFilename[MAX_STRING];
extern CSMVS_Type mvs_series_step;

LRESULT WINAPI ISODlgProc(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam);

/* These routines perform the execution of Myriad integration commands */
BOOL OpenDlg(LPSTR pszFileName, LPCTSTR lpTitle) 
{ 
BOOL fGotName; 
OPENFILENAME ofn;
   pszFileName[0] = '\0'; 

   memset(&ofn, 0, sizeof(ofn));

   ofn.lStructSize = sizeof(OPENFILENAME); 
   ofn.lpstrTitle = lpTitle;
   ofn.lpstrFile = pszFileName; 
   ofn.nMaxFile = MAX_STRING; 
   ofn.Flags = OFN_HIDEREADONLY | OFN_FILEMUSTEXIST; 

   fGotName = GetOpenFileName(&ofn); 
   
   return fGotName; 
} 

void doSetServerName(void)
{
   char outstring[MAX_STRING];

   if(SetServerName(MYRIAD_DDE_SERVICE_NAME)){
      sprintf(outstring, "Set of server name to %s succeeded.", MYRIAD_DDE_SERVICE_NAME);
   }else{
      sprintf(outstring, "Set of server name to %s failed.", MYRIAD_DDE_SERVICE_NAME);
   }

   PrintLine(outstring);
}

void doGetServerName(void)
{
   char outstring[MAX_STRING];
   char tempstring[MAX_STRING];

   strcpy(outstring, "Server name : ");

   GetServerName(tempstring, MAX_STRING);

   if(tempstring[0] != 0){
      strcat(outstring, tempstring);
      PrintLine(outstring);
   }else{
      PrintLine("There is no Server name.");
   }
}

void doGetTopicName(void)
{
   char outstring[MAX_STRING];
   char tempstring[MAX_STRING];

   strcpy(outstring, "Topic name : ");

   GetTopicName(tempstring, MAX_STRING);

   if(tempstring[0] != 0){
      strcat(outstring, tempstring);
      PrintLine(outstring);
   }else{
      PrintLine("There is no Topic name.");
   }
}

void doGetItemName(void)
{
   char outstring[MAX_STRING];
   char tempstring[MAX_STRING];

   strcpy(outstring, "Item name : ");

   GetItemName(tempstring, MAX_STRING);

   if(tempstring[0] != 0){
      strcat(outstring, tempstring);
      PrintLine(outstring);
   }else{
      PrintLine("There is no Item name.");
   }
}

void doEnableMenuItem(BOOL bUseCommandString, BOOL bEnable)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteEnableMenuItem Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   // For our example, we will enable/disable the document stack string 

   if(bUseCommandString){
      PrintLine("Sending Enable Menu Item string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "enable_menu_item(EXECUTE_EMENU_DOCSTACK, ");

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Enable Menu Item succeeded.");
     }else{
         PrintLine("--> Enable Menu Item failed.");
     }
  }else{
     PrintLine("Sending Enable Menu Item command to Myriad...");

     Data.Menu = EXECUTE_EMENU_DOCSTACK;
     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_ENABLEMENUITEM, &Data)){
        PrintLine("--> Enable Menu Item succeeded.");
     }else{
        PrintLine("--> Enable Menu Item failed.");
     }
  }
}

void doEnableDocModify(BOOL bUseCommandString, BOOL bEnable)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteEnableDocModify Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   // For our example, we will enable/disable the document stack string 

   if(bUseCommandString){
      PrintLine("Sending Enable Document Stack Modify string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "enable_doc_modify(");

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Enable Document Stack Modify succeeded.");
     }else{
         PrintLine("--> Enable Document Stack Modify failed.");
     }
  }else{
     PrintLine("Sending Enable Document Stack Modify command to Myriad...");

     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_ENABLEDOCMODIFY, &Data)){
        PrintLine("--> Enable Document Stack Modify succeeded.");
     }else{
        PrintLine("--> Enable Document Stack Modify failed.");
     }
  }
}

void doRunSilent(BOOL bUseCommandString, BOOL bRunSilent)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRunSilent Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   // For our example, we will enable/disable the document stack string 

   if(bUseCommandString){
      PrintLine("Sending Run Silent Item string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "run_silent(");

     if(bRunSilent){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Run Silent Item succeeded.");
     }else{
         PrintLine("--> Run Silent Item failed.");
     }
  }else{
     PrintLine("Sending Run Silent Item command to Myriad...");

     Data.bRunSilent = bRunSilent;

     if(ProcessExecutionCommand(INTG_EXECUTE_RUNSILENT, &Data)){
        PrintLine("--> Run Silent Item succeeded.");
     }else{
        PrintLine("--> Run Silent Item failed.");
     }
  }
}

void doSideBySide(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteSideBySide Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
      PrintLine("Sending Side By Side string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "side_by_side(");
     strcat(ExecutionString, pSideBySideLeftFilename);
     strcat(ExecutionString, ", ");
     strcat(ExecutionString, pSideBySideRightFilename);
     strcat(ExecutionString, ", FALSE");
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Side By Side succeeded.");
     }else{
         PrintLine("--> Side By Side failed.");
     }
  }else{
     PrintLine("Sending Side By Side command to Myriad...");

     strcpy(Data.LeftFilename, pSideBySideLeftFilename);
     strcpy(Data.RightFilename, pSideBySideRightFilename);
     Data.bOpenOriginals = FALSE;

     if(ProcessExecutionCommand(INTG_EXECUTE_SIDEBYSIDE, &Data)){
        PrintLine("--> Side By Side succeeded.");
     }else{
        PrintLine("--> Side By Side failed.");
     }
  }
}

void doSetISOString(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteSetISOString Data;
   int nRet;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
      PrintLine("Sending Set ISO String string to Myriad...");

      // Setup the execution string for the ISO top center string number 1 (first string)
     strcpy(ExecutionString, "set_iso_string(EXECUTE_ISO_TOPCENTER, 1, This is a test print string)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set ISO String succeeded.");
     }else{
         PrintLine("--> Set ISO String failed.");
     }
  }else{
      if((nRet=DialogBoxParam((HINSTANCE)GetWindowLong(hWnd, GWL_HINSTANCE), MAKEINTRESOURCE(IDD_SET_ISO_BANNSER),
            hWnd, (DLGPROC)ISODlgProc, (LPARAM)&Data))==IDOK)
      {
         PrintLine("Sending Set ISO String command to Myriad...");
         if(ProcessExecutionCommand(INTG_EXECUTE_SETISOSTRING, &Data)){
           PrintLine("--> Set ISO String succeeded.");
         }else{
           PrintLine("--> Set ISO String failed.");
         }
      }
  }
}

void doGetISOString(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteGetISOString Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
      PrintLine("Sending Get ISO String string to Myriad...");

      // Setup the execution string for the ISO top center string number 1 (first string)
     strcpy(ExecutionString, "get_iso_string(EXECUTE_ISO_TOPCENTER, 1)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Get ISO String succeeded.");
     }else{
         PrintLine("--> Get ISO String failed.");
     }
  }else{
     PrintLine("Sending Get ISO String command to Myriad...");

     Data.StringType   = EXECUTE_ISO_TOPCENTER;              /* Put the string in the top center of the print */
     Data.StringNumber = 1;                                  /* The first string for top center               */

     if(ProcessExecutionCommand(INTG_EXECUTE_GETISOSTRING, &Data)){
        PrintLine("--> Get ISO String succeeded.");
     }else{
        PrintLine("--> Get ISO String failed.");
     }
  }
}

void doGetAuthors(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
     PrintLine("Sending Get Authors String string to Myriad...");

     strcpy(ExecutionString, "get_authors()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Get Authors String succeeded.");
     }else{
         PrintLine("--> Get Authors String failed.");
     }
  }else{
     PrintLine("Sending Get Authors String command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_GETAUTHORS, NULL)){
        PrintLine("--> Get Authors String succeeded.");
     }else{
        PrintLine("--> Get Authors String failed.");
     }
  }
}

void doSetFocus(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
      PrintLine("Sending Set Focus string to Myriad...");

      // Setup the execution string for the ISO top center string number 1 (first string)
     strcpy(ExecutionString, "set_focus()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Focus succeeded.");
     }else{
         PrintLine("--> Set Focus failed.");
     }
  }else{
     PrintLine("Sending Set Focus command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_SET_FOCUS, NULL)){
        PrintLine("--> Set Focus succeeded.");
     }else{
        PrintLine("--> Set Focus failed.");
     }
  }
}


void doSetDocumentFocus(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSetDocumentFocus Data;

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   strcpy( Data.Filename, pDrawingFilename );

   if(bUseCommandString){
      PrintLine("Sending Set Doc Focus string to Myriad...");

     sprintf(ExecutionString, "set_document_focus(%s)", pDrawingFilename);

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Doc Focus succeeded.");
     }else{
         PrintLine("--> Set Doc Focus failed.");
     }
  }else{
     PrintLine("Sending Set Doc Focus command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_SETDOCUMENTFOCUS, &Data)){
        PrintLine("--> Set Doc Focus succeeded.");
     }else{
        PrintLine("--> Set Doc Focus failed.");
     }
  }
}


void doRedlineTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Redline Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "redline_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Redline Tool succeeded.");
     }else{
         PrintLine("--> Redline Tool failed.");
     }
  }else{
     PrintLine("Sending Redline Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_REDLINETOOL, NULL)){
        PrintLine("--> Redline Tool succeeded.");
     }else{
        PrintLine("--> Redline Tool failed.");
     }
  }
}

void doAuthorTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Author Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "author_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Author Tool succeeded.");
     }else{
         PrintLine("--> Author Tool failed.");
     }
  }else{
     PrintLine("Sending Author Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_AUTHORTOOL, NULL)){
        PrintLine("--> Author Tool succeeded.");
     }else{
        PrintLine("--> Author Tool failed.");
     }
  }
}

void doDisplayISOTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Display ISO Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "display_iso_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Display ISO Tool succeeded.");
     }else{
         PrintLine("--> Display ISO Tool failed.");
     }
  }else{
     PrintLine("Sending Display ISO Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_DISPLAYISOTOOL, NULL)){
        PrintLine("--> Display ISO Tool succeeded.");
     }else{
        PrintLine("--> Display ISO Tool failed.");
     }
  }
}

void doBirdsEyeTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Birds Eye Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "birdseye_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Birds Eye Tool succeeded.");
     }else{
         PrintLine("--> Birds Eye Tool failed.");
     }
  }else{
     PrintLine("Sending Birds Eye Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_BIRDSEYETOOL, NULL)){
        PrintLine("--> Birds Eye Tool succeeded.");
     }else{
        PrintLine("--> Birds Eye Tool failed.");
     }
  }
}

void doEyeGlassTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Eye Glass Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "eyeglass_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Eye Glass Tool succeeded.");
     }else{
         PrintLine("--> Eye Glass Tool failed.");
     }
  }else{
     PrintLine("Sending Eye Glass Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_EYEGLASSTOOL, NULL)){
        PrintLine("--> Eye Glass Tool succeeded.");
     }else{
        PrintLine("--> Eye Glass Tool failed.");
     }
  }
}

void doChangeMarkTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Change Mark Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "changemark_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Change Mark Tool succeeded.");
     }else{
         PrintLine("--> Change Mark Tool failed.");
     }
  }else{
     PrintLine("Sending Change Mark Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_CHANGEMARKTOOL, NULL)){
        PrintLine("--> Change Mark Tool succeeded.");
     }else{
        PrintLine("--> Change Mark Tool failed.");
     }
  }
}

void doDocstackTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Document Stack Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "docstack_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Document Stack Tool succeeded.");
     }else{
         PrintLine("--> Document Stack Tool failed.");
     }
  }else{
     PrintLine("Sending Document Stack Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_DOCSTACKTOOL, NULL)){
        PrintLine("--> Document Stack Tool succeeded.");
     }else{
        PrintLine("--> Document Stack Tool failed.");
     }
  }
}

void doFileOpenTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteFileOpenTool Data;

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending File Open Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "fileopen_tool(EXECUTE_FILEOPEN_IMAGE)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> File Open Tool succeeded.");
     }else{
         PrintLine("--> File Open Tool failed.");
     }
  }else{
     
     Data.FileOpenType = EXECUTE_FILEOPEN_IMAGE;

     PrintLine("Sending File Open Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_FILEOPENTOOL, &Data)){
        PrintLine("--> File Open Tool succeeded.");
     }else{
        PrintLine("--> File Open Tool failed.");
     }
  }
}

void doSelectTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Select Tool string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "select_tool()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Select Tool succeeded.");
     }else{
         PrintLine("--> Select Tool failed.");
     }
  }else{
     PrintLine("Sending Select Tool command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_SELECTTOOL, NULL)){
        PrintLine("--> Select Tool succeeded.");
     }else{
        PrintLine("--> Select Tool failed.");
     }
  }
}

void doZoomTool(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Zoom Tool string to Myriad...");

      // Setup the execution string
      strcpy(ExecutionString, "zoom_tool()");

      if(ProcessExecutionString(ExecutionString)){
          PrintLine("--> Zoom Tool succeeded.");
      }else{
          PrintLine("--> Zoom Tool failed.");
      }
   }else{
      PrintLine("Sending Zoom Tool command to Myriad...");

      if(ProcessExecutionCommand(INTG_EXECUTE_ZOOMTOOL, NULL)){
         PrintLine("--> Zoom Tool succeeded.");
      }else{
         PrintLine("--> Zoom Tool failed.");
      }
   }
}

void doPreviousDoc(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Previous Document string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "previous_doc()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Previous Document succeeded.");
     }else{
         PrintLine("--> Previous Document failed.");
     }
  }else{
     PrintLine("Sending Previous Document command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_PREVIOUSDOC, NULL)){
        PrintLine("--> Previous Document succeeded.");
     }else{
        PrintLine("--> Previous Document failed.");
     }
  }
}

void doNextDoc(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Next Document string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "next_doc()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Next Document succeeded.");
     }else{
         PrintLine("--> Next Document failed.");
     }
  }else{
     PrintLine("Sending Next Document command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_NEXTDOC, NULL)){
        PrintLine("--> Next Document succeeded.");
     }else{
        PrintLine("--> Next Document failed.");
     }
  }
}

void doRemoveMenu(BOOL bUseCommandString, ExecuteRemoveMenuTypes rType)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRemoveMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Remove Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "remove_menu(");  

     switch(rType){
        case EXECUTE_REMOVE_MENU_FILE:    strcat(ExecutionString, "EXECUTE_REMOVE_MENU_FILE");break;
        case EXECUTE_REMOVE_MENU_EDIT:    strcat(ExecutionString, "EXECUTE_REMOVE_MENU_EDIT");break;
        case EXECUTE_REMOVE_MENU_VIEW:    strcat(ExecutionString, "EXECUTE_REMOVE_MENU_VIEW");break;
        case EXECUTE_REMOVE_MENU_REDLINE: strcat(ExecutionString, "EXECUTE_REMOVE_MENU_REDLINE");break;
        case EXECUTE_REMOVE_MENU_TOOLS:   strcat(ExecutionString, "EXECUTE_REMOVE_MENU_TOOLS");break;
        case EXECUTE_REMOVE_MENU_WINDOW:  strcat(ExecutionString, "EXECUTE_REMOVE_MENU_WINDOW");break;
        case EXECUTE_REMOVE_MENU_HELP:    strcat(ExecutionString, "EXECUTE_REMOVE_MENU_HELP");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Remove Menu succeeded.");
     }else{
         PrintLine("--> Remove Menu failed.");
     }
  }else{
     PrintLine("Sending Remove Menu command to Myriad...");

     Data.RemoveMenu = rType; 
     
     if(ProcessExecutionCommand(INTG_EXECUTE_REMOVEMENU, &Data)){
        PrintLine("--> Remove Menu succeeded.");
     }else{
        PrintLine("--> Remove Menu failed.");
     }
  }
}

void doAddUDMenu(BOOL bUseCommandString, ExecuteUDMenuLocationTypes lType, ExecuteUDMenuTypes tType)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteAddUDMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Add User-Defined Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "add_ud_menu(");  

     switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP: strcat(ExecutionString, "EXECUTE_UD_MENU_MAIN_STARTUP");break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW: strcat(ExecutionString, "EXECUTE_UD_MENU_MAIN_DOC_VIEW");break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:  strcat(ExecutionString, "EXECUTE_UD_MENU_RIGHT_POPUP");break;
     }

     strcat(ExecutionString, ", ");

     switch(tType){
        case EXECUTE_UD_MENU_MENU:         strcat(ExecutionString, "EXECUTE_UD_MENU_MENU");break;
        case EXECUTE_UD_MENU_SUBMENU:      strcat(ExecutionString, "EXECUTE_UD_MENU_SUBMENU");break;
        case EXECUTE_UD_MENU_MENUITEM:     strcat(ExecutionString, "EXECUTE_UD_MENU_MENUITEM");break;
        case EXECUTE_UD_MENU_SEPARATOR:    strcat(ExecutionString, "EXECUTE_UD_MENU_SEPARATOR");break;
     }
   
	  switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP:  strcat(ExecutionString, ", \"My Main Item\", 100, 2)");break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW: strcat(ExecutionString, ", \"My Main Item\", 110, 2)");break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:   strcat(ExecutionString, ", \"My Popup Item\",  0)");break;
     }
		  
     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Add User-Defined Menu succeeded.");
     }else{
         PrintLine("--> Add User-Defined Menu failed.");
     }
  }else{
     PrintLine("Sending Add User-Defined Menu command to Myriad...");

     Data.MenuLocation = lType; 
     Data.MenuType = tType; 
	  switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP:         
				strcpy(Data.Text, "My Main Item");
				Data.MenuID = 100;
				break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW:         
				strcpy(Data.Text, "My Main Item");
				Data.MenuID = 110;
				break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:  
				strcpy(Data.Text, "My Popup Item");
			   Data.MenuID   = 0; 
				break;
     }
	  Data.MenuOffset = 2;
     
     Data.ParentID = EXECUTE_UD_MENU_NULL_PARENT;
     
     if(ProcessExecutionCommand(INTG_EXECUTE_ADDUDMENU, &Data)){
        PrintLine("--> Add User-Defined Menu succeeded.");
     }else{
        PrintLine("--> Add User-Defined Menu failed.");
     }
  }
}

void doRemoveUDMenu(BOOL bUseCommandString, ExecuteUDMenuLocationTypes lType)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRemoveUDMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Remove User-Defined Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "remove_ud_menu(");  
	  switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP:         
				strcat(ExecutionString, "100)");
				break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW:         
				strcat(ExecutionString, "110)");
				break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:  
				strcat(ExecutionString, "0)");
				break;
     }

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Remove User-Defined Menu succeeded.");
     }else{
         PrintLine("--> Remove User-Defined Menu failed.");
     }
  }else{
     PrintLine("Sending Remove User-Defined Menu command to Myriad...");
	  switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP:         
				Data.MenuID = 100;
				break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW:         
				Data.MenuID = 110;
				break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:  
			   Data.MenuID   = 0; 
				break;
     }

     if(ProcessExecutionCommand(INTG_EXECUTE_REMOVEUDMENU, &Data)){
        PrintLine("--> Remove User-Defined Menu succeeded.");
     }else{
        PrintLine("--> Remove User-Defined Menu failed.");
     }
  }
}

void doClearUDMenu(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Clear User-Defined Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "clear_ud_menu()");  

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Clear User-Defined Menu succeeded.");
     }else{
         PrintLine("--> Clear User-Defined Menu failed.");
     }
  }else{
     PrintLine("Sending Clear User-Defined Menu command to Myriad...");
     
     if(ProcessExecutionCommand(INTG_EXECUTE_CLEARUDMENU, NULL)){
        PrintLine("--> Clear User-Defined Menu succeeded.");
     }else{
        PrintLine("--> Clear User-Defined Menu failed.");
     }
  }
}

void doEnableUDMenu(BOOL bUseCommandString,  ExecuteUDMenuLocationTypes lType, BOOL bEnable)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteEnableUDMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   // For our example, we will enable/disable the document stack string 

   if(bUseCommandString){
      PrintLine("Sending Enable UD Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "enable_ud_menu(0, ");
	  switch(lType){
        case EXECUTE_UD_MENU_MAIN_STARTUP:         
			   strcpy(ExecutionString, "enable_ud_menu(100, ");
				break;
        case EXECUTE_UD_MENU_MAIN_DOC_VIEW:         
			   strcpy(ExecutionString, "enable_ud_menu(110, ");
				break;
        case EXECUTE_UD_MENU_RIGHT_POPUP:  
				strcpy(ExecutionString, "enable_ud_menu(0, ");
				break;
     }

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Enable UD Menu succeeded.");
     }else{
         PrintLine("--> Enable UD Menu failed.");
     }
  }else{
     PrintLine("Sending Enable UD Menu command to Myriad...");

		switch(lType){
			case EXECUTE_UD_MENU_MAIN_STARTUP:         
				Data.MenuID = 100;
				break;
			case EXECUTE_UD_MENU_MAIN_DOC_VIEW:         
				Data.MenuID = 110;
				break;
			case EXECUTE_UD_MENU_RIGHT_POPUP:  
				Data.MenuID = 0;
				break;
		}

     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_ENABLEUDMENU, &Data)){
        PrintLine("--> Enable UD Menu succeeded.");
     }else{
        PrintLine("--> Enable UD Menu failed.");
     }
  }
}

void doAddUDMainMenuItem(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteAddUDMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Add User-Defined Main Menu Item string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "add_ud_menu(EXECUTE_UD_MENU_MAIN_STARTUP, EXECUTE_UD_MENU_MENUITEM, \"Menu Item 1\", 101, 0, 100)");  


     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Add User-Defined Main Menu Item succeeded.");
     }else{
         PrintLine("--> Add User-Defined Main Menu Item failed.");
     }
  }else{
     PrintLine("Sending Add User-Defined Main Menu Item command to Myriad...");

     Data.MenuLocation = EXECUTE_UD_MENU_MAIN_STARTUP; 
     Data.MenuType = EXECUTE_UD_MENU_MENUITEM; 
	  strcpy(Data.Text, "Menu Item 1");
	  Data.MenuID = 101;
     Data.ParentID = 100;
     
     if(ProcessExecutionCommand(INTG_EXECUTE_ADDUDMENU, &Data)){
        PrintLine("--> Add User-Defined Main Menu Item succeeded.");
     }else{
        PrintLine("--> Add User-Defined Main Menu Item failed.");
     }
  }
}

void doRemoveUDMainMenuItem(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRemoveUDMenu Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Remove User-Defined Main Menu string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "remove_ud_menu(101)");  


     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Remove User-Defined Main Menu Item succeeded.");
     }else{
         PrintLine("--> Remove User-Defined Main Menu Item failed.");
     }
  }else{
     PrintLine("Sending Remove User-Defined Main Menu Item command to Myriad...");

	  Data.MenuID = 101;
     
     if(ProcessExecutionCommand(INTG_EXECUTE_REMOVEUDMENU, &Data)){
        PrintLine("--> Remove User-Defined Main Menu Item succeeded.");
     }else{
        PrintLine("--> Remove User-Defined Main Menu Item failed.");
     }
  }
}

void doAlternateView(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Alternate View string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "alt_view()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Alternate View succeeded.");
     }else{
         PrintLine("--> Alternate View failed.");
     }
  }else{
     PrintLine("Sending Alternate View command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_ALTERNATEVIEW, pData)){
        PrintLine("--> Alternate View succeeded.");
     }else{
        PrintLine("--> Alternate View failed.");
     }
  }
}

void doClip(BOOL bUseCommandString, ExecuteClipTypes cType)
{
   char                ExecutionString[MAX_STRING];
   struct ExecuteClip  Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Clip string to Myriad...");

      // Setup the execution string
      strcpy(ExecutionString, "clip(");

      switch(cType){
        case EXECUTE_CLIP_ALL: strcat(ExecutionString, "EXECUTE_CLIP_ALL");break;
        case EXECUTE_CLIP_ASK: strcat(ExecutionString, "EXECUTE_CLIP_ASK");break;
      }

      strcat(ExecutionString, ")");

      if(ProcessExecutionString(ExecutionString)){
          PrintLine("--> Clip succeeded.");
      }else{
          PrintLine("--> Clip failed.");
      }
  }else{
     PrintLine("Sending Clip command to Myriad...");

     Data.ClipType = cType;

     if(ProcessExecutionCommand(INTG_EXECUTE_CLIP, &Data)){
        PrintLine("--> Clip succeeded.");
     }else{
        PrintLine("--> Clip failed.");
     }
  }
}

void doCloseAll(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Close All string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "close_all()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Close All succeeded.");
     }else{
         PrintLine("--> Close All failed.");
     }
  }else{
     PrintLine("Sending Close All command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_CLOSEALL, pData)){
        PrintLine("--> Close All succeeded.");
     }else{
        PrintLine("--> Close All failed.");
     }
  }
}

void doCloseMarkup(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Close Markup string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "close_markup()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Close Markup succeeded.");
     }else{
         PrintLine("--> Close Markup failed.");
     }
  }else{
     PrintLine("Sending Close Markup command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_CLOSEMARKUP, pData)){
        PrintLine("--> Close Markup succeeded.");
     }else{
        PrintLine("--> Close Markup failed.");
     }
  }
}

void doCloseSession(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Close Session string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "close_session()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Close Session succeeded.");
     }else{
         PrintLine("--> Close Session failed.");
     }
  }else{
     PrintLine("Sending Close Session command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_CLOSESESSION, pData)){
        PrintLine("--> Close Session succeeded.");
     }else{
        PrintLine("--> Close Session failed.");
     }
  }

  CloseConversation();
}

void doDeleteItem(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteDeleteItem Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Delete Item string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "delete_item(");
     strcat(ExecutionString, pDeleteItemFilename);
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Delete Item succeeded.");
     }else{
         PrintLine("--> Delete Item failed.");
     }
  }else{
     PrintLine("Sending Delete Item command to Myriad...");

     strcpy(Data.Filename, pDeleteItemFilename);

     if(ProcessExecutionCommand(INTG_EXECUTE_DELETEITEM, &Data)){
        PrintLine("--> Delete Item succeeded.");
     }else{
        PrintLine("--> Delete Item failed.");
     }
  }
}

void doDisableAltview(BOOL bUseCommandString, BOOL bDisableView)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteDisableAltView Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Disable Alternate View string to Myriad...");

      // Setup the execution string
      strcpy(ExecutionString, "disable_altview(");

      switch(bDisableView){
         case TRUE :  strcat(ExecutionString, "TRUE");break;
         case FALSE : strcat(ExecutionString, "FALSE");break;
      }

      strcat(ExecutionString, ")");

      if(ProcessExecutionString(ExecutionString)){
          PrintLine("--> Disable Altview succeeded.");
      }else{
          PrintLine("--> Disable Altview failed.");
      }
  }else{
     PrintLine("Sending Disable Altview command to Myriad...");

     Data.bDisableView = bDisableView;

     if(ProcessExecutionCommand(INTG_EXECUTE_DISABLEALTVIEW, &Data)){
        PrintLine("--> Disable Altview succeeded.");
     }else{
        PrintLine("--> Disable Altview failed.");
     }
  }
}

void doFolderClear(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Folder Clear string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "ff_clear()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Folder Clear succeeded.");
     }else{
         PrintLine("--> Folder Clear failed.");
     }
  }else{
     PrintLine("Sending Folder Clear command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_FOLDERCLEAR, pData)){
        PrintLine("--> Folder Clear succeeded.");
     }else{
        PrintLine("--> Folder Clear failed.");
     }
  }
}

void doInvertColors(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Invert Colors string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "invert_colors()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Invert Colors succeeded.");
     }else{
         PrintLine("--> Invert Colors failed.");
     }
  }else{
     PrintLine("Sending Invert Colors command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_INVERTCOLORS, pData)){
        PrintLine("--> Invert Colors succeeded.");
     }else{
        PrintLine("--> Invert Colors failed.");
     }
  }
}

void doLockWindow(BOOL bUseCommandString, BOOL bLock)
{
   char   ExecutionString[MAX_STRING];
   char   tempstring[MAX_STRING];
   struct ExecuteLockWindow Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bLock){
      strcpy(tempstring, "--> Lock Window ");
   }else{
      strcpy(tempstring, "--> Unlock Window ");
   }

   if(bUseCommandString){
      PrintLine("Sending Lock Window string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "lock_window(");

     switch(bLock){
        case TRUE:  strcat(ExecutionString, "TRUE");break;
        case FALSE: strcat(ExecutionString, "FALSE");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         strcat(tempstring, "succeeded.");
     }else{
         strcat(tempstring, "failed.");
     }

     PrintLine(tempstring);
  }else{
     PrintLine("Sending Lock Window command to Myriad...");

     Data.bLockWindow = bLock;

     if(ProcessExecutionCommand(INTG_EXECUTE_LOCKWINDOW, &Data)){
         strcat(tempstring, "succeeded.");
     }else{
         strcat(tempstring, "failed.");
     }

     PrintLine(tempstring);
  }
}

void doNewMarkup(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending New Markup string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "new_markup()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> New Markup succeeded.");
     }else{
         PrintLine("--> New Markup failed.");
     }
  }else{
     PrintLine("Sending New Markup command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_NEWMARKUP, NULL)){
        PrintLine("--> New Markup succeeded.");
     }else{
        PrintLine("--> New Markup failed.");
     }
  }
}

void doOpenMarkup(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteOpenMarkup Data;

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   strcpy( Data.Filename, pRedlineFilename );

   if(bUseCommandString){
      PrintLine("Sending Open Markup string to Myriad...");

      // Setup the execution string
     sprintf(ExecutionString, "open_markup(%s)",pRedlineFilename);

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Open Markup succeeded.");
     }else{
         PrintLine("--> Open Markup failed.");
     }
  }else{
     PrintLine("Sending Open Markup command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_OPENMARKUP, &Data)){
        PrintLine("--> Open Markup succeeded.");
     }else{
        PrintLine("--> Open Markup failed.");
     }
  }
}

void doPage(BOOL bUseCommandString, ExecutePageTypes pType)
{
   char ExecutionString[MAX_STRING];
   struct ExecutePage Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Page string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "page(");

     switch(pType){
        case EXECUTE_PAGE_FIRST:    strcat(ExecutionString, "EXECUTE_PAGE_FIRST");break;
        case EXECUTE_PAGE_LAST:     strcat(ExecutionString, "EXECUTE_PAGE_LAST");break;
        case EXECUTE_PAGE_NEXT:     strcat(ExecutionString, "EXECUTE_PAGE_NEXT");break;
        case EXECUTE_PAGE_PREVIOUS: strcat(ExecutionString, "EXECUTE_PAGE_PREVIOUS");break;
        case EXECUTE_PAGE_SPECIFIC: strcat(ExecutionString, "EXECUTE_PAGE_SPECIFIC, 1");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Page succeeded.");
     }else{
         PrintLine("--> Page failed.");
     }
  }else{
     PrintLine("Sending Page command to Myriad...");

     Data.PageType   = pType;
     Data.PageNumber = 1;

     if(ProcessExecutionCommand(INTG_EXECUTE_PAGE, &Data)){
        PrintLine("--> Page succeeded.");
     }else{
        PrintLine("--> Page failed.");
     }
  }
}

void doPanDisplacement(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Pan Displacement string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "pan_displacement()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Pan Displacement succeeded.");
     }else{
         PrintLine("--> Pan Displacement failed.");
     }
  }else{
     PrintLine("Sending Pan Displacement command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_PANDISPLACEMENT, pData)){
        PrintLine("--> Pan Displacement succeeded.");
     }else{
        PrintLine("--> Pan Displacement failed.");
     }
  }
}

void doPrintViewport(BOOL bUseCommandString, ExecutePrintTypes pType)
{
   char ExecutionString[MAX_STRING];
   struct ExecutePrint Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Print Viewport string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "print(");

     switch(pType){
        case EXECUTE_PRINT_QUICK:  strcat(ExecutionString, "EXECUTE_PRINT_QUICK");break;
        case EXECUTE_PRINT_DIALOG: strcat(ExecutionString, "EXECUTE_PRINT_DIALOG");break;
     }

     strcat(ExecutionString, ", TRUE)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Print Viewport succeeded.");
     }else{
         PrintLine("--> Print Viewport failed.");
     }
  }else{
     PrintLine("Sending Print Viewport command to Myriad...");

     Data.PrintType          = pType;
     Data.bPrintCancelDialog = TRUE;

     if(ProcessExecutionCommand(INTG_EXECUTE_PRINTVIEWPORT, &Data)){
        PrintLine("--> Print Viewport succeeded.");
     }else{
        PrintLine("--> Print Viewport failed.");
     }
  }
}

void doPrintDocstack(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecutePrintDocstack Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Print Document Stack string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "print_docstack()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Print Document Stack succeeded.");
     }else{
         PrintLine("--> Print Document Stack failed.");
     }
  }else{
     Data.Filename[0] = 0;  // We do not have a DSF file to send, so use current one
     OpenDlg(Data.Filename, "Print DocStack file in Myriad");
     PrintLine("Sending Print Document Stack command to Myriad...");
     if(ProcessExecutionCommand(INTG_EXECUTE_PRINTDOCSTACK, &Data)){
        PrintLine("--> Print Document Stack succeeded.");
     }else{
        PrintLine("--> Print Document Stack failed.");
     }
  }
}

void doRaster(BOOL bUseCommandString, ExecuteRasterTypes rType)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRaster Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Full Raster string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "raster");

     switch(rType){
        case EXECUTE_RASTER_SAMPLE_DRAW:   strcat(ExecutionString, "(EXECUTE_RASTER_SAMPLE_DRAW)");break;
        case EXECUTE_RASTER_FULL_DRAW:     strcat(ExecutionString, "(EXECUTE_RASTER_FULL_DRAW)");break;
        case EXECUTE_RASTER_SCALE_TO_GRAY: strcat(ExecutionString, "(EXECUTE_RASTER_SCALE_TO_GRAY)");break;
     }

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Raster succeeded.");
     }else{
         PrintLine("--> Raster failed.");
     }
  }else{
     PrintLine("Sending Raster command to Myriad...");
  
     Data.RasterType = rType;

     if(ProcessExecutionCommand(INTG_EXECUTE_RASTER, &Data)){
        PrintLine("--> Raster succeeded.");
     }else{
        PrintLine("--> Raster failed.");
     }
  }
}

void doRepaint(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   char *pData=NULL;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Repaint string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "repaint()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Repaint succeeded.");
     }else{
         PrintLine("--> Repaint failed.");
     }
  }else{
     PrintLine("Sending Repaint command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_REPAINT, pData)){
        PrintLine("--> Repaint succeeded.");
     }else{
        PrintLine("--> Repaint failed.");
     }
  }
}

void doRotate(BOOL bUseCommandString, ExecuteRotateTypes rType)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteRotate Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Rotate string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "rotate(");

     switch(rType){
        case EXECUTE_ROTATE_PREVIOUS: strcat(ExecutionString, "EXECUTE_ROTATE_PREVIOUS");break;
        case EXECUTE_ROTATE_NEXT:     strcat(ExecutionString, "EXECUTE_ROTATE_NEXT");break;
        case EXECUTE_ROTATE_0:        strcat(ExecutionString, "EXECUTE_ROTATE_0");break;
        case EXECUTE_ROTATE_90:       strcat(ExecutionString, "EXECUTE_ROTATE_90");break;
        case EXECUTE_ROTATE_180:      strcat(ExecutionString, "EXECUTE_ROTATE_180");break;
        case EXECUTE_ROTATE_270:      strcat(ExecutionString, "EXECUTE_ROTATE_270");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Rotate succeeded.");
     }else{
         PrintLine("--> Rotate failed.");
     }
  }else{
     PrintLine("Sending Rotate command to Myriad...");

     Data.RotateType = rType;

     if(ProcessExecutionCommand(INTG_EXECUTE_ROTATE, &Data)){
        PrintLine("--> Rotate succeeded.");
     }else{
        PrintLine("--> Rotate failed.");
     }
  }
}

void doSaveMarkup(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSaveMarkup Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Save Markup string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "save_markup(MARKUPFORMAT_MRK,\"C:\\sample.mrk\")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Save Markup succeeded.");
     }else{
         PrintLine("--> Save Markup failed.");
     }
  }else{
     PrintLine("Sending Save Markup command to Myriad...");

     Data.SaveMarkupType = MARKUPFORMAT_MRK;
     strcpy(Data.Filename, "C:\\sample.mrk");

     if(ProcessExecutionCommand(INTG_EXECUTE_SAVEMARKUP, &Data)){
        PrintLine("--> Save Markup succeeded.");
     }else{
        PrintLine("--> Save Markup failed.");
     }
  }
}

void doSetFrameWindow(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSetFrameWindow Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set Frame Window string to Myriad...");

      // Setup the execution string for setting the window to the upper right quadrant
     strcpy(ExecutionString, "set_frame(16000,0,16000,16000)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Frame Window succeeded.");
     }else{
         PrintLine("--> Set Frame Window failed.");
     }
  }else{
     PrintLine("Sending Set Frame Window command to Myriad...");

     // Set the window to be in the upper right quadrant
     Data.Left   = 16000;
     Data.Top    = 0;
     Data.Width  = 16000;
     Data.Height = 16000;

     if(ProcessExecutionCommand(INTG_EXECUTE_SETFRAMEWINDOW, &Data)){
        PrintLine("--> Set Frame Window succeeded.");
     }else{
        PrintLine("--> Set Frame Window failed.");
     }
  }
}

void doViewChangemark(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteViewChangemark Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending View Changemark string to Myriad...");

      strcpy(ExecutionString, "view_changemark()");

      if(ProcessExecutionString(ExecutionString)){
          PrintLine("--> View Changemark succeeded.");
      }else{
          PrintLine("--> View Changemark failed.");
      }
  }else{
      PrintLine("Sending View Changemark command to Myriad...");

      Data.Title[0] = 0;   // Clear title to view the first changemark in the changemark list

      if(ProcessExecutionCommand(INTG_EXECUTE_VIEWCHANGEMARK, &Data)){
         PrintLine("--> View Changemark succeeded.");
      }else{
         PrintLine("--> View Changemark failed.");
      }
  }
}

void doGetChangemarks(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
     PrintLine("Sending Get Changemarks string to Myriad...");

     strcpy(ExecutionString, "get_changemarks()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Get Changemarks succeeded.");
     }else{
         PrintLine("--> Get Changemarks failed.");
     }
  }else{
     PrintLine("Sending Get Changemarks command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_GETCHANGEMARKS, NULL)){
        PrintLine("--> Get Changemarks succeeded.");
     }else{
        PrintLine("--> Get Changemarks failed.");
     }
  }
}

void doSetMarkupColor(BOOL bUseCommandString)
{
   char   ExecutionString[MAX_STRING];
   struct ExecuteSetMarkupColor Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set Markup Color string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "set_markup_color(1, 0)");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Markup Color succeeded.");
     }else{
         PrintLine("--> Set Markup Color failed.");
     }
  }else{
     PrintLine("Sending Set Markup Color command to Myriad...");

     Data.LayerID    = 1;
     Data.LayerColor = 0;

     if(ProcessExecutionCommand(INTG_EXECUTE_SETMARKUPCOLOR, &Data)){
        PrintLine("--> Set Markup Color succeeded.");
     }else{
        PrintLine("--> Set Markup Color failed.");
     }
  }
}

void doSetReturnData(BOOL bUseCommandString, ExecuteSetReturnDataTypes sType)
{
   char   ExecutionString[MAX_STRING];
   char   Tempstring[MAX_STRING];
   struct ExecuteSetReturnData Data;
   char   MsgString[25];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      // Setup the execution string
     strcpy(ExecutionString, "set_return_data(");

     switch(sType){
        case EXECUTE_SET_RETURN_DATA_SET:{
           strcat(ExecutionString, "EXECUTE_SET_RETURN_DATA_SET,");
           strcat(ExecutionString, SET_RETURN_DATA_TEST_STRING);
           strcpy(MsgString, "Set");
        }
        break;

        case EXECUTE_SET_RETURN_DATA_GET:{
           strcat(ExecutionString, "EXECUTE_SET_RETURN_DATA_GET");
           strcpy(MsgString, "Get");
        }
        break;
     }

     sprintf(Tempstring, "Sending %s Return Data string to Myriad...", MsgString);
     PrintLine(Tempstring);

     strcat(ExecutionString, ")");

     sprintf(Tempstring, "(Test string is %s)", SET_RETURN_DATA_TEST_STRING);
     PrintLine(Tempstring);

     if(ProcessExecutionString(ExecutionString)){
         sprintf(Tempstring, "--> %s Return Data succeeded.", MsgString);
         PrintLine(Tempstring);
     }else{
         sprintf(Tempstring, "--> %s Return Data failed.", MsgString);
         PrintLine(Tempstring);
     }
  }else{
     switch(sType){
        case EXECUTE_SET_RETURN_DATA_SET:{
           strcpy(MsgString, "Set");
           strcpy(Data.Data, SET_RETURN_DATA_TEST_STRING);

           sprintf(Tempstring, "(Test string is %s)", SET_RETURN_DATA_TEST_STRING);
           PrintLine(Tempstring);
        }
        break;

        case EXECUTE_SET_RETURN_DATA_GET:{
           strcpy(MsgString, "Get");
           memset(Data.Data, 0, EXECUTE_SET_RETURN_DATA_SIZE);
        }
        break;
     }

     sprintf(Tempstring, "Sending %s Return Data string to Myriad...", MsgString);
     PrintLine(Tempstring);

     Data.SetType = sType;

     if(ProcessExecutionCommand(INTG_EXECUTE_SETRETURNDATA, &Data)){
         sprintf(Tempstring, "--> %s Return Data succeeded.", MsgString);
         PrintLine(Tempstring);
     }else{
         sprintf(Tempstring, "--> %s Return Data failed.", MsgString);
         PrintLine(Tempstring);
     }
  }
}

void doToggleToolbar(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Toggle Toolbar string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "toggle_toolbar()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Toggle Toolbar succeeded.");
     }else{
         PrintLine("--> Toggle Toobar failed.");
     }
  }else{
     PrintLine("Sending Toggle Toolbar command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_TOGGLETOOLBAR, NULL)){
        PrintLine("--> Toggle Toolbar succeeded.");
     }else{
        PrintLine("--> Toggle Toolbar failed.");
     }
  }
}

void doWindow(BOOL bUseCommandString, ExecuteWindowTypes wType)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteWindow Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Window string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "window(");
  
     switch(wType){
        case EXECUTE_WINDOW_TILE_HORZ     : strcat(ExecutionString, "EXECUTE_WINDOW_TILE_HORZ");break;
        case EXECUTE_WINDOW_TILE_VERT     : strcat(ExecutionString, "EXECUTE_WINDOW_TILE_VERT");break;
        case EXECUTE_WINDOW_CASCADE       : strcat(ExecutionString, "EXECUTE_WINDOW_CASCADE");break;
        case EXECUTE_WINDOW_FIT           : strcat(ExecutionString, "EXECUTE_WINDOW_FIT");break;
        case EXECUTE_WINDOW_ARRANGE_ICONS : strcat(ExecutionString, "EXECUTE_WINDOW_ARRANGE_ICONS");break;
        case EXECUTE_WINDOW_MAXIMIZE      : strcat(ExecutionString, "EXECUTE_WINDOW_MAXIMIZE");break;
        case EXECUTE_WINDOW_MINIMIZE      : strcat(ExecutionString, "EXECUTE_WINDOW_MINIMIZE");break;
        case EXECUTE_WINDOW_RESTORE       : strcat(ExecutionString, "EXECUTE_WINDOW_RESTORE");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Window succeeded.");
     }else{
         PrintLine("--> Window failed.");
     }
  }else{
     PrintLine("Sending Window command to Myriad...");

     Data.WindowType = wType;

     if(ProcessExecutionCommand(INTG_EXECUTE_WINDOW, &Data)){
        PrintLine("--> Window succeeded.");
     }else{
        PrintLine("--> Window failed.");
     }
  }
}

void doMainWindow(BOOL bUseCommandString, ExecuteMainWindowTypes wType)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteMainWindow Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Main Window string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "main_window(");
  
     switch(wType){
        case EXECUTE_MAIN_WINDOW_MAXIMIZE : strcat(ExecutionString, "EXECUTE_MAIN_WINDOW_MAXIMIZE");break;
        case EXECUTE_MAIN_WINDOW_MINIMIZE : strcat(ExecutionString, "EXECUTE_MAIN_WINDOW_MINIMIZE");break;
        case EXECUTE_MAIN_WINDOW_RESTORE  : strcat(ExecutionString, "EXECUTE_MAIN_WINDOW_RESTORE");break;
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Main Window succeeded.");
     }else{
         PrintLine("--> Main Window failed.");
     }
  }else{
     PrintLine("Sending Main Window command to Myriad...");

     Data.WindowType = wType;

     if(ProcessExecutionCommand(INTG_EXECUTE_MAINWINDOW, &Data)){
        PrintLine("--> Main Window succeeded.");
     }else{
        PrintLine("--> Main Window failed.");
     }
  }
}

void doZoom(BOOL bUseCommandString, ExecuteZoomTypes zType)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteZoom Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
     PrintLine("Sending Zoom string to Myriad...");

     strcpy(ExecutionString, "zoom");
     // Setup the execution string
     switch(zType){
        case EXECUTE_ZOOM_IN:       strcat(ExecutionString, "(EXECUTE_ZOOM_IN)");break;
        case EXECUTE_ZOOM_OUT:      strcat(ExecutionString, "(EXECUTE_ZOOM_OUT)");break;
        case EXECUTE_ZOOM_EXTENTS:  strcat(ExecutionString, "(EXECUTE_ZOOM_EXTENTS)");break;
        case EXECUTE_ZOOM_PREVIOUS: strcat(ExecutionString, "(EXECUTE_ZOOM_PREVIOUS)");break;
        case EXECUTE_ZOOM_POINT:    strcat(ExecutionString, "(EXECUTE_ZOOM_POINT)");break;
        case EXECUTE_ZOOM_WIDTH:    strcat(ExecutionString, "(EXECUTE_ZOOM_WIDTH)");break;
     }

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Zoom succeeded.");
     }else{
         PrintLine("--> Zoom failed.");
     }
  }else{
     PrintLine("Sending Zoom command to Myriad...");

     Data.ZoomType = zType;

     if(ProcessExecutionCommand(INTG_EXECUTE_ZOOM, &Data)){
        PrintLine("--> Zoom succeeded.");
     }else{
        PrintLine("--> Zoom failed.");
     }
  }
}

void doEnableColorSelection(BOOL bUseCommandString, BOOL bEnable)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteEnableColorSel Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Enable Color Selection string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "enable_color_sel(");

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Enable Color Selection succeeded.");
     }else{
         PrintLine("--> Enable Color Selection failed.");
     }
  }else{
     PrintLine("Sending Enable Color Selection command to Myriad...");

     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_ENABLECOLORSEL, &Data)){
        PrintLine("--> Enable Color Selection succeeded.");
     }else{
        PrintLine("--> Enable Color Selection failed.");
     }
  }
}

void doSetAuthorName(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSetAuthorName Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set Author Name string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "set_author_name(");
     strcat(ExecutionString, MYRIAD_AUTHOR_NAME);
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Author Name succeeded.");
     }else{
         PrintLine("--> Set Author Name failed.");
     }
  }else{
     PrintLine("Sending Set Author Name command to Myriad...");

     strcpy(Data.AuthorName, MYRIAD_AUTHOR_NAME);

     if(ProcessExecutionCommand(INTG_EXECUTE_SETAUTHORNAME, &Data)){
        PrintLine("--> Set Author Name succeeded.");
     }else{
        PrintLine("--> Set Author Name failed.");
     }
  }
}

void doSetLayerName(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSetLayerName Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set Layer Name string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "set_layer_name(0, ");
     strcat(ExecutionString, MYRIAD_LAYER_NAME);
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Layer Name succeeded.");
     }else{
         PrintLine("--> Set Layer Name failed.");
     }
  }else{
     PrintLine("Sending Set Layer Name command to Myriad...");

     Data.LayerID = 0;
     strcpy(Data.LayerName, MYRIAD_LAYER_NAME);

     if(ProcessExecutionCommand(INTG_EXECUTE_SETLAYERNAME, &Data)){
        PrintLine("--> Set Layer Name succeeded.");
     }else{
        PrintLine("--> Set Layer Name failed.");
     }
  }
}

void doGetLayerInfo(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Get Layer Info string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "get_layer_info()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Get Layer Info succeeded.");
     }else{
         PrintLine("--> Get Layer Info failed.");
     }
  }else{
     PrintLine("Sending Get Layer Info command to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_GETLAYERINFO, NULL)){
        PrintLine("--> Get Layer Info succeeded.");
     }else{
        PrintLine("--> Get Layer Info failed.");
     }
  }
}

void doMonochrome(BOOL bUseCommandString, BOOL bEnable)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteMonochrome Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Monochrome string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "monochrome(");

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Monochrome succeeded.");
     }else{
         PrintLine("--> Monochrome failed.");
     }
  }else{
     PrintLine("Sending Monochrome command to Myriad...");

     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_MONOCHROME, &Data)){
        PrintLine("--> Monochrome succeeded.");
     }else{
        PrintLine("--> Monochrome failed.");
     }
  }
}

void doRedlineChangeMark(BOOL bUseCommandString, BOOL bEnable)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteRedlineChangeMark Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Redline Changemark string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "redline_changemark(");

     if(bEnable){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Redline Changemark succeeded.");
     }else{
         PrintLine("--> Redline Changemark failed.");
     }
  }else{
     PrintLine("Sending Redline Changemark command to Myriad...");

     Data.bEnable = bEnable;

     if(ProcessExecutionCommand(INTG_EXECUTE_REDLINECHANGEMARK, &Data)){
        PrintLine("--> Redline Changemark succeeded.");
     }else{
        PrintLine("--> Redline Changemark failed.");
     }
  }
}

void doOnetimeString(BOOL bStartMyriad)
{
   char ExecutionString[MAX_STRING];

   // We will do an FF Load onetime command
   PrintLine("Sending Onetime FF Load string to Myriad...");

   // Setup the execution string
   strcpy(ExecutionString, "ff_load(");
   strcat(ExecutionString, pDrawingFilename);
   strcat(ExecutionString, ",FF Load Demo, FALSE,");
   strcat(ExecutionString, pRedlineFilename);
   strcat(ExecutionString, ")");

   if(ProcessOnetimeExecutionString(ExecutionString, bStartMyriad)){
      PrintLine("--> Onetime FF Load succeeded.");
   }else{
      PrintLine("--> Onetime FF Load failed.");
   }
}

void doOnetimeCommand(BOOL bStartMyriad)
{
   struct ExecuteFFLoad Data;

   // We will do an FF Load onetime command
   PrintLine("Sending Onetime FF Load command to Myriad...");

   // Setup the execution command data
   strcpy(Data.Filename, pDrawingFilename);
   strcpy(Data.Description, "FF Load Demo");
   strcpy(Data.RedlineFilename, pRedlineFilename);

   if(ProcessOnetimeExecutionCommand(INTG_EXECUTE_LOADFOLDERFILE, &Data, bStartMyriad)){
      PrintLine("--> Onetime FF Load command succeeded.");
   }else{
      PrintLine("--> Onetime FF Load command failed.");
   }
}


void doSeriesMVS(void)
{
   if(mvs_series_step == CSMVS_SERIES_NOT_RUNNING)
   {
      mvs_series_step = CSMVS_LOAD_ASM_FILE;
      PostMessage(hWnd, PROCESS_MVS_SERIES_STEP_MESSAGE,0,0);
   }
}

void ProcessCSMVSStep(void)
{
   char ExecutionString[MAX_STRING];

   switch(mvs_series_step)
   {
   case CSMVS_LOAD_ASM_FILE:
      strcpy(ExecutionString, "FF_LOAD(\"c:\\sample.par\")");
      break;
   case CSMVS_NEWVIEW_TOP:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Top\",\"Top\")");
      break;
   case CSMVS_SETVIEW_TOP:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_TOP)");
      break;
   case CSMVS_NEWVIEW_BOTTOM:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Bottom\",\"Bottom\")");
      break;
   case CSMVS_SETVIEW_BOTTOM:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_BOTTOM)");
      break;
   case CSMVS_NEWVIEW_LEFT:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Left\",\"Left\")");
      break;
   case CSMVS_SETVIEW_LEFT:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_LEFT)");
      break;
   case CSMVS_NEWVIEW_RIGHT:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Right\",\"Right\")");
      break;
   case CSMVS_SETVIEW_RIGHT:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_RIGHT)");
      break;
   case CSMVS_NEWVIEW_FRONT:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Front\",\"Front\")");
      break;
   case CSMVS_SETVIEW_FRONT:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_FRONT)");
      break;
   case CSMVS_NEWVIEW_BACK:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Back\",\"Back\")");
      break;
   case CSMVS_SETVIEW_BACK:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_BACK)");
      break;
   case CSMVS_NEWVIEW_ISOMETRIC:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Isometric\",\"Isometric\")");
      break;
   case CSMVS_SETVIEW_ISOMETRIC:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_ISOMETRIC)");
      break;
   case CSMVS_NEWVIEW_DIMETRIC:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Dimetric\",\"Dimetric\")");
      break;
   case CSMVS_SETVIEW_DIMETRIC:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_DIMETRIC)");
      break;
   case CSMVS_NEWVIEW_TRIMETRIC:
      strcpy(ExecutionString, "NEW_3DVIEW(\"Trimetric\",\"Trimetric\")");
      break;
   case CSMVS_SETVIEW_TRIMETRIC:
      strcpy(ExecutionString, "SET_3DVIEW(VIEW3D_TRIMETRIC)");
      break;
   case CSMVS_SAVE_VIEWSET:
      strcpy(ExecutionString, "SAVE_VIEWSET(\"c:\\sample.mvs\")");
      break;
   }

   if(mvs_series_step > CSMVS_SAVE_VIEWSET ||
      mvs_series_step < CSMVS_SERIES_NOT_RUNNING)
   {
      PrintLine("Error:  Invalid MVS series step given");
   }
   else
   {
      if(mvs_series_step == CSMVS_SAVE_VIEWSET)      
      {
         // we are done.
         mvs_series_step = CSMVS_SERIES_NOT_RUNNING;      
      }
      else
      {
         // advance to the next step in the series
         mvs_series_step++;      
      }

      if(ProcessExecutionString(ExecutionString))
      {
         PrintLine("--> Series Step succeeded.");
      }
      else
      {
         PrintLine("--> Series Step failed.");
      }
   }
}


void doFolderInit(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteFFInit Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending File Folder Init string to Myriad...");

      // Setup the execution string
     sprintf(ExecutionString, "ff_init(%s, true)", pFolderFilename);

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> File Folder Init succeeded.");
     }else{
         PrintLine("--> File Folder Init failed.");
     }
  }else{
     PrintLine("Sending File Folder Init command to Myriad...");

     strcpy(Data.Filename, pFolderFilename);
     Data.bShowOpenDialog = TRUE;
   
     if(ProcessExecutionCommand(INTG_EXECUTE_INITFOLDERFILE, &Data)){
        PrintLine("--> File Folder Init command succeeded.");
     }else{
        PrintLine("--> File Folder Init command failed.");
     }
  }
}

void doFolderLoad(BOOL bUseCommandString)
{
   struct ExecuteFFLoad Data;
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   OpenDlg(pDrawingFilename, "Drawing to load in Myriad");
   OpenDlg(pRedlineFilename, "Redline to load in Myriad");

   if(bUseCommandString){
      PrintLine("Sending File Folder Load string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "ff_load(");
     strcat(ExecutionString, pDrawingFilename);
     strcat(ExecutionString, ",File Folder Load Demo,");
     strcat(ExecutionString, pRedlineFilename);
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> File Folder Load succeeded.");
     }else{
         PrintLine("--> File Folder Load failed.");
     }
  }else{
     PrintLine("Sending File Folder Load command to Myriad...");

     // Setup the execution command data
     memset(&Data, 0, sizeof(Data));
     strcpy(Data.Filename, pDrawingFilename);
     strcpy(Data.Description, "File Folder Load Demo");
     strcpy(Data.RedlineFilename, pRedlineFilename);
   
     if(ProcessExecutionCommand(INTG_EXECUTE_LOADFOLDERFILE, &Data)){
        PrintLine("--> File Folder Load command succeeded.");
     }else{
        PrintLine("--> File Folder Load command failed.");
     }
  }
}

void AddNotifyCommandString(char *Notifystring, char *Execstring, BOOL *bFirstOne)
{
   if(!*bFirstOne){
      strcat(Execstring, ",");
   }

   strcat(Execstring, Notifystring);

   *bFirstOne = FALSE;
}

void doSetNotifications(BOOL bUseCommandString, NotificationRequestType nType)
{
   struct ExecuteSetNotifications Data;
   char   ExecutionString[MAX_STRING];
   BOOL   bFirstOne=TRUE;

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set Notifications string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "set_notifications(");

     if(nType & INTG_NOTIFY_REQUEST_NONE){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_NONE", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_ALL){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_ALL", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_EXECUTION_RETURNS){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_EXECUTION_RETURNS", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_MOUSE){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_MOUSE", ExecutionString, &bFirstOne);
     }

     if(nType & (INTG_NOTIFY_REQUEST_INTELLIGENTOBJ)){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_INTELLIGENTOBJ", ExecutionString, &bFirstOne);
     }

     if(nType & (INTG_NOTIFY_REQUEST_INTOBJ_LOAD_LAUNCH)){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_INTOBJ_LOAD_LAUNCH", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_MARKUP){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_MARKUP", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_FILE_LOAD){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_FILE_LOAD", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_VIEWPORT){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_VIEWPORT", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_EXIT){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_EXIT", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_DATABASE_LOOKUP){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_DATABASE_LOOKUP", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_PRINT){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_PRINT", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_ISO_BANNER){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_ISO_BANNER", ExecutionString, &bFirstOne);
     }

     if(nType & (INTG_NOTIFY_REQUEST_INTELLIGENTOBJ|INTG_NOTIFY_REQUEST_VIEWPORT)){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_INTELLIGENTOBJ,INTG_NOTIFY_REQUEST_VIEWPORT", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_UD_MENU){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_UD_MENU", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_CHANGEMARK){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_CHANGEMARK", ExecutionString, &bFirstOne);
     }

     if(nType & INTG_NOTIFY_REQUEST_3D){
        AddNotifyCommandString("INTG_NOTIFY_REQUEST_3D", ExecutionString, &bFirstOne);
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set Notifications succeeded.");
     }else{
         PrintLine("--> Set Notifications failed.");
     }
  }else{
     PrintLine("Sending Set Notifications command to Myriad...");

     Data.NotificationTypes = nType;

     if(ProcessExecutionCommand(INTG_EXECUTE_SET_NOTIFICATIONS, &Data)){
        PrintLine("-->Set Notifications command succeeded.");
     }else{
        PrintLine("-->Set Notifications command failed.");
     }
  }
}

void doSetOnTop(BOOL bUseCommandString, BOOL bAlwaysOnTop)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteSetOnTop Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Set On Top string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "set_on_top(");

     if(bAlwaysOnTop){
        strcat(ExecutionString, "TRUE");
     }else{
        strcat(ExecutionString, "FALSE");
     }

     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Set On Top succeeded.");
     }else{
         PrintLine("--> Set On Top failed.");
     }
  }else{
     PrintLine("Sending Set On Top command to Myriad...");

     Data.bAlwaysOnTop = bAlwaysOnTop;

     if(ProcessExecutionCommand(INTG_EXECUTE_SET_ON_TOP, &Data)){
        PrintLine("--> Set On Top succeeded.");
     }else{
        PrintLine("--> Set On Top failed.");
     }
  }
}

void doExportToFile(BOOL bUseCommandString, ExecuteExportTypes tType)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteExportToFile Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Export To File string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "export_to_file(");
     strcat(ExecutionString, pExportFilename);
     strcat(ExecutionString, ", ");

     switch(tType){
        case EXECUTE_EXPORT_BMP : strcat(ExecutionString, "EXECUTE_EXPORT_BMP"); break;
        case EXECUTE_EXPORT_JPG : strcat(ExecutionString, "EXECUTE_EXPORT_JPG"); break;
        case EXECUTE_EXPORT_PNG : strcat(ExecutionString, "EXECUTE_EXPORT_PNG"); break;
        case EXECUTE_EXPORT_DLS : strcat(ExecutionString, "EXECUTE_EXPORT_DLS"); break;
     }
     
     strcat(ExecutionString, ")");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Export To File succeeded.");
     }else{
         PrintLine("--> Export To File failed.");
     }
  }else{
     PrintLine("Sending Set On Top command to Myriad...");

     strcpy(Data.FileName, pExportFilename);
     Data.FileType = tType;

     if(ProcessExecutionCommand(INTG_EXECUTE_EXPORT_TO_FILE, &Data)){
        PrintLine("--> Export To File succeeded.");
     }else{
        PrintLine("--> Export To File failed.");
     }
  }
}

void doInquireDocument(BOOL bUseCommandString)
{
	 char ExecutionString[MAX_STRING];

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Inquire Document string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "inquire_document()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Inquire Document succeeded.");
     }else{
         PrintLine("--> Inquire Document failed.");
     }
  }else{
     PrintLine("Sending Inquire Document to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_INQUIRE_DOCUMENT, NULL)){
        PrintLine("--> Inquire Document succeeded.");
     }else{
        PrintLine("--> Inquire Document failed.");
     }
  }
}

void doInquireSystem(BOOL bUseCommandString)
{
	 char ExecutionString[MAX_STRING];

   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(bUseCommandString){
      PrintLine("Sending Inquire System string to Myriad...");

      // Setup the execution string
     strcpy(ExecutionString, "inquire_system()");

     if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Inquire System succeeded.");
     }else{
         PrintLine("--> Inquire System failed.");
     }
  }else{
     PrintLine("Sending Inquire System to Myriad...");

     if(ProcessExecutionCommand(INTG_EXECUTE_INQUIRE_SYSTEM, NULL)){
        PrintLine("--> Inquire System succeeded.");
     }else{
        PrintLine("--> Inquire System failed.");
     }
  }
}

void doOpenDocstack(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   struct ExecuteOpenDocstack Data;
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(!OpenDlg(pFolderFilename, "Open DocStack file in Myriad"))
      return;
   if(bUseCommandString){
      PrintLine("Sending Open Docstack string to Myriad...");
      
      // Setup the execution string
      sprintf(ExecutionString, "open_docstack(%s)", pFolderFilename);
      
      if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Open Docstack succeeded.");
      }else{
         PrintLine("--> Open Docstack failed.");
      }
   }else{
      strcpy( Data.Filename, pFolderFilename );
      Data.bShowDialog = TRUE;
      
      PrintLine("Sending Open Docstack to Myriad...");
      
      if(ProcessExecutionCommand(INTG_EXECUTE_OPENDOCSTACK, &Data)){
         PrintLine("--> Open Docstack succeeded.");
      }else{
         PrintLine("--> Open Docstack failed.");
      }
   }
}

/*
void doVerbNoun(BOOL bUseCommandString)
{
   char ExecutionString[MAX_STRING];
   
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }
   
   if(bUseCommandString){
      PrintLine("Sending Verb Noun string to Myriad...");
      
      // Setup the execution string
      strcpy(ExecutionString, "verb_noun()");
      
      if(ProcessExecutionString(ExecutionString)){
         PrintLine("--> Verb Noun succeeded.");
      }else{
         PrintLine("--> Verb Noun failed.");
      }
   }else{
      PrintLine("Sending Verb Noun to Myriad...");
      
      if(ProcessExecutionCommand(INTG_EXECUTE_VERBNOUN, NULL)){
         PrintLine("--> Verb Noun succeeded.");
      }else{
         PrintLine("--> Verb Noun failed.");
      }
   }
}
*/

/***************************************************************************\
* ISODlgProc
*
* About dialog proc.
*
* History:
*   03-05-99      Created.
\***************************************************************************/

LRESULT WINAPI ISODlgProc(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam)
{
HWND hCtrl;
int nRet;
static struct ExecuteSetISOString *pISO;
char szBuff[32];

   switch (message) 
    {
      case WM_INITDIALOG:{
         pISO = (struct ExecuteSetISOString *)lParam;
         EnableWindow(GetDlgItem(hDlg, IDOK), pISO != NULL);
         if((hCtrl=GetDlgItem(hDlg, IDC_ISO_LIST)) != NULL)
         {
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_FONT");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_CLEAR_ALL");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_RESTORE_DEFAULTS");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_TOPLEFT");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_TOPCENTER");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_TOPRIGHT");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_BOTTOMLEFT");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_BOTTOMCENTER");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_BOTTOMRIGHT");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_LEFTTOP");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_LEFTCENTER");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_LEFTBOTTOM");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_RIGHTTOP");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_RIGHTCENTER");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_RIGHTBOTTOM");
            SendMessage(hCtrl, LB_ADDSTRING,0, (LPARAM)"EXECUTE_ISO_WATERMARK");
         }
         SendDlgItemMessage(hDlg, IDC_ISO_BANNER, EM_LIMITTEXT, MAX_ISO_STRING_SIZE-1, 0);
         SendDlgItemMessage(hDlg, IDC_ISO_BANNER_NUMBER, EM_LIMITTEXT, 2, 0);
         SetDlgItemText(hDlg, IDC_ISO_BANNER_NUMBER, "1");
         return TRUE;
      }

      case WM_COMMAND:{
        if (wParam == IDOK)
        {
         if((hCtrl=GetDlgItem(hDlg, IDC_ISO_LIST)) != NULL)
            if((nRet=SendMessage(hCtrl, LB_GETCURSEL , 0, 0))!=LB_ERR)
            {
               pISO->StringType = EXECUTE_ISO_FONT + nRet;
               if(!GetDlgItemText(hDlg, IDC_ISO_BANNER, pISO->String, MAX_ISO_STRING_SIZE))
               {
                  MessageBeep(0);
                  SetFocus(GetDlgItem(hDlg, IDC_ISO_BANNER));
                  return TRUE;
               }
               if(GetDlgItemText(hDlg, IDC_ISO_BANNER_NUMBER, szBuff, sizeof(szBuff)))
                  pISO->StringNumber = atoi(szBuff);
            }
            EndDialog(hDlg, wParam);
        }
        else if (wParam == IDCANCEL)
            EndDialog(hDlg, wParam);
        break;
      }
    }

    return FALSE;

    UNREFERENCED_PARAMETER(lParam);
    UNREFERENCED_PARAMETER(hDlg);
}
