/***********************************************************************
**                                                                    **
**  Copyright (c) 1996 Informative Graphics Corp.                     **
**      706 E. Bell Rd.  Suite 207                                    **
**      Phoenix, AZ  85022                                            **
**                                                                    **
**      ALL RIGHTS RESERVED.                                          **
**                                                                    **
**      May 1, 1996                                                   **
**                                                                    **
**      This source code can be used and distributed by ANYONE.  No   **
**      warranties of any kind are offered by Informative Graphics    **
**      as to the useability of this software.  USE AT YOUR OWN RISK! **
**                                                                    **
**  File: myrintob.c                                                  **
**  Written By: Shaun Riordan                                         **
**  Purpose:                                                          **
**                                                                    **
**  This module contains the routines which process the intelligent   **
**  object link list.                                                 **
**                                                                    **
************************************************************************/

#include "myrdata.h"

extern pFileRec pFileListFirst;
extern pFileRec pFileListLast;
extern int      TAGsize;
extern int      Char2PixTable[256];

void AddFileToList(struct NotifyLoadFileB *pRecord)
{
   pFileRec pNewFileRec = NULL;

   pNewFileRec = calloc(1,sizeof(FileList) + strlen(pRecord->filepathname) + 1);

   if(pNewFileRec){
      if(!pFileListFirst){
         pFileListFirst = pNewFileRec;
      }

      pNewFileRec->filehandle = (long)pRecord->filehandle;
      strcpy(pNewFileRec->filename, pRecord->filepathname);
      pNewFileRec->next = NULL;
      pNewFileRec->pMyBlocks = NULL;
      pNewFileRec->pMyLastBlock = NULL;

      if(pFileListLast){
         pFileListLast->next = pNewFileRec;
      }

      pFileListLast = pNewFileRec;
   }else{
      MessageBox((HWND)NULL,"Could not allocate for a new file","AddFileToList",MB_OK);
   }
}

void AddBlockToList(struct NotifyLoadBlockB *pRecord)
{
   pBlockRec pNewBlockRec;
   pBlockRec pPrevBlockRec;
   pFileRec pParentFileRec = GetFilePointerFromFileHandle((long)pRecord->filehandle);

   pNewBlockRec = calloc(1,sizeof(BlockList) + strlen(pRecord->blockname) + 1);

   if(pNewBlockRec){
      pNewBlockRec->filehandle       = (long)pRecord->filehandle;
      pNewBlockRec->blockhandle      = (int)pRecord->blockhandle;
      pNewBlockRec->next             = NULL;
      pNewBlockRec->pMyAttributes    = NULL;
      pNewBlockRec->pMyLastAttribute = NULL;

      strcpy(pNewBlockRec->blockname, pRecord->blockname);

      if(pPrevBlockRec = pParentFileRec->pMyLastBlock){
         pPrevBlockRec->next = pNewBlockRec;
      }else{
         pParentFileRec->pMyBlocks =  pNewBlockRec;
      }

      pParentFileRec->pMyLastBlock =  pNewBlockRec;
   }else{
      MessageBox((HWND)NULL,"Could not allocate for a new block","AddFileToList",MB_OK);
   }
}

void AddAttributeToList(struct NotifyLoadAttrib *pRecord)
{
   char tagbuff[MAX_STRING];
   char databuff[MAX_STRING];
   pAttributeRec pNewAttributeRec;
   pAttributeRec pPrevAttributeRec;
   pFileRec pParentFileRec = GetFilePointerFromFileHandle((long)pRecord->filehandle);
   pBlockRec pParentBlockRec = GetBlockPointerFromBlockHandle(pParentFileRec, (int)pRecord->blockhandle);

   strcpy(tagbuff, pRecord->blob);
   strcpy(databuff, &pRecord->blob[257]);

   pNewAttributeRec = calloc(1,sizeof(AttributeList)+strlen(tagbuff)+strlen(databuff)+2);

   if(pNewAttributeRec){
      pNewAttributeRec->filehandle      = (long)pRecord->filehandle;
      pNewAttributeRec->blockhandle     = (int)pRecord->blockhandle;
      pNewAttributeRec->attributehandle = (int)pRecord->attribhandle;
      pNewAttributeRec->data_offset     = strlen(tagbuff) + 1;
      pNewAttributeRec->next            = NULL;

      strcpy(pNewAttributeRec->tag, tagbuff);
      strcpy(&pNewAttributeRec->tag[pNewAttributeRec->data_offset], databuff);

      if(pPrevAttributeRec = pParentBlockRec->pMyLastAttribute){
         pPrevAttributeRec->next = pNewAttributeRec;
      }else{
         pParentBlockRec->pMyAttributes = pNewAttributeRec;
      }

      pParentBlockRec->pMyLastAttribute = pNewAttributeRec;
   }else{
      MessageBox((HWND)NULL,"Could not allocate for a new attribute","AddFileToList",MB_OK);
   }
}

BOOL GetMsgString(struct NotifyLaunchBlock *pRecord,char *MessageTitle,char *MessageBody)
{
   long hDesiredHandle = (long)pRecord->filehandle;
   char temp[256];
   char *location = NULL;

   pFileRec pFile      = GetFilePointerFromFileHandle((long)pRecord->filehandle);
   pBlockRec pBlock    = GetBlockPointerFromBlockHandle(pFile, (int)pRecord->blockhandle); 
   pAttributeRec pAttr = pBlock->pMyAttributes;

   GetFilenameFromFilePointer(pFile,MessageTitle);
   strcat(MessageTitle, " BlockName: ");

   CatBlocknameFromBlockPointer(pBlock,MessageTitle);
   
   strcpySpaces(MessageBody, "TAG:");
   
   strcat(MessageBody, "DATA:");

   while(pAttr){
      AddAttributeText(pAttr, MessageBody);
      pAttr=pAttr->next;
   }

   if((location = strstr(MessageBody,"FILELOAD:")) != NULL){
      location += 9;
      while ((*location == ' ') || (*location == '.'))
         location++;             //step over any leading spaces or dots
      strcpy(temp,"ff_load(");
      strcat(temp,location);
      strcat(temp,",,)");
      strcpy(MessageBody,temp);
      return(TRUE); // attribute is a file myriad should load
   }

   return(FALSE);
}

pFileRec GetFilePointerFromFileHandle(long hDesiredFile)
{
   pFileRec pCurFileRec = pFileListFirst;

   while (pCurFileRec){

      if(pCurFileRec->filehandle == hDesiredFile)
         return(pCurFileRec);
      
      pCurFileRec = pCurFileRec->next;
   }

   return(NULL);
}

pBlockRec GetBlockPointerFromBlockHandle(pFileRec pDesiredFile, int hDesiredBlock)
{
   pBlockRec pCurBlockRec = pDesiredFile->pMyBlocks;
   
   while (pCurBlockRec){
      
      if(pCurBlockRec->blockhandle == hDesiredBlock)
         return(pCurBlockRec);
      
      pCurBlockRec = pCurBlockRec->next;
      
   }

   return(NULL);
}

void GetFilenameFromFilePointer(pFileRec pFile, char *buffer)
{
   char drive[_MAX_DRIVE];
   char dir[_MAX_DIR];
   char fname[_MAX_FNAME];
   char ext[_MAX_EXT];

   if(pFile){
      _splitpath(pFile->filename,drive,dir,fname,ext);
      strcpy(buffer,fname);
      strcat(buffer,ext);
   }
}

void CatBlocknameFromBlockPointer(pBlockRec pBlock,char *buffer)
{
   if(pBlock){
      strcat(buffer,pBlock->blockname);
   }
}

void AddAttributeText(pAttributeRec pAttr, char *buffer)
{
   int length = strlen(buffer);
   char buff[257];
   int i = 0;
   
   strcpyDots(buff,pAttr->tag);

   if(length + strlen(buff) + 1 < 1024){
      strcat(buffer, "\n");
      strcat(buffer, buff);
   }
   
   length += strlen(buff);

   strcpy(buff, &pAttr->tag[pAttr->data_offset]);

   if(length + strlen(buff) + 1 < 1024)
      strcat(buffer, buff);
}

pFileRec GetFilePointerFromName(LPSTR filename)
{
   pFileRec pCurFileRec = pFileListFirst;

   while (pCurFileRec){

      if(!stricmp(filename,pCurFileRec->filename))
         return(pCurFileRec);
      
      pCurFileRec = pCurFileRec->next;
   }

   return(NULL);
}

void CleanUpAll(void)
{
   pFileRec pFile = pFileListFirst;
   pFileRec pNextFile;
   
   while(pFile){
      pNextFile = pFile->next;
      RemoveFile(pFile);
      pFile = pNextFile;
   }
}

void RemoveFile(pFileRec pFile)
{
   pBlockRec pBlock;
   pBlockRec pNextBlock;
   pFileRec  pPrevFile;

   if(pFile){
      pBlock    = pFile->pMyBlocks;
      pPrevFile = FindPrevFileRec(pFile);

      if(pPrevFile){
         if(pFile == pFileListLast){
            pFileListLast = pPrevFile;
            pPrevFile->next = NULL;
         }else{
            pPrevFile->next = pFile->next;
         }
      }
   
      if(pFile == pFileListFirst){
         pFileListFirst = pFile->next;
      }

      while(pBlock){
         pNextBlock = pBlock->next;
         RemoveBlock(pBlock);
         pBlock = pNextBlock;
      }

      free(pFile);
   }
}

void RemoveBlock(pBlockRec pBlock)
{
   pAttributeRec pAttribute = pBlock->pMyAttributes;
   pAttributeRec pNextAttribute;
   
   while(pAttribute){
      pNextAttribute = pAttribute->next;
      free(pAttribute);
      pAttribute = pNextAttribute;
   }

   free(pBlock);
}

pFileRec FindPrevFileRec(pFileRec pFile)
{
   pFileRec pRetFile = pFileListFirst;

   while(pRetFile){
      if(pRetFile->next == pFile)
         return(pRetFile);

      pRetFile = pRetFile->next;
   }

   return(NULL);
}

void GetTAGSize(void)
{
   char buff[64];

   if(GetPrivateProfileString(MYRIAD_INTOBJ,MYRIAD_TAGSIZE, "200", buff,64, MYRIAD_INTEGRATION_TEST_INI) != 0){
      TAGsize = atoi(buff);
   }
   return;
}

void strcpySpaces(LPSTR string1, LPSTR string2)
{
   int pixlength = 0;
   int leftovers = 0;
   int i = 0;
   int j = 0;
   int curchar = 1;

   while(curchar){
      curchar = (int)string2[i];
      pixlength += Char2PixTable[curchar];
      if (pixlength < TAGsize){
         string1[i] = string2[i];
      }else{
         string1[i-1] = 0;
         return;
      }
      i++;
   }
   i--; //i is now the number of chars in string1

   leftovers = (int)(TAGsize - pixlength) / 4;
   for (j = 0; j < leftovers ; j++){
      string1[i + j] = ' ';
   }
   string1[i + leftovers] = 0;
   return;
}

void strcpyDots(LPSTR string1, LPSTR string2)
{
   int pixlength = 0;
   int leftovers = 0;
   int i = 0;
   int j = 0;
   int curchar = 1;

   while(curchar){
      curchar = (int)string2[i];
      pixlength += Char2PixTable[curchar];
      if (pixlength < TAGsize){
         string1[i] = string2[i];
      }else{
         string1[i-1] = 0;
         return;
      }
      i++;
   }
   i--; //i is now the number of chars in string1

   leftovers = (int)(TAGsize - pixlength) / 4;
   for (j = 0; j < leftovers ; j++){
      if(j == leftovers - 1)
         string1[i + j] = ' ';
      else
         string1[i + j] = '.';
   }
   string1[i + leftovers] = 0;
   return;
}

void doFileLoad(LPSTR buffer)
{
   if(!IsServerUp()){
      PrintLine("There is no connection to Myriad.");
      return;
   }

   if(!ProcessExecutionString(buffer))
      PrintLine("--> Set Frame Window failed.");
}

void fillintable(void)
{
   int i;

   //set defaults pixel sizes
   for (i = 0 ;i < 256; i++){
      Char2PixTable[i] = 8;
   }
   //set pixel sizes for the system font's normal chars

   Char2PixTable[0] = 0;
   Char2PixTable[32] = 4;
   Char2PixTable[33] = 4;
   Char2PixTable[34] = 6;
   Char2PixTable[35] = 8;
   Char2PixTable[36] = 8;
   Char2PixTable[37] = 11;
   Char2PixTable[38] = 9;
   Char2PixTable[39] = 4;
   Char2PixTable[40] = 4;
   Char2PixTable[41] = 4;
   Char2PixTable[42] = 6;
   Char2PixTable[43] = 8;
   Char2PixTable[44] = 4;
   Char2PixTable[45] = 4;
   Char2PixTable[46] = 4;
   Char2PixTable[47] = 4;
   Char2PixTable[48] = 8;
   Char2PixTable[49] = 8;
   Char2PixTable[50] = 8;
   Char2PixTable[51] = 8;
   Char2PixTable[52] = 8;
   Char2PixTable[53] = 8;
   Char2PixTable[54] = 8;
   Char2PixTable[55] = 8;
   Char2PixTable[56] = 8;
   Char2PixTable[57] = 8;
   Char2PixTable[58] = 4;
   Char2PixTable[59] = 4;
   Char2PixTable[60] = 8;
   Char2PixTable[61] = 8;
   Char2PixTable[62] = 8;
   Char2PixTable[63] = 8;
   Char2PixTable[64] = 14;
   Char2PixTable[65] = 8;
   Char2PixTable[66] = 10;
   Char2PixTable[67] = 9;
   Char2PixTable[68] = 10;
   Char2PixTable[69] = 9;
   Char2PixTable[70] = 8;
   Char2PixTable[71] = 10;
   Char2PixTable[72] = 10;
   Char2PixTable[73] = 4;
   Char2PixTable[74] = 7;
   Char2PixTable[75] = 9;
   Char2PixTable[76] = 8;
   Char2PixTable[77] = 12;
   Char2PixTable[78] = 10;
   Char2PixTable[79] = 10;
   Char2PixTable[80] = 9;
   Char2PixTable[81] = 10;
   Char2PixTable[82] = 10;
   Char2PixTable[83] = 9;
   Char2PixTable[84] = 8;
   Char2PixTable[85] = 10;
   Char2PixTable[86] = 8;
   Char2PixTable[87] = 14;
   Char2PixTable[88] = 9;
   Char2PixTable[89] = 10;
   Char2PixTable[90] = 9;
   Char2PixTable[91] = 4;
   Char2PixTable[92] = 4;
   Char2PixTable[93] = 4;
   Char2PixTable[94] = 5;
   Char2PixTable[95] = 8;
   Char2PixTable[96] = 5;
   Char2PixTable[97] = 8;
   Char2PixTable[98] = 8;
   Char2PixTable[99] = 7;
   Char2PixTable[100] = 8;
   Char2PixTable[101] =	8;
   Char2PixTable[102] =	4;
   Char2PixTable[103] =	8;
   Char2PixTable[104] =	8;
   Char2PixTable[105] =	4;
   Char2PixTable[106] =	4;
   Char2PixTable[107] =	7;
   Char2PixTable[108] =	4;
   Char2PixTable[109] =	12;
   Char2PixTable[110] =	8;
   Char2PixTable[111] =	8;
   Char2PixTable[112] =	8;
   Char2PixTable[113] =	8;
   Char2PixTable[114] =	5;
   Char2PixTable[115] =	8;
   Char2PixTable[116] =	4;
   Char2PixTable[117] =	8;
   Char2PixTable[118] =	8;
   Char2PixTable[119] =	10;
   Char2PixTable[120] =	8;
   Char2PixTable[121] =	8;
   Char2PixTable[122] =	8;
   Char2PixTable[123] =	5;
   Char2PixTable[124] =	4;
   Char2PixTable[125] =	5;
   Char2PixTable[126] =	5;

   return;
}
