/***********************************************************************
**                                                                    **
**  Copyright (c) 1996 Informative Graphics Corp.                     **
**      706 E. Bell Rd.  Suite 207                                    **
**      Phoenix, AZ  85022                                            **
**                                                                    **
**      ALL RIGHTS RESERVED.                                          **
**                                                                    **
**      March 11, 1996                                                **
**                                                                    **
**      This source code can be used and distributed by ANYONE.  No   **
**      warranties of any kind are offered by Informative Graphics    **
**      as to the useability of this software.  USE AT YOUR OWN RISK! **
**                                                                    **
**  File: myrtest.c                                                   **
**  Written By: Scott Willis                                          **
**  Purpose:                                                          **
**                                                                    **
**      This example program is intended for illustrative purposes    **
**      only. Only the minimum code required to perform the           **
**      commands is given. You will want to create more robust error  **
**      handling, etc, in your applications.                          **
**                                                                    **
**      The purpose of this program is to provide a reference for     **
**      developing integrations, which will allow you to see how      **
**      each of the API routines work, and to easily cut-and-paste    **
**      the API routine calls into your application.                  **
**                                                                    **
**      The modules used by this test application:                    **
**                                                                    **
**      MYRTEST.C       - Main source module, contains the message    **
**                        handling routines for menu commands and     **
**                        notification messages from Myriad. All      **
**                        screen output is handled by this module,    **
**                        and all conversation starting and stopping  **
**                        is done here.                               **
**                                                                    **
**      MYREXEC.C       - Handles all the execution commands for the  **
**                        test application. Each of the routines      **
**                        performs both the string and structure      **
**                        forms of the command.                       **
**                                                                    **
**      MYRINTOBJ.C     - Handles all commands for the intelligent    **
**                        objects.                                    **
**                                                                    **
**      MYRTEST.RC      - Resource file for the application.          **
**                                                                    **
**      MYRDATA.H       - Contains structure and routine definitions  **
**                        for the application.                        **
**                                                                    **
**      MYRTEST.H       - Contains resource ID definitions.           **
**                                                                    **
**      MITEST16.MAK    - 16-Bit make file (Created with Microsoft    **
**                        Visual C++ version 1.5).                    **
**                                                                    **
**      MITEST32.MAK    - 32-Bit make file (Created with Microsoft    **
**                        Visual C++ version 4.0).                    **
**                                                                    **
************************************************************************/

#include "myrdata.h"

#define  CONNECT_RETRY_COUNT        (50)

HWND                     hWnd = NULL;
int                      CurrentLine=0;                /* Used for output to client area */
int                      NumberLines=0;
struct OutputLineRecord  *pLineHead=NULL;
struct OutputLineRecord  *pLineTail=NULL;
HINSTANCE                hInst;
char                     gszAppName[]  = "MYRTEST";
char                     gszAppTitle[] = "Myriad DDE Integration Demo";
char                     pDrawingFilename[MAX_STRING];
char                     pFolderFilename[MAX_STRING];
char                     pRedlineFilename[MAX_STRING];
char                     pDeleteItemFilename[MAX_STRING];
char                     pSideBySideLeftFilename[MAX_STRING];
char                     pSideBySideRightFilename[MAX_STRING];
char                     pExportFilename[MAX_STRING];
CSMVS_Type               mvs_series_step = CSMVS_SERIES_NOT_RUNNING;
BOOL                     bRunSilentState=FALSE;

// Intelligent object handling
pFileRec       pFileListFirst=NULL;   // Link list pointer to first file record structure.
pFileRec       pFileListLast=NULL;    // Link list pointer to last file record structure.
int            TAGsize=200;           // Width, in pixels, of TAG column in messagebox (alterable by ini file).
int            Char2PixTable[256];    // Table containing pixel size of all system font chars. 
                                      // Used for formating the text in the strings used by MessageBox.
BOOL           bOkToDisplay=TRUE;     // used to determine if INTOBJ messages are displayed

int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpszCmdLine, int nCmdShow)
{
   MSG msg;
   WNDCLASS wndclass;

   hInst = hInstance;

   if(!hPrevInstance){
       wndclass.style            = CS_HREDRAW | CS_VREDRAW;
       wndclass.lpfnWndProc      = (WNDPROC)WndProc;
       wndclass.cbClsExtra       = 0;
       wndclass.cbWndExtra       = 0;
       wndclass.hInstance        = hInst;
       wndclass.hCursor          = LoadCursor (NULL, IDC_ARROW);
       wndclass.hIcon            = LoadIcon(NULL, IDI_APPLICATION);
       wndclass.lpszMenuName     = gszAppName;
       wndclass.hbrBackground    = GetStockObject(WHITE_BRUSH);
       wndclass.lpszClassName    = gszAppName;
       RegisterClass(&wndclass);
   }

   hWnd = CreateWindow(gszAppName,
                       gszAppName,
                       WS_OVERLAPPEDWINDOW, 10, 300,
                       300, 300, NULL, NULL, hInstance, NULL);

   ShowWindow(hWnd, nCmdShow);

   SetWindowText(hWnd, gszAppTitle);

   // Get the filenames to use for the drawing and redline functions

   GetFilenames();
   fillintable(); // Setup the text pixel width table.
   
   while(GetMessage(&msg,0,0,0)){
       TranslateMessage(&msg);
       DispatchMessage(&msg);
   }

   return(msg.wParam);
}

long FAR PASCAL WndProc(HWND hWnd, unsigned iMessage, WORD wParam, LONG lParam)
{
   int ret=0;
   int rc=TRUE;

   switch (iMessage){
      case WM_PAINT:{
         PaintWindow();
     }
     break;

      case PROCESS_MVS_SERIES_STEP_MESSAGE:
        {
           ProcessCSMVSStep();
        }
        break;

      case IGC_NOTIFY_CALLBACK_MESSAGE:{
        NotifyCallbackHandler((struct NotifyCallbackRecord *)lParam);
     }
     break;

      case WM_COMMAND:{
         switch (wParam){
           case IDM_CONNECT_CONNECT_START:{
               if(IsServerUp()){
                  PrintLine("Connection to Myriad is already established.");
               }else if(!connectToMyriad(TRUE)){
                  PrintLine("Unable to connect to Myriad.");
               }
            }
            break;

            case IDM_CONNECT_CONNECT_NOSTART:{
               if(IsServerUp()){
                   PrintLine("Connection to Myriad is already established.");
               }else if(!connectToMyriad(FALSE)){
                   PrintLine("Unable to connect to Myriad");
               }
            }
            break;

            case IDM_CONNECT_DISCONNECT:{
                if(!IsServerUp()){
                   PrintLine("There is no connection to Myriad.");
                }else{
                   if(CloseConversation()){
                      PrintLine("Connection to Myriad closed successfully.");
                   }else{
                      PrintLine("Connection to Myriad could not be closed.");
                   }
                }
            }
            break;

            case IDM_CONNECT_EXIT:{
                doCloseSession(FALSE);
            }
            break;

            case IDM_CONNECT_ONETIME_START:{
               if(IsServerUp()){
                   PrintLine("Connection to Myriad is already established.");
               }else{
                   doOnetimeCommand(TRUE);
               }
            }
            break;

            case IDM_CONNECT_ONETIME_NOSTART:{
               if(IsServerUp()){
                   PrintLine("Connection to Myriad is already established.");
               }else{
                   doOnetimeCommand(FALSE);
               }
            }
            break;

            case IDM_CONNECT_STRING_START:{
               if(IsServerUp()){
                   PrintLine("Connection to Myriad is already established.");
               }else{
                   doOnetimeString(TRUE);
               }
            }
            break;

            case IDM_CONNECT_STRING_NOSTART:{
               if(IsServerUp()){
                   PrintLine("Connection to Myriad is already established.");
               }else{
                   doOnetimeString(FALSE);
               }
            }
            break;

             case IDM_NOTIFY_NOTIFY_ALL:{   
                doSetNotifications(TRUE, INTG_NOTIFY_REQUEST_ALL);
                bOkToDisplay = TRUE;
            }
            break;

          case IDM_NOTIFY_NOTIFY_OFF:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_NONE); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_EXECUTION_RETURNS:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_EXECUTION_RETURNS); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_MOUSE:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_MOUSE); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_INTELLIGENTOBJ:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_INTELLIGENTOBJ); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_MARKUP:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_MARKUP); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_FILE_LOAD:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_FILE_LOAD); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_VIEWPORT:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_VIEWPORT); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_EXIT:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_EXIT); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_DATABASE_LOOKUP:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_DATABASE_LOOKUP); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_PRINT:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_PRINT); 
            }
            break;

          case IDM_NOTIFY_NOTIFY_ISO_BANNER:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_ISO_BANNER); 
            }
            break;
  
            case IDM_NOTIFY_NOTIFY_CUSTOM:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_INTELLIGENTOBJ|INTG_NOTIFY_REQUEST_VIEWPORT); 
                bOkToDisplay = FALSE;
            }
            break;
  
             case IDM_NOTIFY_NOTIFY_MENU:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_UD_MENU); 
            }
            break;
  
             case IDM_NOTIFY_NOTIFY_CHANGEMARK:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_CHANGEMARK); 
            }
            break;
 
            case IDM_NOTIFY_NOTIFY_INTOBJ_LOAD_LAUNCH:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_INTOBJ_LOAD_LAUNCH); 
            }
            break;
  
            case IDM_NOTIFY_NOTIFY_3D:{
                doSetNotifications(FALSE, INTG_NOTIFY_REQUEST_3D); 
            }
            break;
  
             case IDM_COMMAND_COMMAND_INQUIRE_DOCUMENT:{
                 doInquireDocument(FALSE);
            }
             break;
  
             case IDM_COMMAND_COMMAND_INQUIRE_SYSTEM:{
                 doInquireSystem(FALSE);
            }
             break;
  
             case IDM_COMMAND_COMMAND_RUN_SILENT:{
                 doRunSilent(FALSE, !bRunSilentState);
             }
             break;

             case IDM_COMMAND_COMMAND_OPEN_DOCSTACK:
                doOpenDocstack(FALSE);
                break;

            /* These are the commands which are invoked using record structures */

             case IDM_COMMAND_COMMAND_ALTERNATEVIEW:{
                 doAlternateView(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_CLIP_ALL:{
                 doClip(FALSE, EXECUTE_CLIP_ALL);
            }
            break;

             case IDM_COMMAND_COMMAND_CLIP_ASK:{
                 doClip(FALSE, EXECUTE_CLIP_ASK);
            }
            break;

             case IDM_COMMAND_COMMAND_CLOSEALL:{
                 doCloseAll(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_CLOSEMARKUP:{
                 doCloseMarkup(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_CLOSESESSION:{
                 doCloseSession(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DELETEITEM:{
                 doDeleteItem(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DISABLEALTVIEW_ON:{
                 doDisableAltview(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_DISABLEALTVIEW_OFF:{
                 doDisableAltview(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_FOLDERCLEAR:{
                 doFolderClear(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_INITFOLDERFILE:{
                 doFolderInit(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_LOADFOLDERFILE:{
                 doFolderLoad(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_IN:{
                 doZoom(FALSE, EXECUTE_ZOOM_IN);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_OUT:{
                 doZoom(FALSE, EXECUTE_ZOOM_OUT);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_EXTENTS:{
                 doZoom(FALSE, EXECUTE_ZOOM_EXTENTS);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_POINT:{
                 doZoom(FALSE, EXECUTE_ZOOM_POINT);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_PREVIOUS:{
                 doZoom(FALSE, EXECUTE_ZOOM_PREVIOUS);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_WIDTH:{
                 doZoom(FALSE, EXECUTE_ZOOM_WIDTH);
            }
            break;

             case IDM_COMMAND_COMMAND_INVERTCOLORS:{
                 doInvertColors(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_LOCKWINDOW_ON:{
                 doLockWindow(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_LOCKWINDOW_OFF:{
                 doLockWindow(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_NEWMARKUP:{
                 doNewMarkup(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_OPENMARKUP:{
                 doOpenMarkup(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_PAGE_FIRST:{
                 doPage(FALSE, EXECUTE_PAGE_FIRST);
            }
            break;

             case IDM_COMMAND_COMMAND_PAGE_LAST:{
                 doPage(FALSE, EXECUTE_PAGE_LAST);
            }
            break;

             case IDM_COMMAND_COMMAND_PAGE_NEXT:{
                 doPage(FALSE, EXECUTE_PAGE_NEXT);
            }
            break;

             case IDM_COMMAND_COMMAND_PAGE_PREVIOUS:{
                 doPage(FALSE, EXECUTE_PAGE_PREVIOUS);
            }
            break;

             case IDM_COMMAND_COMMAND_PAGE_SPECIFIC:{
                 doPage(FALSE, EXECUTE_PAGE_SPECIFIC);
            }
            break;

             case IDM_COMMAND_COMMAND_PANDISPLACEMENT:{
                 doPanDisplacement(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_PRINT_QUICK:{
                 doPrintViewport(FALSE, EXECUTE_PRINT_QUICK);
            }
            break;

             case IDM_COMMAND_COMMAND_PRINT_DIALOG:{
                 doPrintViewport(FALSE, EXECUTE_PRINT_DIALOG);
            }
            break;

             case IDM_COMMAND_COMMAND_PRINT_DOCSTACK:{
                 doPrintDocstack(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_RASTER_SAMPLE:{
                 doRaster(FALSE, EXECUTE_RASTER_SAMPLE_DRAW);
            }
            break;

             case IDM_COMMAND_COMMAND_RASTER_FULL:{
                 doRaster(FALSE, EXECUTE_RASTER_FULL_DRAW);
            }
            break;

             case IDM_COMMAND_COMMAND_RASTER_SCALE:{
                 doRaster(FALSE, EXECUTE_RASTER_SCALE_TO_GRAY);
            }
            break;

             case IDM_COMMAND_COMMAND_REPAINT:{
                 doRepaint(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_PREVIOUS:{
                 doRotate(FALSE, EXECUTE_ROTATE_PREVIOUS);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_NEXT:{
                 doRotate(FALSE, EXECUTE_ROTATE_NEXT);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_0:{
                 doRotate(FALSE, EXECUTE_ROTATE_0);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_90:{
                 doRotate(FALSE, EXECUTE_ROTATE_90);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_180:{
                 doRotate(FALSE, EXECUTE_ROTATE_180);
            }
            break;

             case IDM_COMMAND_COMMAND_ROTATE_270:{
                 doRotate(FALSE, EXECUTE_ROTATE_270);
            }
            break;

             case IDM_COMMAND_COMMAND_SAVEMARKUP:{
                 doSaveMarkup(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SETFRAMEWINDOW:{
                 doSetFrameWindow(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SETMARKUPCOLOR:{
                 doSetMarkupColor(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SETRETURNDATA_SET:{
                 doSetReturnData(FALSE, EXECUTE_SET_RETURN_DATA_SET);
            }
            break;

             case IDM_COMMAND_COMMAND_SETRETURNDATA_GET:{
                 doSetReturnData(FALSE, EXECUTE_SET_RETURN_DATA_GET);
            }
            break;

             case IDM_COMMAND_COMMAND_TOGGLETOOLBAR:{
                 doToggleToolbar(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_TILE_HORZ:{
                 doWindow(FALSE, EXECUTE_WINDOW_TILE_HORZ);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_TILE_VERT:{
                 doWindow(FALSE, EXECUTE_WINDOW_TILE_VERT);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_CASCADE:{
                 doWindow(FALSE, EXECUTE_WINDOW_CASCADE);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_FIT:{
                 doWindow(FALSE, EXECUTE_WINDOW_FIT);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_ARRANGE:{
                 doWindow(FALSE, EXECUTE_WINDOW_ARRANGE_ICONS);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_MAXIMIZE:{
                 doWindow(FALSE, EXECUTE_WINDOW_MAXIMIZE);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_MINIMIZE:{
                 doWindow(FALSE, EXECUTE_WINDOW_MINIMIZE);
            }
            break;

             case IDM_COMMAND_COMMAND_WINDOW_RESTORE:{
                 doWindow(FALSE, EXECUTE_WINDOW_RESTORE);
            }
            break;

             case IDM_COMMAND_COMMAND_MAIN_WIN_MAXIMIZE:{
                 doMainWindow(FALSE, EXECUTE_MAIN_WINDOW_MAXIMIZE);
            }
            break;

             case IDM_COMMAND_COMMAND_MAIN_WIN_MINIMIZE:{
                 doMainWindow(FALSE, EXECUTE_MAIN_WINDOW_MINIMIZE);
            }
            break;

             case IDM_COMMAND_COMMAND_MAIN_WIN_RESTORE:{
                 doMainWindow(FALSE, EXECUTE_MAIN_WINDOW_RESTORE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLECOLORSEL_ON:{
                 doEnableColorSelection(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLECOLORSEL_OFF:{
                 doEnableColorSelection(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SETAUTHORNAME:{
                 doSetAuthorName(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SETLAYERNAME:{
                 doSetLayerName(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_GETLAYERINFO:{
                 doGetLayerInfo(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_FILE:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_FILE);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_EDIT:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_EDIT);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_VIEW:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_VIEW);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_REDLINE:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_REDLINE);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_TOOLS:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_TOOLS);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_WINDOW:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_WINDOW);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEMENU_HELP:{
                 doRemoveMenu(FALSE, EXECUTE_REMOVE_MENU_HELP);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEMENUITEM_ON:{
                 doEnableMenuItem(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEMENUITEM_OFF:{
                 doEnableMenuItem(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEDOCMOD_ON:{
                 doEnableDocModify(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEDOCMOD_OFF:{
                 doEnableDocModify(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_REDLINE_TOOL:{
                 doRedlineTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_AUTHOR_TOOL:{
                 doAuthorTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DISPLAYISO_TOOL:{
                 doDisplayISOTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_EYEGLASS_TOOL:{
                 doEyeGlassTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_BIRDSEYE_TOOL:{
                 doBirdsEyeTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_CHANGEMARK_TOOL:{
                 doChangeMarkTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DOCSTACK_TOOL:{
                 doDocstackTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SELECT_TOOL:{
                 doSelectTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ZOOM_TOOL:{
                 doZoomTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_FILEOPEN_TOOL:{
                 doFileOpenTool(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DOC_PREVIOUS:{
                 doPreviousDoc(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_DOC_NEXT:{
                 doNextDoc(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_MONOCHROME_ENABLE:{
                 doMonochrome(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_MONOCHROME_DISABLE:{
                 doMonochrome(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_REDLINECHM_ENABLE:{
                 doRedlineChangeMark(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_REDLINECHM_DISABLE:{
                 doRedlineChangeMark(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SIDE_BY_SIDE:{
                 doSideBySide(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SET_ISO_STRING:{
                 doSetISOString(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_GET_ISO_STRING:{
                 doGetISOString(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SET_FOCUS:{
                 doSetFocus(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SET_DOC_FOCUS:{
                 doSetDocumentFocus(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ADDUDPOPMENU:{
                 doAddUDMenu(FALSE, EXECUTE_UD_MENU_RIGHT_POPUP, EXECUTE_UD_MENU_MENUITEM);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEUDPOPMENU:{
                 doRemoveUDMenu(FALSE, EXECUTE_UD_MENU_RIGHT_POPUP);
            }
            break;

             case IDM_COMMAND_COMMAND_CLEARUDMENU:{
                 doClearUDMenu(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEUDPOPMENU_ON:{
                 doEnableUDMenu(FALSE, EXECUTE_UD_MENU_RIGHT_POPUP, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEUDPOPMENU_OFF:{
                 doEnableUDMenu(FALSE, EXECUTE_UD_MENU_RIGHT_POPUP, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_ADDUDMAINMENU:{
                 doAddUDMenu(FALSE, EXECUTE_UD_MENU_MAIN_STARTUP, EXECUTE_UD_MENU_MENU);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEUDMAINMENU:{
                 doRemoveUDMenu(FALSE, EXECUTE_UD_MENU_MAIN_STARTUP);
            }
            break;

             case IDM_COMMAND_COMMAND_ADDUDMAINMENUITEM:{
                 doAddUDMainMenuItem(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_REMOVEUDMAINMENUITEM:{
                 doRemoveUDMainMenuItem(FALSE);
            }
            break;
             case IDM_COMMAND_COMMAND_ENABLEUDMAINMENU_ON:{
                 doEnableUDMenu(FALSE, EXECUTE_UD_MENU_MAIN_STARTUP, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_ENABLEUDMAINMENU_OFF:{
                 doEnableUDMenu(FALSE, EXECUTE_UD_MENU_MAIN_STARTUP, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_SET_ON_TOP_ON:{
                 doSetOnTop(FALSE, TRUE);
            }
            break;

             case IDM_COMMAND_COMMAND_SET_ON_TOP_OFF:{
                 doSetOnTop(FALSE, FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_EXPORT_FILE_BMP:{
                 doExportToFile(FALSE, EXECUTE_EXPORT_BMP);
            }
            break;

             case IDM_COMMAND_COMMAND_EXPORT_FILE_JPG:{
                 doExportToFile(FALSE, EXECUTE_EXPORT_JPG);
            }
            break;

             case IDM_COMMAND_COMMAND_EXPORT_FILE_PNG:{
                 doExportToFile(FALSE, EXECUTE_EXPORT_PNG);
            }
            break;
                  
             case IDM_COMMAND_COMMAND_EXPORT_FILE_DLS:{
                     doExportToFile(FALSE, EXECUTE_EXPORT_DLS);
            }
            break;

             case IDM_COMMAND_COMMAND_GET_AUTHORS:{
                 doGetAuthors(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_VIEW_CHANGEMARK:{
                 doViewChangemark(FALSE);
            }
            break;

             case IDM_COMMAND_COMMAND_GET_CHANGEMARKS:{
                 doGetChangemarks(FALSE);
            }
            break;

           /* These are the commands which are invoked using string commands */

             case IDM_COMMAND_STRING_ALTERNATEVIEW:{
                 doAlternateView(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_CLIP_ALL:{
                 doClip(TRUE, EXECUTE_CLIP_ALL);
            }
            break;

             case IDM_COMMAND_STRING_CLIP_ASK:{
                 doClip(TRUE, EXECUTE_CLIP_ASK);
            }
            break;

             case IDM_COMMAND_STRING_CLOSEALL:{
                 doCloseAll(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_CLOSEMARKUP:{
                 doCloseMarkup(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_CLOSESESSION:{
                 doCloseSession(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DELETEITEM:{
                 doDeleteItem(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DISABLEALTVIEW_ON:{
                 doDisableAltview(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DISABLEALTVIEW_OFF:{
                 doDisableAltview(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_FOLDERCLEAR:{
                 doFolderClear(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_INITFOLDERFILE:{
                 doFolderInit(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_LOADFOLDERFILE:{
                 doFolderLoad(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_IN:{
                 doZoom(TRUE, EXECUTE_ZOOM_IN);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_OUT:{
                 doZoom(TRUE, EXECUTE_ZOOM_OUT);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_EXTENTS:{
                 doZoom(TRUE, EXECUTE_ZOOM_EXTENTS);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_POINT:{
                 doZoom(TRUE, EXECUTE_ZOOM_POINT);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_PREVIOUS:{
                 doZoom(TRUE, EXECUTE_ZOOM_PREVIOUS);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_WIDTH:{
                 doZoom(TRUE, EXECUTE_ZOOM_WIDTH);
            }
            break;

             case IDM_COMMAND_STRING_INVERTCOLORS:{
                 doInvertColors(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_LOCKWINDOW_ON:{
                 doLockWindow(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_LOCKWINDOW_OFF:{
                 doLockWindow(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_NEWMARKUP:{
                 doNewMarkup(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_OPENMARKUP:{
                 doOpenMarkup(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_PAGE_FIRST:{
                 doPage(TRUE, EXECUTE_PAGE_FIRST);
            }
            break;

             case IDM_COMMAND_STRING_PAGE_LAST:{
                 doPage(TRUE, EXECUTE_PAGE_LAST);
            }
            break;

             case IDM_COMMAND_STRING_PAGE_NEXT:{
                 doPage(TRUE, EXECUTE_PAGE_NEXT);
            }
            break;

             case IDM_COMMAND_STRING_PAGE_PREVIOUS:{
                 doPage(TRUE, EXECUTE_PAGE_PREVIOUS);
            }
            break;

             case IDM_COMMAND_STRING_PAGE_SPECIFIC:{
                 doPage(TRUE, EXECUTE_PAGE_SPECIFIC);
            }
            break;

             case IDM_COMMAND_STRING_PRINT_QUICK:{
                 doPrintViewport(TRUE, EXECUTE_PRINT_QUICK);
            }
            break;

             case IDM_COMMAND_STRING_PRINT_DIALOG:{
                 doPrintViewport(TRUE, EXECUTE_PRINT_DIALOG);
            }
            break;

             case IDM_COMMAND_STRING_PRINT_DOCSTACK:{
                 doPrintDocstack(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_PANDISPLACEMENT:{
                 doPanDisplacement(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_RASTER_SAMPLE:{
                 doRaster(TRUE, EXECUTE_RASTER_SAMPLE_DRAW);
            }
            break;

             case IDM_COMMAND_STRING_RASTER_FULL:{
                 doRaster(TRUE, EXECUTE_RASTER_FULL_DRAW);
            }
            break;

             case IDM_COMMAND_STRING_RASTER_SCALE:{
                 doRaster(TRUE, EXECUTE_RASTER_SCALE_TO_GRAY);
            }
            break;

             case IDM_COMMAND_STRING_REPAINT:{
                 doRepaint(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_PREVIOUS:{
                 doRotate(TRUE, EXECUTE_ROTATE_PREVIOUS);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_NEXT:{
                 doRotate(TRUE, EXECUTE_ROTATE_NEXT);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_0:{
                 doRotate(TRUE, EXECUTE_ROTATE_0);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_90:{
                 doRotate(TRUE, EXECUTE_ROTATE_90);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_180:{
                 doRotate(TRUE, EXECUTE_ROTATE_180);
            }
            break;

             case IDM_COMMAND_STRING_ROTATE_270:{
                 doRotate(TRUE, EXECUTE_ROTATE_270);
            }
            break;

             case IDM_COMMAND_STRING_SAVEMARKUP:{
                 doSaveMarkup(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SETFRAMEWINDOW:{
                 doSetFrameWindow(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SETMARKUPCOLOR:{
                 doSetMarkupColor(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SETRETURNDATA_SET:{
                 doSetReturnData(TRUE, EXECUTE_SET_RETURN_DATA_SET);
            }
            break;

             case IDM_COMMAND_STRING_SETRETURNDATA_GET:{
                 doSetReturnData(TRUE, EXECUTE_SET_RETURN_DATA_GET);
            }
            break;

             case IDM_COMMAND_STRING_TOGGLETOOLBAR:{
                 doToggleToolbar(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_TILE_HORZ:{
                 doWindow(TRUE, EXECUTE_WINDOW_TILE_HORZ);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_TILE_VERT:{
                 doWindow(TRUE, EXECUTE_WINDOW_TILE_VERT);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_CASCADE:{
                 doWindow(TRUE, EXECUTE_WINDOW_CASCADE);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_FIT:{
                 doWindow(TRUE, EXECUTE_WINDOW_FIT);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_ARRANGE:{
                 doWindow(TRUE, EXECUTE_WINDOW_ARRANGE_ICONS);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_MAXIMIZE:{
                 doWindow(TRUE, EXECUTE_WINDOW_MAXIMIZE);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_MINIMIZE:{
                 doWindow(TRUE, EXECUTE_WINDOW_MINIMIZE);
            }
            break;

             case IDM_COMMAND_STRING_WINDOW_RESTORE:{
                 doWindow(TRUE, EXECUTE_WINDOW_RESTORE);
            }
            break;

             case IDM_COMMAND_STRING_MAIN_WIN_MAXIMIZE:{
                 doMainWindow(TRUE, EXECUTE_MAIN_WINDOW_MAXIMIZE);
            }
            break;

             case IDM_COMMAND_STRING_MAIN_WIN_MINIMIZE:{
                 doMainWindow(TRUE, EXECUTE_MAIN_WINDOW_MINIMIZE);
            }
            break;

             case IDM_COMMAND_STRING_MAIN_WIN_RESTORE:{
                 doMainWindow(TRUE, EXECUTE_MAIN_WINDOW_RESTORE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLECOLORSEL_ON:{
                 doEnableColorSelection(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLECOLORSEL_OFF:{
                 doEnableColorSelection(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_SETAUTHORNAME:{
                 doSetAuthorName(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SETLAYERNAME:{
                 doSetLayerName(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_GETLAYERINFO:{
                 doGetLayerInfo(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_FILE:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_FILE);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_EDIT:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_EDIT);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_VIEW:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_VIEW);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_REDLINE:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_REDLINE);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_TOOLS:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_TOOLS);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_WINDOW:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_WINDOW);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEMENU_HELP:{
                 doRemoveMenu(TRUE, EXECUTE_REMOVE_MENU_HELP);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEMENUITEM_ON:{
                 doEnableMenuItem(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEMENUITEM_OFF:{
                 doEnableMenuItem(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEDOCMOD_ON:{
                 doEnableDocModify(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEDOCMOD_OFF:{
                 doEnableDocModify(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_REDLINE_TOOL:{
                 doRedlineTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_AUTHOR_TOOL:{
                 doAuthorTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DISPLAYISO_TOOL:{
                 doDisplayISOTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_EYEGLASS_TOOL:{
                 doEyeGlassTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_BIRDSEYE_TOOL:{
                 doBirdsEyeTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_CHANGEMARK_TOOL:{
                 doChangeMarkTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DOCSTACK_TOOL:{
                 doDocstackTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SELECT_TOOL:{
                 doSelectTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ZOOM_TOOL:{
                 doZoomTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_FILEOPEN_TOOL:{
                 doFileOpenTool(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DOC_PREVIOUS:{
                 doPreviousDoc(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_DOC_NEXT:{
                 doNextDoc(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_MONOCHROME_ENABLE:{
                 doMonochrome(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_MONOCHROME_DISABLE:{
                 doMonochrome(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_REDLINECHM_ENABLE:{
                 doRedlineChangeMark(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_REDLINECHM_DISABLE:{
                 doRedlineChangeMark(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_SIDE_BY_SIDE:{
                 doSideBySide(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SET_ISO_STRING:{
                 doSetISOString(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_GET_ISO_STRING:{
                 doGetISOString(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SET_FOCUS:{
                 doSetFocus(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SET_DOC_FOCUS:{
                 doSetDocumentFocus(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ADDUDPOPMENU:{
                 doAddUDMenu(TRUE, EXECUTE_UD_MENU_RIGHT_POPUP, EXECUTE_UD_MENU_MENUITEM);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEUDPOPMENU:{
                 doRemoveUDMenu(TRUE, EXECUTE_UD_MENU_RIGHT_POPUP);
            }
            break;

             case IDM_COMMAND_STRING_CLEARUDMENU:{
                 doClearUDMenu(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEUDPOPMENU_ON:{
                 doEnableUDMenu(TRUE, EXECUTE_UD_MENU_RIGHT_POPUP, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEUDPOPMENU_OFF:{
                 doEnableUDMenu(TRUE, EXECUTE_UD_MENU_RIGHT_POPUP, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_ADDUDMAINMENU:{
                 doAddUDMenu(TRUE, EXECUTE_UD_MENU_MAIN_STARTUP, EXECUTE_UD_MENU_MENU);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEUDMAINMENU:{
                 doRemoveUDMenu(TRUE, EXECUTE_UD_MENU_MAIN_STARTUP);
            }
            break;

             case IDM_COMMAND_STRING_ADDUDMAINMENUITEM:{
                 doAddUDMainMenuItem(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_REMOVEUDMAINMENUITEM:{
                 doRemoveUDMainMenuItem(TRUE);
            }
            break;
             case IDM_COMMAND_STRING_ENABLEUDMAINMENU_ON:{
                 doEnableUDMenu(TRUE, EXECUTE_UD_MENU_MAIN_STARTUP, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_ENABLEUDMAINMENU_OFF:{
                 doEnableUDMenu(TRUE, EXECUTE_UD_MENU_MAIN_STARTUP, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_SET_ON_TOP_ON:{
                 doSetOnTop(TRUE, TRUE);
            }
            break;

             case IDM_COMMAND_STRING_SET_ON_TOP_OFF:{
                 doSetOnTop(TRUE, FALSE);
            }
            break;

             case IDM_COMMAND_STRING_EXPORT_FILE_BMP:{
                 doExportToFile(TRUE, EXECUTE_EXPORT_BMP);
            }
            break;

             case IDM_COMMAND_STRING_EXPORT_FILE_JPG:{
                 doExportToFile(TRUE, EXECUTE_EXPORT_JPG);
            }
            break;

             case IDM_COMMAND_STRING_EXPORT_FILE_PNG:{
                 doExportToFile(TRUE, EXECUTE_EXPORT_PNG);
            }
            break;

            case IDM_COMMAND_STRING_EXPORT_FILE_DLS:{
                     doExportToFile(TRUE, EXECUTE_EXPORT_DLS);
            }
            break;


             case IDM_COMMAND_STRING_INQUIRE_DOCUMENT:{
                 doInquireDocument(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_INQUIRE_SYSTEM:{
                 doInquireSystem(TRUE);
            }
            break;
  
             case IDM_COMMAND_STRING_OPEN_DOCSTACK:
                doOpenDocstack(TRUE);
                break;

             case IDM_COMMAND_STRING_RUN_SILENT:{
                 doRunSilent(TRUE, !bRunSilentState);
             }
             break;

             case IDM_COMMAND_STRING_GET_AUTHORS:{
                 doGetAuthors(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_GET_CHANGEMARKS:{
                 doGetChangemarks(TRUE);
            }
            break;

             case IDM_COMMAND_STRING_VIEW_CHANGEMARK:{
                 doViewChangemark(TRUE);
            }
            break;

            case IDM_COMMAND_SERIES_MVS:{
                 doSeriesMVS();
            }
            break;

             case IDM_FILE_CLEAR:{
                 FreeOutputLines();
                 InvalidateRect(hWnd, NULL, FALSE);
                 UpdateWindow(hWnd);
            }
             break;

          case IDM_FILE_DUMP:{
                 DumpDisplay();
          }
             break;

             case IDM_FILE_SET_SERVER_NAME:{
                 doSetServerName();
          }
             break;

             case IDM_FILE_GET_SERVER_NAME:{
                 doGetServerName();
          }
             break;

          case IDM_FILE_GET_TOPIC_NAME:{
                 doGetTopicName();
          }
             break;

          case IDM_FILE_GET_ITEM_NAME:{
                 doGetItemName();
          }
             break;

             case IDM_FILE_EXIT:{
                 DestroyWindow(hWnd);
            }
            break;
          }

        if((wParam != IDM_FILE_DUMP) && (wParam != IDM_FILE_CLEAR) && (wParam != IDM_FILE_EXIT)){
             PrintBlankLine();
        }
      }
      break;

      case WM_CLOSE:{
         CleanUpAll(); 
         DestroyWindow(hWnd);
      }
      break;

      case WM_DESTROY:{
         CloseConversation();
         FreeOutputLines();
         PostQuitMessage(0);
      }
      break;

      default:{
         return DefWindowProc(hWnd, iMessage, wParam, lParam);
      }
   }

   return(FALSE);
}

void GetFilenames(void)
{
   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_FFLOAD_FILENAME, "", pDrawingFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pDrawingFilename, FFLOAD_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_FFINIT_FILENAME, "", pFolderFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pFolderFilename, FFINIT_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_REDLINE_FILENAME, "", pRedlineFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pRedlineFilename, FFLOAD_REDLINE_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_DELETE_ITEM_FILENAME, "", pDeleteItemFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pDeleteItemFilename, DELETE_ITEM_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_SIDE_BY_SIDE_LEFT_FILENAME, "", pSideBySideLeftFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pSideBySideLeftFilename, SIDE_BY_SIDE_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_SIDE_BY_SIDE_RIGHT_FILENAME, "", pSideBySideRightFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pSideBySideRightFilename, SIDE_BY_SIDE_FILENAME);
   }

   if(GetPrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION,
                              MYRIAD_EXPORT_FILENAME, "", pExportFilename,
                              MAX_STRING, MYRIAD_INTEGRATION_TEST_INI) == 0){
      strcpy(pExportFilename, EXPORT_FILENAME);
   }

   /* Create the INI file if necessary */

   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_FFLOAD_FILENAME, pDrawingFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_FFINIT_FILENAME, pFolderFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_REDLINE_FILENAME, pRedlineFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_DELETE_ITEM_FILENAME, pDeleteItemFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_SIDE_BY_SIDE_LEFT_FILENAME, pSideBySideLeftFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_SIDE_BY_SIDE_RIGHT_FILENAME, pSideBySideRightFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTEGRATION_TEST_APPLICATION, MYRIAD_EXPORT_FILENAME, pExportFilename, MYRIAD_INTEGRATION_TEST_INI);
   WritePrivateProfileString(MYRIAD_INTOBJ,MYRIAD_TAGSIZE, "200",MYRIAD_INTEGRATION_TEST_INI);
}

void DumpDisplay(void)
{
    struct OutputLineRecord *pTopLine;
    FILE   *fp;

    if((fp = fopen("MYRTEST.PRT", "w")) != NULL){
       pTopLine = pLineHead;

       while(pTopLine != NULL){
          fprintf(fp, "%s\n", pTopLine->Line);
          pTopLine = pTopLine->Next;
       }

       fclose(fp);
    }
}

void PrintLine(char *outline)
{
    struct OutputLineRecord *pNewLine;

    if((pNewLine = malloc(sizeof(*pNewLine))) != NULL){
        pNewLine->Next = NULL;

        if((pNewLine->Line = malloc(strlen(outline) + 1)) != NULL){
            strcpy(pNewLine->Line, outline);

            if(pLineHead == NULL){
                pLineHead = pNewLine;
            }else if(pLineTail != NULL){
                pLineTail->Next = pNewLine;
            }

            pLineTail = pNewLine;
            NumberLines++;

            InvalidateRect(hWnd, NULL, FALSE);
            UpdateWindow(hWnd);
        }else{
            free(pNewLine);  // Out of memory
        }
    }
}

void WriteOutputLine(char *outline)
{
    TEXTMETRIC  tm;
    HDC         hDC;
    RECT        clientRect;
    int         MaxLine;
    int         yCoord;

    MaxLine = FindMaxLines();

    hDC = GetDC(hWnd);

    GetTextMetrics(hDC, &tm);
    GetClientRect(hWnd, &clientRect);

    yCoord = CurrentLine * tm.tmHeight;

    TextOut(hDC, 3, yCoord, outline, strlen(outline));

    ReleaseDC(hWnd, hDC);

    CurrentLine++;
}

int FindMaxLines()
{
    int         result=0;
    TEXTMETRIC  tm;
    HDC         hDC;
    RECT        clientRect;

    hDC = GetDC(hWnd);

    GetTextMetrics(hDC, &tm);
    GetClientRect(hWnd, &clientRect);

    result = ((clientRect.bottom - clientRect.top) / tm.tmHeight);

    ReleaseDC(hWnd, hDC);

    return(result);
}

void PaintWindow()
{
    struct OutputLineRecord *pTopLine;
    HDC    hDC;
    RECT   clientRect;
    int    MaxLines;
    int    i;

    MaxLines = FindMaxLines();

    // Clear the display
    hDC = GetDC(hWnd);
    GetClientRect(hWnd, &clientRect);
    BitBlt(hDC, 0, 0, clientRect.right - clientRect.left, clientRect.bottom - clientRect.top, hDC, 0, 0, WHITENESS);
    ReleaseDC(hWnd, hDC);

    pTopLine = pLineHead;

    for(i=0; i < NumberLines - MaxLines; i++){
        if(pTopLine != NULL){
            pTopLine = pTopLine->Next;
        }
    }

    CurrentLine = 0;
    while(pTopLine != NULL){
        WriteOutputLine(pTopLine->Line);
        pTopLine = pTopLine->Next;
    }

    ValidateRect(hWnd, NULL);
}

void FreeOutputLines()
{
    struct OutputLineRecord *pTemp;

    while(pLineHead != NULL){
        pTemp = pLineHead->Next;

        if(pLineHead->Line != NULL){
            free(pLineHead->Line);
        }

        free(pLineHead);
        pLineHead = pTemp;
    }

    CurrentLine = 0;
    NumberLines = 0;
    pLineTail = NULL;
}

void PrintBlankLine(void)
{
   PrintLine("");
}

BOOL connectToMyriad(BOOL bStartMyriad)
{
  BOOL result;

  if(bStartMyriad){
     result = StartAndInitServer(MYRIAD_EXECUTABLE_NAME);
  }else{
     result = InitServer();
  }

  if(result){
      PrintLine("Connection to Myriad succeeded.");

      // Establish the notify callback routine
      SetNotifyWindow(hWnd);
  }else{
      PrintLine("Connection attempt to Myriad failed.");
  }

  return(result);
}

void HandleExecutionReturnPrint(void *pData)
{
   struct NotifyExecutionReturn *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      strcpy(tempString, ">>> Notify Execution Return for command ");

      switch(pRecord->Command){
         case INTG_EXECUTE_NOTIFY_RETURN:      strcat(tempString, "(NOTIFY RETURN)");break;
         case INTG_EXECUTE_SET_NOTIFICATIONS:  strcat(tempString, "(SET NOTIFICATIONS)");break;
         case INTG_EXECUTE_ALTERNATEVIEW:      strcat(tempString, "(ALTERNATE VIEW)");break;
         case INTG_EXECUTE_CLIP:               strcat(tempString, "(CLIP)");break;
         case INTG_EXECUTE_CLOSEALL:           strcat(tempString, "(CLOSE ALL)");break;
         case INTG_EXECUTE_CLOSEMARKUP:        strcat(tempString, "(CLOSE MARKUP)");break;
         case INTG_EXECUTE_CLOSESESSION:       strcat(tempString, "(CLOSE SESSION)");break;
         case INTG_EXECUTE_DELETEITEM:         strcat(tempString, "(DELETE ITEM)");break;
         case INTG_EXECUTE_DISABLEALTVIEW:     strcat(tempString, "(DISABLE ALT VIEW)");break;
         case INTG_EXECUTE_FOLDERCLEAR:        strcat(tempString, "(FOLDER CLEAR)");break;
         case INTG_EXECUTE_INITFOLDERFILE:     strcat(tempString, "(INIT FOLDER FILE)");break;
         case INTG_EXECUTE_LOADFOLDERFILE:     strcat(tempString, "(LOAD FOLDER FILE)");break;
         case INTG_EXECUTE_INVERTCOLORS:       strcat(tempString, "(INVERT COLORS)");break;
         case INTG_EXECUTE_LOCKWINDOW:         strcat(tempString, "(LOCK WINDOW)");break;
         case INTG_EXECUTE_OPENMARKUP:         strcat(tempString, "(OPEN MARKUP)");break;
         case INTG_EXECUTE_PAGE:               strcat(tempString, "(PAGE)");break;
         case INTG_EXECUTE_PANDISPLACEMENT:    strcat(tempString, "(PAN DISPLACEMENT)");break;
         case INTG_EXECUTE_PRINTVIEWPORT:      strcat(tempString, "(PRINT VIEWPORT)");break;
         case INTG_EXECUTE_RASTER:             strcat(tempString, "(RASTER)");break;
         case INTG_EXECUTE_REPAINT:            strcat(tempString, "(REPAINT)");break;
         case INTG_EXECUTE_ROTATE:             strcat(tempString, "(ROTATE)");break;
         case INTG_EXECUTE_SAVEMARKUP:         strcat(tempString, "(SAVE MARKUP)");break;
         case INTG_EXECUTE_SETFRAMEWINDOW:     strcat(tempString, "(SET FRAME WINDOW)");break;
         case INTG_EXECUTE_SETMARKUPCOLOR:     strcat(tempString, "(SET MARKUP COLOR)");break;
         case INTG_EXECUTE_SETRETURNDATA:      strcat(tempString, "(SET RETURN DATA)");break;
         case INTG_EXECUTE_TOGGLETOOLBAR:      strcat(tempString, "(TOGGLE TOOLBAR)");break;
         case INTG_EXECUTE_WINDOW:             strcat(tempString, "(WINDOW)");break;
         case INTG_EXECUTE_ZOOM:               strcat(tempString, "(ZOOM)");break;
         case INTG_EXECUTE_REMOVEMENU:         strcat(tempString, "(REMOVE MENU)");break;
         case INTG_EXECUTE_ENABLEMENUITEM:     strcat(tempString, "(ENABLE MENU ITEM)");break;
         case INTG_EXECUTE_ENABLEDOCMODIFY:    strcat(tempString, "(ENABLE DOCUMENT STACK MODIFY)");break;
         case INTG_EXECUTE_ENABLECOLORSEL:     strcat(tempString, "(ENABLE COLOR SELECTION)");break;
         case INTG_EXECUTE_SETAUTHORNAME:      strcat(tempString, "(SET AUTHOR NAME)");break;
         case INTG_EXECUTE_SETLAYERNAME:       strcat(tempString, "(SET LAYER NAME)");break;
         case INTG_EXECUTE_GETLAYERINFO:       strcat(tempString, "(GET LAYER INFO)");break;
         case INTG_EXECUTE_AUTHORTOOL:         strcat(tempString, "(AUTHOR TOOL)");break;
         case INTG_EXECUTE_REDLINETOOL:        strcat(tempString, "(REDLINE TOOL)");break;
         case INTG_EXECUTE_EYEGLASSTOOL:       strcat(tempString, "(EYE GLASS TOOL)");break;
         case INTG_EXECUTE_BIRDSEYETOOL:       strcat(tempString, "(BIRDS EYE TOOL)");break;
         case INTG_EXECUTE_CHANGEMARKTOOL:     strcat(tempString, "(CHANGEMARK TOOL)");break;
         case INTG_EXECUTE_SELECTTOOL:         strcat(tempString, "(SELECT TOOL)");break;
         case INTG_EXECUTE_ZOOMTOOL:           strcat(tempString, "(ZOOM TOOL)");break;
         case INTG_EXECUTE_PREVIOUSDOC:        strcat(tempString, "(PREVIOUS DOC)");break;
         case INTG_EXECUTE_NEXTDOC:            strcat(tempString, "(NEXT DOC)");break;
         case INTG_EXECUTE_MONOCHROME:         strcat(tempString, "(MONOCHROME)");break;
         case INTG_EXECUTE_REDLINECHANGEMARK:  strcat(tempString, "(REDLINE CHANGEMARK)");break;
         case INTG_EXECUTE_DOCSTACKTOOL:       strcat(tempString, "(DOCUMENT STACK TOOL)");break;
         case INTG_EXECUTE_SIDEBYSIDE:         strcat(tempString, "(SIDE BY SIDE COMPARE)");break;
         case INTG_EXECUTE_SETISOSTRING:       strcat(tempString, "(SET ISO STRING)");break;
         case INTG_EXECUTE_GETISOSTRING:       strcat(tempString, "(GET ISO STRING)");break;
         case INTG_EXECUTE_SET_FOCUS:          strcat(tempString, "(SET FOCUS)");break;
         case INTG_EXECUTE_ADDUDMENU:          strcat(tempString, "(ADD UD MENU)");break;
         case INTG_EXECUTE_REMOVEUDMENU:       strcat(tempString, "(REMOVE UD MENU)");break;
         case INTG_EXECUTE_CLEARUDMENU:        strcat(tempString, "(CLEAR UD MENU)");break;
         case INTG_EXECUTE_ENABLEUDMENU:       strcat(tempString, "(ENABLE UD MENU)");break;
         case INTG_EXECUTE_SET_ON_TOP:         strcat(tempString, "(SET ON TOP)");break;
         case INTG_EXECUTE_EXPORT_TO_FILE:     strcat(tempString, "(EXPORT TO FILE)");break;
         case INTG_EXECUTE_INQUIRE_DOCUMENT:   strcat(tempString, "(INQUIRE DOCUMENT)");break;
         case INTG_EXECUTE_INQUIRE_SYSTEM:     strcat(tempString, "(INQUIRE SYSTEM)");break;
         case INTG_EXECUTE_RENAME:             strcat(tempString, "(RENAME)");break;
         case INTG_EXECUTE_PRINTSETTINGS:      strcat(tempString, "(PRINT SETTINGS)");break;
         case INTG_EXECUTE_CLOSEVIEWPORT:      strcat(tempString, "(CLOSE VIEWPORT)");break;
         case INTG_EXECUTE_CLEARCOMMANDQUEUE:  strcat(tempString, "(CLEAR COMMAND QUEUE)");break;
         case INTG_EXECUTE_MAINWINDOW:         strcat(tempString, "(MAIN WINDOW)");break;
         case INTG_EXECUTE_CLOSEDOCUMENT:      strcat(tempString, "(CLOSE DOCUMENT)");break;
         case INTG_EXECUTE_SELECTAUTHOR:       strcat(tempString, "(SELECT AUTHOR)");break;
         case INTG_EXECUTE_GETAUTHORS:         strcat(tempString, "(GET AUTHORS)");break;
         case INTG_EXECUTE_SETDOCUMENTFOCUS:   strcat(tempString, "(SET DOCUMENT FOCUS)");break;
         case INTG_EXECUTE_VIEWCHANGEMARK:     strcat(tempString, "(VIEW CHANGEMARK)");break;
         case INTG_EXECUTE_GETCHANGEMARKS:     strcat(tempString, "(GET CHANGEMARKS)");break;
         case INTG_EXECUTE_FILEOPENTOOL:       strcat(tempString, "(FILE OPEN TOOL)");break;
         case INTG_EXECUTE_NEWMARKUP:          strcat(tempString, "(NEW MARKUP)");break;
         case INTG_EXECUTE_DISPLAYISOTOOL:     strcat(tempString, "(DISPLAY ISO TOOL)");break;
         case INTG_EXECUTE_EXPORTCHANGEMARKS:  strcat(tempString, "(EXPORT CHANGEMARKS)");break;
         case INTG_EXECUTE_PRINTDOCSTACK:      strcat(tempString, "(PRINT DOCUMENT STACK)");break;
         case INTG_EXECUTE_NEWDOCSTACK:        strcat(tempString, "(NEW DOCUMENT STACK)");break;
         case INTG_EXECUTE_OPENDOCSTACK:       strcat(tempString, "(OPEN DOCUMENT STACK)");break;
         case INTG_EXECUTE_SAVEDOCSTACK:       strcat(tempString, "(SAVE DOCUMENT STACK)");break;
         case INTG_EXECUTE_RUNSILENT:          strcat(tempString, "(RUN SILENT)");break;
         case INTG_EXECUTE_USEINTEGRATIONOPEN: strcat(tempString, "(USE INTEGRATION OPEN)");break;
         case INTG_EXECUTE_SETWYSIWYG:         strcat(tempString, "(SET WYSIWYG)");break;
         case INTG_EXECUTE_SETDEFAULTLAYERNAME: strcat(tempString, "(SET DEFAULT LAYER NAME)");break;
         case INTG_EXECUTE_INTEGRATIONENABLED: strcat(tempString, "(INTEGRATION ENABLED)");break;
         case INTG_EXECUTE_MODIFYINIVALUE:      strcat(tempString, "(MODIFY INI VALUE)");break;
         case INTG_EXECUTE_ADDPAGE:             strcat(tempString, "(ADD PAGE)");break;
         case INTG_EXECUTE_ADDMANYPAGES:        strcat(tempString, "(ADD MANY PAGES)");break;
         case INTG_EXECUTE_PUBLISH3DASSEMBLY:   strcat(tempString, "(PUBLISH 3D ASSEMBLY)");break;
         case INTG_EXECUTE_SET3DRENDERMODE:     strcat(tempString, "(SET 3D RENDER MODE)");break;
         case INTG_EXECUTE_SET3DPROJECTIONMODE: strcat(tempString, "(SET 3D PROJECTION MODE)");break;
         case INTG_EXECUTE_DISABLE3DVIEWSET:    strcat(tempString, "(DISABLE 3D VIEWSET)");break;
         case INTG_EXECUTE_SET3DVIEW:           strcat(tempString, "(SET 3D VIEW)");break;
         case INTG_EXECUTE_NEW3DVIEW:           strcat(tempString, "(NEW 3D VIEW)");break;
         case INTG_EXECUTE_SAVEVIEWSET:         strcat(tempString, "(SAVE VIEWSET)");break;
         case INTG_EXECUTE_DELETEALL3DVIEWS:    strcat(tempString, "(DELETE ALL 3D VIEWS)");break;

         default:                              strcat(tempString, "(INVALID COMMAND)");
      }

      switch(pRecord->ReturnCode){
         case NOTIFY_EXECUTION_RC_OK:      strcat(tempString, " - (OK)");break;
         case NOTIFY_EXECUTION_RC_FAILED:  strcat(tempString, " - (FAILED)");break;
         case NOTIFY_EXECUTION_RC_REFUSED: strcat(tempString, " - (REFUSED)");break;
         default:                          strcat(tempString, " - (Unknown return code)");break;
      }
      PrintLine(tempString);

      if(mvs_series_step != CSMVS_SERIES_NOT_RUNNING)
      {
         PostMessage(hWnd, PROCESS_MVS_SERIES_STEP_MESSAGE,0,0);
      }
   }else{
      PrintLine(">>> Notify Execution Return (Invalid data packet)");
   }
}

void HandleMouseMovePrint(void *pData)
{
   struct NotifyMouseMove *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Mouse Move (x: %d y: %d)", (int)pRecord->x, (int)pRecord->y);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Mouse Move (Invalid data packet)");
   }
}

void HandleLButtonDownPrint(void *pData)
{
   struct NotifyLButtonDown *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Left Button Down (x: %d y: %d)", (int)pRecord->x, (int)pRecord->y);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Left Button Down (Invalid data packet)");
   }
}

void HandleLButtonUpPrint(void *pData)
{
   struct NotifyLButtonUp *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Left Button Up (x: %d y: %d)", (int)pRecord->x, (int)pRecord->y);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Left Button Up (Invalid data packet)");
   }
}

void HandleLButtonDblClickPrint(void *pData)
{
   struct NotifyLButtonDblClick *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Left Button Double Click (x: %d y: %d)", (int)pRecord->x, (int)pRecord->y);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Left Button Double Click (Invalid data packet)");
   }
}

void HandleExitPrint(void *pData)
{
   struct NotifyExitReturn ReturnData;

   if(pData != NULL){
      PrintLine(">>> Notify Exit received.");

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_EXIT;
      ReturnData.bOKToExit           = TRUE;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid Exit Notification received.");
   }
}

void HandleDatabaseLookupPrint(void *pData)
{
   struct NotifyDatabaseLookupReturn ReturnData;
   char   tempString[MAX_STRING];
   struct NotifyDatabaseLookup *pRecord;

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Database Lookup received : %s", pRecord->Filename);
      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_DATABASE_LOOKUP;

      /* Just cut off the DBMS:, and pass back the remainder. You would perform
         your database lookup here.
      */

      strcpy(tempString, pRecord->Filename);
      strupr(tempString);

      if(strncmp(tempString, "DBMS:", strlen("DBMS:")) == 0){
        strcpy(tempString, &tempString[strlen("DBMS:")]);
      }

      strcpy(ReturnData.Filename, tempString);

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid Database Lookup Notification received.");
   }
}

void HandleOpenMarkupRequestPrint(void *pData)
{
   struct NotifyOpenMarkupRequestReturn ReturnData;
   struct NotifyOpenMarkupRequest *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Open Markup Request received : %s", pRecord->Filename);
      PrintLine(tempString);

      if(pRecord->bEdit){
         sprintf(tempString, ">>> Markup Type : Editable");
      }else{
         sprintf(tempString, ">>> Markup Type : Read-Only");
      }

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_OPEN_MARKUP_REQUEST;

      /* You would return the path of the file to use to open the markup in ReturnData.Filename */
      /* For the demo program, we have no file to return, so return nothing */
      ReturnData.Filename[0] = 0;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid Open Markup Request Notification received.");
   }
}

void HandleOpenMVSRequestPrint(void *pData)
{
   struct NotifyOpenMVSRequestReturn ReturnData;
   struct NotifyOpenMVSRequest *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Open MVS Request received : %s", pRecord->Filename);
      PrintLine(tempString);

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_OPEN_MVS_REQUEST;

      /* You would return the path of the file to use to open the mvs in ReturnData.Filename */
      /* For the demo program, we have no file to return, so return nothing */
      ReturnData.Filename[0] = 0;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid Open MVS Request Notification received.");
   }
}

void HandleSaveAsMarkupRequestPrint(void *pData)
{
   struct NotifySaveAsMarkupRequestReturn ReturnData;
   struct NotifySaveAsMarkupRequest *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Save As Markup Request received");
      PrintLine(tempString);

      sprintf(tempString, ">>> Markup Source Filename: %s", pRecord->SourceFilename);
      PrintLine(tempString);

      sprintf(tempString, ">>> Markup Filename: %s", pRecord->Filename);
      PrintLine(tempString);

      if(pRecord->bNew){
         sprintf(tempString, ">>> Markup Type : New");
      }else{
         sprintf(tempString, ">>> Markup Type : Existing");
      }

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_SAVEAS_MARKUP_REQUEST;

      /* You would store the path of the file to use to save the markup as in ReturnData.Filename */
      /* For the demo program, we will just return the given markup filename */
      strcpy(tempString, pRecord->Filename);
      strupr(tempString);

      if(strncmp(tempString, "DBMS:", strlen("DBMS:")) == 0){
        strcpy(tempString, &tempString[strlen("DBMS:")]);
      }
      else
      {
         char drive[_MAX_DRIVE];
         char dir[_MAX_DIR];
         char fname[_MAX_FNAME];
         char ext[_MAX_EXT];
         char *filebase;

         if(pRecord->bNew)
         {
            filebase = pRecord->SourceFilename;
         }
         else
         {
            filebase = pRecord->Filename;
         }         

         _splitpath( filebase, drive, dir, fname, ext );
         _makepath( tempString, drive, dir, fname, "mrk" );
      }

      strcpy(ReturnData.Filename, tempString);

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid SaveAs Markup Request Notification received.");
   }
}

void HandleSaveAsMVSRequestPrint(void *pData)
{
   struct NotifySaveAsMVSRequestReturn ReturnData;
   struct NotifySaveAsMVSRequest *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Save As MVS Request received");
      PrintLine(tempString);

      sprintf(tempString, ">>> MVS Source Filename: %s", pRecord->SourceFilename);
      PrintLine(tempString);

      sprintf(tempString, ">>> MVS Filename: %s", pRecord->Filename);
      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_SAVEAS_MVS_REQUEST;

      /* You would store the path of the file to use to save the markup as in ReturnData.Filename */
      /* For the demo program, we will just return the given markup filename */
      strcpy(tempString, pRecord->Filename);
      strupr(tempString);

      if(strncmp(tempString, "DBMS:", strlen("DBMS:")) == 0){
        strcpy(tempString, &tempString[strlen("DBMS:")]);
      }
      else
      {
         char drive[_MAX_DRIVE];
         char dir[_MAX_DIR];
         char fname[_MAX_FNAME];
         char ext[_MAX_EXT];
         char *filebase;

         filebase = pRecord->Filename;

         _splitpath( filebase, drive, dir, fname, ext );
         _makepath( tempString, drive, dir, fname, "mvs" );
      }

      strcpy(ReturnData.Filename, tempString);

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid SaveAs MVS Request Notification received.");
   }
}

void HandleNotifyPrintPrint(void *pData)
{
   struct NotifyPrint *pRecord;
   struct NotifyPrintReturn ReturnData;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      PrintLine(">>> Notify Print received.");
      sprintf(tempString, ">>> Filename : %s", pRecord->Filename);
      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_PRINT;
      ReturnData.bOKToPrint          = TRUE;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>>Invalid Print Notification received.");
   }
}

void HandleNotifyPrintPrintComplete(void *pData)
{
   struct NotifyPrintComplete *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      strcpy(tempString, ">>> Notify Print Complete : ");
  
      if(pRecord->bCancelled){
         strcat(tempString, "Cancelled");
      }else{
         strcat(tempString, "Completed");
      }

      if(pRecord->ErrorType == NOTIFY_PRINT_COMPLETE_ERROR_CREATING_DC_WITH_SPECIFIED_PRINTER){         
         char *work = tempString + strlen(tempString);
         sprintf(work, " Error creating DC with specified printer.  Error:%d", pRecord->WindowsErrorNumber);
      }else{
         strcat(tempString, " No Errors.");
      }
      
      PrintLine(tempString);
   }else{
      PrintLine(">>>Invalid Print Notification received.");
   }
}

void HandleLoadFileBeginPrint(void *pData)
{
   struct NotifyLoadFileB *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Load File Begin (Symbol ID: %d File Handle: %d Path: %s)", (int)pRecord->symbolID, (int)pRecord->filehandle, pRecord->filepathname);
      if(bOkToDisplay)PrintLine(tempString);
      AddFileToList(pRecord);
   }else{
      PrintLine(">>> Notify Load File Begin (Invalid data packet)");
   }
}

void HandleLoadBlockBeginPrint(void *pData)
{
   struct NotifyLoadBlockB *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Load Block Begin (Symbol ID: %d File Handle: %d Block Handle: %d Block Name: %s)", (int)pRecord->symbolID, (int)pRecord->filehandle, (int)pRecord->blockhandle, pRecord->blockname);
      if(bOkToDisplay)PrintLine(tempString);
      AddBlockToList(pRecord);
   }else{
      PrintLine(">>> Notify Load Block Begin (Invalid data packet)");
   }
}

void HandleLoadAttributePrint(void *pData)
{
   struct NotifyLoadAttrib *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Load Attribute (Symbol ID: %d File Handle: %d Block Handle: %d Attribute Handle: %d Blob Size: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle,
              (int)pRecord->blockhandle, (int)pRecord->attribhandle, (int)pRecord->blobsize);
      if(bOkToDisplay)PrintLine(tempString);
      AddAttributeToList(pRecord);
   }else{
      PrintLine(">>> Notify Load Attribute (Invalid data packet)");
   }
}

void HandleLoadBlockEndPrint(void *pData)
{
   struct NotifyLoadBlockE *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Load Block End (Symbol ID: %d File Handle: %d Block Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle, (int)pRecord->blockhandle);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Load Block End (Invalid data packet)");
   }
}

void HandleLoadFileEndPrint(void *pData)
{
   struct NotifyLoadFileE *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Load File End (Symbol ID: %d File Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Load File End (Invalid data packet)");
   }
}

void HandleDisplayFileBeginPrint(void *pData)
{
   struct NotifyDisplayFileB *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Display File Begin (Symbol ID: %d File Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle);
      if(bOkToDisplay)PrintLine(tempString);
      GetTAGSize();
   }else{
      PrintLine(">>> Notify Display File Begin (Invalid data packet)");
   }
}

void HandleDisplayBlockBeginPrint(void *pData)
{
   struct NotifyDisplayBlockB *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Display Block Begin (Symbol ID: %d File Handle: %d Block Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle, (int)pRecord->blockhandle);
      if(bOkToDisplay)PrintLine(tempString);

      sprintf(tempString, "    (Ext ULeft %d Ext URight %d Ext LLeft %d Ext LRight %d)",
              (int)pRecord->extents[0], (int)pRecord->extents[1], (int)pRecord->extents[2], (int)pRecord->extents[3]);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Display Block Begin (Invalid data packet)");
   }
}

void HandleDisplayAttributePrint(void *pData)
{
   struct NotifyDisplayAttrib *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Display Attribute (Symbol ID: %d File Handle: %d Block Handle: %d Attribute Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle,
              (int)pRecord->blockhandle, (int)pRecord->attribhandle);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Display Attribute (Invalid data packet)");
   }
}

void HandleDisplayBlockEndPrint(void *pData)
{
   struct NotifyDisplayBlockE *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Display Block End (Symbol ID: %d File Handle: %d Block Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle, (int)pRecord->blockhandle);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Display Block End (Invalid data packet)");
   }
}

void HandleDisplayFileEndPrint(void *pData)
{
   struct NotifyDisplayFileE *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Display File End (Symbol ID: %d File Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle);
      if(bOkToDisplay)PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Display File End (Invalid data packet)");
   }
}

void HandleLaunchAttribBlockPrint(void *pData)
{
   struct NotifyLaunchBlock *pRecord;
   char   tempString[MAX_STRING];
   char   MessageTitle[256];
   char   MessageBody[1024];
   IGBOOL loadmsg =FALSE; // if TRUE, the messagebody will be a path and filename

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Launch Attribute (Symbol ID: %d File Handle: %d Block Handle: %d)", (int)pRecord->symbolID, (int)pRecord->filehandle, (int)pRecord->blockhandle);
      PrintLine(tempString);

      sprintf(tempString, "    (Ext ULeft %d Ext URight %d Ext LLeft %d Ext LRight %d)",
              (int)pRecord->extents[0], (int)pRecord->extents[1], (int)pRecord->extents[2], (int)pRecord->extents[3]);
      if(bOkToDisplay)PrintLine(tempString);
      loadmsg = GetMsgString(pRecord,MessageTitle,MessageBody);
      if(loadmsg)
         doFileLoad(MessageBody);
      else
         MessageBox((HWND)NULL,MessageBody,MessageTitle,MB_OK);
   }else{
      PrintLine(">>> Notify Launch Attribute (Invalid data packet)");
   }
}

void HandleSetReturnDataPrint(void *pData)
{
   struct NotifySetReturnData *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      if(pRecord->Data[0] != 0){
        sprintf(tempString, ">>> Notify Set Return Data value %s", pRecord->Data);
      }else{
        sprintf(tempString, ">>> Notify Set Return Data returned a blank string (FAILED) <<<");
      }

      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Set Return Data (Invalid data packet)");
   }
}

void HandleFileLoadedPrint(void *pData)
{
   struct NotifyFileLoaded *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify File Loaded %s : ", pRecord->Filename);

      switch(pRecord->LoadReturnCode){
        case NOTIFY_FILE_LOAD_OK:           strcat(tempString, "NOTIFY_FILE_LOAD_OK");break;
        case NOTIFY_FILE_LOAD_INVALID_FILE: strcat(tempString, "NOTIFY_FILE_LOAD_INVALID_FILE");break;
        case NOTIFY_FILE_LOAD_ERROR:        strcat(tempString, "NOTIFY_FILE_LOAD_ERROR");break;
        default : strcat(tempString, "INVALID LOAD RETURN CODE GIVEN");break;
      }

      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify File Loaded (Invalid data packet)");
   }
}

void HandleViewportClosePrint(void *pData)
{
   struct NotifyViewportClose *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL)
   {
      sprintf(tempString, ">>> Notify Viewport Closed : %s", pRecord->Filename);
      PrintLine(tempString);
      RemoveFile(GetFilePointerFromName((LPSTR)pRecord->Filename));
   }
   else
   {
      PrintLine(">>> Notify Viewport Closed (Invalid data packet)");
   }
}

void HandleNewMarkupPrint(void *pData)
{
   struct NotifyNewMarkup *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify New Markup On Image : %s", pRecord->Filename);
      PrintLine(tempString);

      sprintf(tempString, "    Layer Name : %s", pRecord->Layername);
      PrintLine(tempString);

      sprintf(tempString, "    Author Name : %s", pRecord->Authorname);
      PrintLine(tempString);

   }else{
      PrintLine(">>> Notify New Markup (Invalid data packet)");
   }
}

void HandleOpenMarkupPrint(void *pData)
{
   struct NotifyOpenMarkup *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Open Markup %s : ", pRecord->Filename);

      switch(pRecord->OpenMarkupReturnCode){
        case NOTIFY_OPENMARKUP_OK:           strcat(tempString, "NOTIFY_OPENMARKUP_OK");break;
        case NOTIFY_OPENMARKUP_INVALID_FILE: strcat(tempString, "NOTIFY_OPENMARKUP_INVALID_FILE");break;
        case NOTIFY_OPENMARKUP_ERROR:        strcat(tempString, "NOTIFY_OPENMARKUP_ERROR");break;
        default : strcat(tempString, "INVALID OPENMARKUP RETURN CODE GIVEN");break;
      }
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Open Markup (Invalid data packet)");
   }
}

void HandleSaveMarkupPrint(void *pData)
{
   struct NotifySaveMarkup *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL)
   {
      sprintf(tempString, ">>> Notify Save Markup : %s", pRecord->Filename);
      PrintLine(tempString);

      sprintf(tempString, "    Sourcename: %s", pRecord->Sourcename);
      PrintLine(tempString);

   }else{
      PrintLine(">>> Notify Save Markup (Invalid data packet)");
   }
}

void HandleMarkupSavedPrint(void *pData)
{
   struct NotifyMarkupSaved *pRecord;
   struct NotifyMarkupSavedReturn ReturnData;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Markup Saved : %s : ", pRecord->Filename);

      switch(pRecord->SaveReturnCode){
        case NOTIFY_MARKUP_SAVED_OK:        strcat(tempString, "NOTIFY_MARKUP_SAVED_OK");break;
        case NOTIFY_MARKUP_SAVED_ERROR:     strcat(tempString, "NOTIFY_MARKUP_SAVED_ERROR");break;
        case NOTIFY_MARKUP_SAVED_CANCELLED: strcat(tempString, "NOTIFY_MARKUP_SAVED_CANCELLED");break;
        default : strcat(tempString, "INVALID MARKUP SAVED RETURN CODE GIVEN");break;
      }

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_MARKUP_SAVED;
      ReturnData.Filename[0] = 0;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>> Notify Markup Saved (Invalid data packet)");
   }
}


void HandleMVSSavedPrint(void *pData)
{
   struct NotifyMVSSaved *pRecord;
   struct NotifyMVSSavedReturn ReturnData;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify MVS Saved : %s : ", pRecord->Filename);

      switch(pRecord->SaveReturnCode){
        case NOTIFY_MVS_SAVED_OK:        strcat(tempString, "NOTIFY_MVS_SAVED_OK");break;
        case NOTIFY_MVS_SAVED_ERROR:     strcat(tempString, "NOTIFY_MVS_SAVED_ERROR");break;
        case NOTIFY_MVS_SAVED_CANCELLED: strcat(tempString, "NOTIFY_MVS_SAVED_CANCELLED");break;
        default : strcat(tempString, "INVALID MVS SAVED RETURN CODE GIVEN");break;
      }

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_MVS_SAVED;
      ReturnData.Filename[0] = 0;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>> Notify VS Saved (Invalid data packet)");
   }
}


void HandleCloseMarkupPrint(void *pData)
{
   struct NotifyCloseMarkup *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Close Markup : %s", pRecord->Filename);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Close Markup (Invalid data packet)");
   }
}

void HandleImageChangePrint(void *pData)
{
   struct NotifyImageChange *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Image Change : %s", pRecord->Filename);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Image Change (Invalid data packet)");
   }
}

void HandleGetLayerInfoPrint(void *pData)
{
   struct NotifyGetLayerInfo      *pRecord;
   struct NotifyGetLayerInfoEntry *pEntry;
   char   tempString[MAX_STRING];
   char   visiblestring[MAX_STRING];
   int    i;

   if((pRecord = pData) != NULL){
      if(pRecord->NumberLayers > 1){
         sprintf(tempString, ">>> Notify Get Layer Info (%d Layers)", pRecord->NumberLayers);
      }else if(pRecord->NumberLayers == 1){
         sprintf(tempString, ">>> Notify Get Layer Info (1 Layer)");
      }else{
         sprintf(tempString, ">>> Notify Get Layer Info (No Layers)");
      }

      PrintLine(tempString);

      /* Run through all the layer entries in the packet.

         The structure of the GetLayerInfo packet is:

         +-------------------------+
         | NotifyGetLayerInfo      |   <--- Control block for packet (Contains the number of layers in packet)
         +-------------------------+
         | NotifyGetLayerInfoEntry |
         |           .             |
         |           .             |   <--- An entry for each layer (Array of entry records)
         |           .             |
         +-------------------------+
      */

      if(pRecord->NumberLayers > 0){
         pEntry = (struct NotifyGetLayerInfoEntry*)&pRecord->LayerEntryArray;

         PrintBlankLine();
         PrintLine("Layer ID    Layer Name    Author Name   Visible");

         for(i=0; i < (int)pRecord->NumberLayers; i++){
            if(pEntry->bVisible){
               strcpy(visiblestring, "TRUE");
            }else{
               strcpy(visiblestring, "FALSE");
            }

            sprintf(tempString, "%5d %15s %19s %18s", pEntry->LayerID, pEntry->LayerName, pEntry->AuthorName, visiblestring);
            PrintLine(tempString);

            pEntry++;
         }
      }
   }else{
      PrintLine(">>> Notify Get Layer Info (Invalid data packet)");
   }
}

void HandleGetISOStringPrint(void *pData)
{
   struct NotifyGetISOString *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Get ISO String : ");

      switch(pRecord->StringType){
        case EXECUTE_ISO_FONT :         strcat(tempString, "EXECUTE ISO FONT");break;
        case EXECUTE_ISO_TOPLEFT :      strcat(tempString, "EXECUTE ISO TOP LEFT");break;
        case EXECUTE_ISO_TOPCENTER :    strcat(tempString, "EXECUTE ISO TOP CENTER");break;
        case EXECUTE_ISO_TOPRIGHT :     strcat(tempString, "EXECUTE ISO TOP RIGHT");break;
        case EXECUTE_ISO_BOTTOMLEFT :   strcat(tempString, "EXECUTE ISO BOTTOM LEFT");break;
        case EXECUTE_ISO_BOTTOMCENTER : strcat(tempString, "EXECUTE ISO BOTTOM CENTER");break;
        case EXECUTE_ISO_BOTTOMRIGHT :  strcat(tempString, "EXECUTE ISO BOTTOM RIGHT");break;
        case EXECUTE_ISO_LEFTTOP :      strcat(tempString, "EXECUTE ISO LEFT TOP");break;
        case EXECUTE_ISO_LEFTCENTER :   strcat(tempString, "EXECUTE ISO LEFT CENTER");break;
        case EXECUTE_ISO_LEFTBOTTOM :   strcat(tempString, "EXECUTE ISO LEFT BOTTOM");break;
        case EXECUTE_ISO_RIGHTTOP :     strcat(tempString, "EXECUTE ISO RIGHT TOP");break;
        case EXECUTE_ISO_RIGHTCENTER :  strcat(tempString, "EXECUTE ISO RIGHT CENTER");break;
        case EXECUTE_ISO_RIGHTBOTTOM :  strcat(tempString, "EXECUTE ISO RIGHT BOTTOM");break;
      }

      PrintLine(tempString);
  
      sprintf(tempString, "  String Number : %d", (int)pRecord->StringNumber);
      PrintLine(tempString);
      sprintf(tempString, "  String : %s", pRecord->String);
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify Get ISO String (Invalid data packet)");
   }
}

void HandleGetAuthorsPrint(void *pData)
{
   struct NotifyGetAuthors *pRecord;
   char   tempString[MAX_STRING];
   int    i;

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Get Authors : Number Authors %ld", pRecord->NumberAuthors);
      PrintLine(tempString);

      for(i=0; i < pRecord->NumberAuthors; i++){
         sprintf(tempString, "%2d. %s  : ", i + 1, pRecord->Authors[i].AuthorName);

         if(pRecord->Authors[i].bSelect){
            strcat(tempString, "Selected");
         }
         else{
            strcat(tempString, "Not Selected");
         }

         PrintLine(tempString);
      }
   }else{
      PrintLine(">>> Notify Get Authors (Invalid data packet)");
   }
}

void HandleNotifyUDMenuPrint(void *pData)
{
   struct NotifyUDMenu *pRecord;
   char   tempString[MAX_STRING];
   char   idstring[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify User-Defined Menu : ");
      strcat(tempString, pRecord->Text);
      strcat(tempString, " - ID: ");
      sprintf(idstring, "%d", pRecord->MenuID);
      strcat(tempString, idstring);
      
      PrintLine(tempString);
   }else{
      PrintLine(">>> Notify User-Defined Menu (Invalid data packet)");
   }
}

void HandleChangemarkViewedPrint(void *pData)
{
   pNotifyChangemarkViewed pRecord;
   char                    tempString[MAX_STRING];

   if ((pRecord = pData) != NULL) {
      sprintf(tempString, ">>> Changemark Viewed: ");
      strcat(tempString, pRecord->ChangemarkTitle);
      PrintLine(tempString);

      sprintf(tempString, "Parent Filename: ");
      strcat(tempString, pRecord->Filename);
      PrintLine(tempString);
   }
}

void HandleGetChangemarksPrint(void *pData)
{
   pNotifyGetChangemarks pRecord;
   char                  tempString[MAX_STRING];
   int                   i;

   if ((pRecord = pData) != NULL) {
      sprintf(tempString, ">>> Get Changemarks: %ld Changemarks", pRecord->NumberChangemarks);
      PrintLine(tempString);

      for(i=0; i < pRecord->NumberChangemarks; i++){
         sprintf(tempString, "%3d. %s", i + 1, pRecord->Changemark[i].ChangemarkTitle);
         PrintLine(tempString);

         sprintf(tempString, "   %s", pRecord->Changemark[i].ChangemarkText);
         PrintLine(tempString);

         sprintf(tempString, "   Parent Filename: %s ", pRecord->Changemark[i].Filename);
         PrintLine(tempString);

         sprintf(tempString, "   Author: %s ", pRecord->Changemark[i].ChangemarkAuthor);
         PrintLine(tempString);

         sprintf(tempString, "   Changemark Layer Name: %s ", pRecord->Changemark[i].ChangemarkLayerName);
         PrintLine(tempString);

         sprintf(tempString, "   Changemark Layer is Visible: ");
        
         if(pRecord->Changemark[i].bChangemarkLayerVisible){
            strcat(tempString, "Yes");
         }
         else{
            strcat(tempString, "No");
         }

         PrintLine(tempString);
      }
   }
}

void HandleInquireDocumentPrint(void *pData)
{
   pNotifyInquireDocument pRecord;
   char                   tempString[MAX_STRING];
   pImageInfo             ptr;
   int                    i;


   if ((pRecord = pData) != NULL) {
      sprintf(tempString, ">>> Inquire Document Info: ");
      PrintLine(tempString);

      if (pRecord->MarkupFile[0] != '\0') {
         sprintf(tempString, "Markup file: %s", pRecord->MarkupFile);
         PrintLine(tempString);
         if (pRecord->MarkupChanged)
            sprintf(tempString, "Markup file has been changed");
         else
            sprintf(tempString, "Markup file has not been changed");
         PrintLine(tempString);
      }
      else {
         sprintf(tempString, "Markup file: None");
         PrintLine(tempString);
      }

      sprintf(tempString, "Description: %s", pRecord->Description);
      PrintLine(tempString);

      sprintf(tempString, "Current viewed area (clip): %lf, %lf, %lf, %lf", pRecord->Clip[0], 
                           pRecord->Clip[1], pRecord->Clip[2], pRecord->Clip[3]);
      PrintLine(tempString);

      sprintf(tempString, "Limits of the document: %lf, %lf, %lf, %lf", pRecord->Limits[0],
                           pRecord->Limits[1], pRecord->Limits[2], pRecord->Limits[3]);
      PrintLine(tempString);

      sprintf(tempString, "Document window size: %ld, %ld, %ld, %ld", pRecord->DocWindowSize[0],
         pRecord->DocWindowSize[1], pRecord->DocWindowSize[2], pRecord->DocWindowSize[3]);
      PrintLine(tempString);

      sprintf(tempString, "Document window position: %ld, %ld, %ld, %ld", pRecord->DocWindowPosition[0],
         pRecord->DocWindowPosition[1], pRecord->DocWindowPosition[2], pRecord->DocWindowPosition[3]);
      PrintLine(tempString);

     strcpy(tempString, "Document window state: ");

     switch(pRecord->DocWindowState.State){
        case WINDOW_MINIMIZED : strcat(tempString, "Minimized");break;
        case WINDOW_MAXIMIZED : strcat(tempString, "Maximized");break;
        case WINDOW_WINDOWED  : strcat(tempString, "Windowed");break;
     }

     PrintLine(tempString);

      sprintf(tempString, "Myriad window size: %ld, %ld, %ld, %ld", pRecord->MyrWindowSize[0],
         pRecord->MyrWindowSize[1], pRecord->MyrWindowSize[2], pRecord->MyrWindowSize[3]);
      PrintLine(tempString);

      sprintf(tempString, "Myriad window position: %ld, %ld, %ld, %ld", pRecord->MyrWindowPosition[0],
         pRecord->MyrWindowPosition[1], pRecord->MyrWindowPosition[2], pRecord->MyrWindowPosition[3]);
      PrintLine(tempString);

     strcpy(tempString, "Myriad window state: ");

     switch(pRecord->MyrWindowState.State){
        case WINDOW_MINIMIZED : strcat(tempString, "Minimized");break;
        case WINDOW_MAXIMIZED : strcat(tempString, "Maximized");break;
        case WINDOW_WINDOWED  : strcat(tempString, "Windowed");break;
     }

     PrintLine(tempString);

      sprintf(tempString, "Number of pages: %ld", pRecord->NumberOfPages);
      PrintLine(tempString);

      sprintf(tempString, "Active page: %ld", pRecord->ActivePage);
      PrintLine(tempString);

      sprintf(tempString, "Image type: ");
      switch (pRecord->ImageType.Type) {
         case MONOCHROME_RASTER: strcat(tempString, "Monochrome Raster"); break;
         case COLOR_RASTER: strcat(tempString, "Color Raster"); break;
      case VECTOR: strcat(tempString, "Vector"); break;
         case TEXT: strcat(tempString, "Text"); break;
      }
      PrintLine(tempString);

      sprintf(tempString, "Orientation: ");
      switch (pRecord->Orientation.Type) {
      case DEGREES_0: strcat(tempString, "0 Degrees"); break;
         case DEGREES_90: strcat(tempString, "90 Degrees"); break;
      case DEGREES_180: strcat(tempString, "180 Degrees"); break;
         case DEGREES_270: strcat(tempString, "270 Degrees"); break;
      }
      PrintLine(tempString);

      sprintf(tempString, "Resolution: %ld", pRecord->Resolution);
      PrintLine(tempString);

      sprintf(tempString, "Number of files: %ld", pRecord->NumberOfFiles);
      PrintLine(tempString);

      sprintf(tempString, "Files:");
      PrintLine(tempString);

      ptr = pRecord->ImageInfo;
   
      for (i = 0; i < pRecord->NumberOfFiles; i++) {
         sprintf(tempString, "Name:%s  World Scale:%lf", ptr->Filename, ptr->WorldScale);
         PrintLine(tempString);
         ptr++;
      }
         
   } else {
      PrintLine(">>> Notify Inquire Document (Invalid data packet)");
   }
}

// This routine converts the paper size enumeration to a string for display
char *GetPaperSizeString(ExecutePrintPaperSizeTypes paperSize, char *paperSizeString)
{
   paperSizeString[0] = 0;
  
   switch(paperSize){
      case EXECUTE_PRINT_SIZE_DEFAULT:                  strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_DEFAULT"); break;
      case EXECUTE_PRINT_SIZE_LETTER:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTER"); break;
      case EXECUTE_PRINT_SIZE_LEGAL:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LEGAL"); break;
      case EXECUTE_PRINT_SIZE_A4:                       strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A4"); break;
      case EXECUTE_PRINT_SIZE_CSHEET:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_CSHEET"); break;
      case EXECUTE_PRINT_SIZE_DSHEET:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_DSHEET"); break;
      case EXECUTE_PRINT_SIZE_ESHEET:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ESHEET"); break;
      case EXECUTE_PRINT_SIZE_LETTERSMALL:              strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTERSMALL"); break;
      case EXECUTE_PRINT_SIZE_TABLOID:                  strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_TABLOID"); break;
      case EXECUTE_PRINT_SIZE_LEDGER:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LEDGER"); break;
      case EXECUTE_PRINT_SIZE_STATEMENT:                strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_STATEMENT"); break;
      case EXECUTE_PRINT_SIZE_EXECUTIVE:                strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_EXECUTIVE"); break;
      case EXECUTE_PRINT_SIZE_A3:                       strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A3"); break;
      case EXECUTE_PRINT_SIZE_A4SMALL:                  strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A4SMALL"); break;
      case EXECUTE_PRINT_SIZE_A5:                       strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A5"); break;
      case EXECUTE_PRINT_SIZE_B4:                       strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_B4"); break;
      case EXECUTE_PRINT_SIZE_FOLIO:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_FOLIO"); break;
      case EXECUTE_PRINT_SIZE_QUARTO:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_QUARTO"); break;
      case EXECUTE_PRINT_SIZE_10X14:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_10X14"); break;
      case EXECUTE_PRINT_SIZE_11X17:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_11X17"); break;
      case EXECUTE_PRINT_SIZE_NOTE:                     strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_NOTE"); break;
      case EXECUTE_PRINT_SIZE_ENV9:                     strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV9"); break;
      case EXECUTE_PRINT_SIZE_ENV10:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV10"); break;
      case EXECUTE_PRINT_SIZE_ENV11:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV11"); break;
      case EXECUTE_PRINT_SIZE_ENV12:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV12"); break;
      case EXECUTE_PRINT_SIZE_ENV14:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV14"); break;
      case EXECUTE_PRINT_SIZE_ENVDL:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVDL"); break;
      case EXECUTE_PRINT_SIZE_ENVC3:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVC3"); break;
      case EXECUTE_PRINT_SIZE_ENVC4:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVC4"); break;
      case EXECUTE_PRINT_SIZE_ENVC5:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVC5"); break;
      case EXECUTE_PRINT_SIZE_ENVC6:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVC6"); break;
      case EXECUTE_PRINT_SIZE_ENVC65:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVC65"); break;
      case EXECUTE_PRINT_SIZE_ENVB4:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVB4"); break;
      case EXECUTE_PRINT_SIZE_ENVB5:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVB5"); break;
      case EXECUTE_PRINT_SIZE_ENVB6:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVB6"); break;
      case EXECUTE_PRINT_SIZE_ENVITALY:                 strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVITALY"); break;
      case EXECUTE_PRINT_SIZE_ENVMONARCH:               strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVMONARCH"); break;
      case EXECUTE_PRINT_SIZE_ENVPERSONAL:              strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENVPERSONAL"); break;
      case EXECUTE_PRINT_SIZE_FANFOLD_US:               strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_FANFOLD_US"); break;
      case EXECUTE_PRINT_SIZE_FANFOLD_STDGERMAN:        strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_FANFOLD_STDGERMAN"); break;
      case EXECUTE_PRINT_SIZE_FANFOLD_LGLGERMAN:        strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_FANFOLD_LGLGERMAN"); break;
      case EXECUTE_PRINT_SIZE_ISOB4:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ISOB4"); break;
      case EXECUTE_PRINT_SIZE_JAPANESE_POSTCARD:        strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_JAPANESE_POSTCARD"); break;
      case EXECUTE_PRINT_SIZE_9X11:                     strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_9X11"); break;
      case EXECUTE_PRINT_SIZE_10X11:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_10X11"); break;
      case EXECUTE_PRINT_SIZE_15X11:                    strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_15X11"); break;
      case EXECUTE_PRINT_SIZE_ENV_INVITE:               strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_ENV_INVITE"); break;
      case EXECUTE_PRINT_SIZE_LETTER_EXTRA:             strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTER_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_LEGAL_EXTRA:              strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LEGAL_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_TABLOID_EXTRA:            strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_TABLOID_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_A4_EXTRA:                 strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A4_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_LETTER_TRANSVERSE:        strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTER_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_A3_TRANSVERSE:            strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A3_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_A3_EXTRA_TRANSVERSE:      strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A3_EXTRA_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_A4_TRANSVERSE:            strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A4_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_LETTER_EXTRA_TRANSVERSE:  strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTER_EXTRA_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_A5_TRANSVERSE:            strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A5_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_B5_TRANSVERSE:            strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_B5_TRANSVERSE"); break;
      case EXECUTE_PRINT_SIZE_A_PLUS:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A_PLUS"); break;
      case EXECUTE_PRINT_SIZE_B_PLUS:                   strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_B_PLUS"); break;
      case EXECUTE_PRINT_SIZE_LETTER_PLUS:              strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_LETTER_PLUS"); break;
      case EXECUTE_PRINT_SIZE_A4_PLUS:                  strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A4_PLUS"); break;
      case EXECUTE_PRINT_SIZE_A3_EXTRA:                 strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A3_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_A5_EXTRA:                 strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A5_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_B5_EXTRA:                 strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_B5_EXTRA"); break;
      case EXECUTE_PRINT_SIZE_A2:                       strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_A2"); break;
      case EXECUTE_PRINT_SIZE_USER:                     strcpy(paperSizeString, "EXECUTE_PRINT_SIZE_USER"); break;
      default :                                         strcpy(paperSizeString, "Unknown"); break;
   }  

   return(paperSizeString);
}

void HandleInquireSystemPrint(void *pData)
{
   pNotifyInquireSystem         pRecord;
   pNotifyDocumentStackDocument pDoc;
   pNotifyDocumentStackImage    pImage;
   char                         tempString[MAX_STRING];
   char                         imageType[MAX_STRING];
   char                         paperSize[MAX_STRING];
   int                          docNumber;
   int                          imageNumber;
   char                         *pBuffer=NULL;

   if((pRecord = pData) != NULL) {
      sprintf(tempString, ">>> Inquire System Info: ");
      PrintLine(tempString);

      sprintf(tempString, "Product Version: %ld.%ld.%ld.%ld", pRecord->Version.Major, pRecord->Version.Minor1, pRecord->Version.Minor2, pRecord->Version.Build);
      PrintLine(tempString);

      sprintf(tempString, "Current Author Name: %s", pRecord->CurrentAuthor);
      PrintLine(tempString);

     strcpy(tempString, "Myriad window state: ");

     switch(pRecord->MyrWindowState.State){
        case WINDOW_MINIMIZED : strcat(tempString, "Minimized");break;
        case WINDOW_MAXIMIZED : strcat(tempString, "Maximized");break;
        case WINDOW_WINDOWED  : strcat(tempString, "Windowed");break;
     }

      PrintLine(tempString);
      
      PrintLine("Print Settings:");

      sprintf(tempString, "Printer Name: %s", pRecord->PrintSettings.PrinterName);
      PrintLine(tempString);

      sprintf(tempString, "Paper Size: %s", GetPaperSizeString(pRecord->PrintSettings.PaperSize, paperSize));
      PrintLine(tempString);

      sprintf(tempString, "Copies: %ld", pRecord->PrintSettings.Copies);
      PrintLine(tempString);

      sprintf(tempString, "Scale Type: ");

      switch (pRecord->PrintSettings.ScaleType) {
        case EXECUTE_PRINT_SCALE_PAGE     : strcat(tempString, "Scale To Page"); break;
        case EXECUTE_PRINT_SCALE_TO_SCALE : strcat(tempString, "Print To Scale"); break;
      }

      PrintLine(tempString);

      sprintf(tempString, "Scale Percentage: %lf", pRecord->PrintSettings.ScalePercent);
      PrintLine(tempString);

     strcpy(tempString, "Generate Bitmap: ");

     if(pRecord->PrintSettings.bGenerateBitmap){
        strcat(tempString, "TRUE");
     }else{
        strcat(tempString, "FALSE");
     }

      PrintLine(tempString);

     strcpy(tempString, "Black and White: ");

     if(pRecord->PrintSettings.bBlackAndWhite){
        strcat(tempString, "TRUE");
     }else{
        strcat(tempString, "FALSE");
     }

      PrintLine(tempString);

     strcpy(tempString, "Outline Fills: ");

     if(pRecord->PrintSettings.bOutlineFills){
        strcat(tempString, "TRUE");
     }else{
        strcat(tempString, "FALSE");
     }

      PrintLine(tempString);

      sprintf(tempString, "Orientation: ");

      switch (pRecord->PrintSettings.Orientation) {
        case EXECUTE_PRINT_ORIENT_PORTRAIT  : strcat(tempString, "Portrait"); break;
        case EXECUTE_PRINT_ORIENT_LANDSCAPE : strcat(tempString, "Landscape"); break;
      }

      PrintLine(tempString);

      sprintf(tempString, "Print What: ");

      switch (pRecord->PrintSettings.PrintWhat) {
        case EXECUTE_PRINT_DOCUMENT : strcat(tempString, "Document"); break;
        case EXECUTE_PRINT_NOTES    : strcat(tempString, "Notes"); break;
      }

      PrintLine(tempString);

      sprintf(tempString, "Print Range: ");

      switch (pRecord->PrintSettings.PrintRange) {
        case EXECUTE_PRINT_RANGE_ALL     : strcat(tempString, "All"); break;
        case EXECUTE_PRINT_RANGE_PAGES   : strcat(tempString, "Pages"); break;
        case EXECUTE_PRINT_RANGE_CURRENT : strcat(tempString, "Current Page"); break;
      }

      PrintLine(tempString);

      sprintf(tempString, "From Page: %ld", pRecord->PrintSettings.FromPage);
      PrintLine(tempString);

      sprintf(tempString, "To Page: %ld", pRecord->PrintSettings.ToPage);
      PrintLine(tempString);

      PrintLine("Document Stack Information:");

      sprintf(tempString, "Number of documents in Document Stack: %ld", pRecord->NumberDocumentsInStack);
      PrintLine(tempString);

      pBuffer = (char*)&pRecord->DocumentInfo;

      for(docNumber=0; docNumber < pRecord->NumberDocumentsInStack; docNumber++){
         pDoc = (pNotifyDocumentStackDocument)pBuffer;
         pBuffer += sizeof(*pDoc);

         sprintf(tempString, "%d) %-45s : Number Images %ld", docNumber + 1, pDoc->DocumentName, pDoc->NumberImages);
         PrintLine(tempString);

         for(imageNumber=0; imageNumber < pDoc->NumberImages; imageNumber++){
            pImage = (pNotifyDocumentStackImage)pBuffer;
            pBuffer += sizeof(*pImage);

            switch(pImage->FileType){
               case DOCUMENT_MAIN_IMAGE       : strcpy(imageType, "Main Image");break;
               case DOCUMENT_READONLY_OVERLAY : strcpy(imageType, "Read-Only Overlay");break;
               case DOCUMENT_EDITABLE_MARKUP  : strcpy(imageType, "Editable Markup");break;
               default : strcpy(imageType, "Unknown");break;
            }

            sprintf(tempString, "       %d. %-38s : %s", imageNumber + 1, pImage->FileName, imageType);
            PrintLine(tempString);
         }
      }
   }
}

void HandleRunSilentMsgPrint(void *pData)
{
   pNotifyRunSilentMessage             pRecord;
   struct NotifyRunSilentMessageReturn ReturnData;
   char                                tempString[MAX_STRING];

   if ((pRecord = pData) != NULL) {
      sprintf(tempString, ">>> Run Silent Message: ");
      PrintLine(tempString);

      sprintf(tempString, "Caption: %s", pRecord->Caption);
      PrintLine(tempString);

      sprintf(tempString, "Text: %s", pRecord->Text);
      PrintLine(tempString);

      sprintf(tempString, "Style: %ld", (long)pRecord->Style);
      PrintLine(tempString);
   
      // Just tell Myriad to put up the default message box
      ReturnData.Header.ReplyMessage = INTG_NOTIFY_RUN_SILENT_MSG;
      ReturnData.bDisplayMessage     = TRUE;
      ReturnData.Result              = 0;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   } else {
      PrintLine(">>> Notify Run Silent (Invalid data packet)");
   }
}

void HandleISOEditPrint(void *pData)
{
   PrintLine(">>> Notify ISO Edit received.");
}

void HandleISOLookupPrint(void *pData)
{
   struct NotifyDatabaseISOLookup *pRecord;
   struct NotifyDatabaseISOLookupReturn ReturnData;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Database ISO Lookup : %s : %s", 
         pRecord->Filename, pRecord->Lookupstring);

      PrintLine(tempString);

      ReturnData.Header.ReplyMessage = INTG_NOTIFY_DATABASE_ISO_LOOKUP;
      strcpy(ReturnData.Returnstring,"Lookup String");

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
         PrintLine("-->Notification returned successfully.");
      }else{
         PrintLine("-->Notification returned failure.");
      }
   }else{
      PrintLine(">>> Notify Database ISO Lookup (Invalid data packet)");
   }
}

void HandleIntegrationEnabledPrint(void *pData)
{
   struct NotifyIntegrationEnabled *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      sprintf(tempString, ">>> Notify Integration Enabled : "); 

      if(pRecord->bIntegrationEnabled){
         strcat(tempString, "TRUE");
      }
      else{
         strcat(tempString, "FALSE");
      }

      PrintLine(tempString);

   }else{
      PrintLine(">>> Notify Integration Enabled (Invalid data packet)");
   }
}

void HandleISODisplayPrint(void *pData)
{
   struct NotifyISODisplayReturn ReturnData;

   PrintLine(">>> Notify ISO Display received.");

   ReturnData.Header.ReplyMessage = INTG_NOTIFY_ISO_DISPLAY;
   ReturnData.bOKToDisplay        = TRUE;

   if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData)){
      PrintLine("-->Notification returned successfully.");
   }else{
      PrintLine("-->Notification returned failure.");
   }
}

void HandleModelLoaded(void *pData)
{
   pNotify3DModelLoaded pRecord;
   char tempString[MAX_STRING];
   int  i;

   if((pRecord = pData) != NULL){
      PrintLine(">>> Notify Model Loaded received.");

      // Print out the information for the model root entry
      sprintf(tempString, "Model ID: %ld", pRecord->EntityID);
      PrintLine(tempString);
        
      sprintf(tempString, "Model Filename: %s", pRecord->Filename);
      PrintLine(tempString);
        
      sprintf(tempString, "Number Entities: %ld", pRecord->NumberModelEntities);
      PrintLine(tempString);

      // Print out all the children
      for(i=0; i < pRecord->NumberModelEntities; i++){
         // Print out each child. Note that the children for an entity immediately follow
         // the entity in the ModelEntities array.
         sprintf(tempString, "   Entity ID: %ld", pRecord->ModelEntities[i].EntityID);
         PrintLine(tempString);

         sprintf(tempString, "   Entity Name: %s", pRecord->ModelEntities[i].EntityName);
         PrintLine(tempString);
         
         sprintf(tempString, "   Number Children: %ld", pRecord->ModelEntities[i].NumberChildren);
         PrintLine(tempString);

         if(pRecord->ModelEntities[i].ContainsGeometry){
            sprintf(tempString, "   Contains Geometry: Yes");
         }
         else{
            sprintf(tempString, "   Contains Geometry: No");
         }

         PrintLine(tempString);
      }
   }
}

void HandleComponentSelectionChanged(void *pData)
{
   pNotify3DComponentSelectionChanged pRecord;
   char tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      PrintLine(">>> Notify Component Selection Change received.");

      // Print out the information for the model root entry
      sprintf(tempString, "Entity ID: %ld", pRecord->EntityID);
      PrintLine(tempString);
        
      sprintf(tempString, "Entity Name: %s", pRecord->EntityName);
      PrintLine(tempString);
        
      if(pRecord->ContainsGeometry){
         sprintf(tempString, "   Contains Geometry: Yes");
      }
      else{
         sprintf(tempString, "   Contains Geometry: No");
      }

      PrintLine(tempString);
        
      if(pRecord->Selected){
         sprintf(tempString, "   Selected: Yes");
      }
      else{
         sprintf(tempString, "   Selected: No");
      }

      PrintLine(tempString);
        
      if(pRecord->GeometryVisible){
         sprintf(tempString, "   Geometry Visible: Yes");
      }
      else{
         sprintf(tempString, "   Geometry Visible: No");
      }

      PrintLine(tempString);
   }
}

void HandleComponentListEnabled(void *pData)
{
   pNotify3DComponentListEnabled pRecord;
   char tempString[MAX_STRING];

   if((pRecord = pData) != NULL){
      PrintLine(">>> Notify Component List Enabled received.");

      // Print out the information for the model root entry
      sprintf(tempString, "Model ID: %ld", pRecord->EntityID);
      PrintLine(tempString);
        
      sprintf(tempString, "Model Filename: %s", pRecord->Filename);
      PrintLine(tempString);
   }
}

void HandleMVSViewCreated(void *pData)
{
   struct NotifyMVSViewCreated *pRecord;
   char   tempString[MAX_STRING];

   if((pRecord = pData) != NULL)
   {
      sprintf(tempString, ">>> Notify MVS View Created : ");
      PrintLine(tempString);

      sprintf(tempString, "Sourcename: %s", pRecord->Sourcename);
      PrintLine(tempString);

      sprintf(tempString, "Viewname: %s", pRecord->Viewname);
      PrintLine(tempString);

      sprintf(tempString, "ViewType: ");

      switch(pRecord->ViewType)
      {
        case NOTIFY_MVS_VIEW_STANDARD: strcat(tempString, "NOTIFY_MVS_VIEW_STANDARD");break;
        case NOTIFY_MVS_VIEW_MARKUP:   strcat(tempString, "NOTIFY_MVS_VIEW_MARKUP");break;
        default : strcat(tempString, "INVALID VIEW TYPE GIVEN");break;
      }

      PrintLine(tempString);
   }else
   {
      PrintLine(">>> Notify MVS View Created (Invalid data packet)");
   }
}

void Handle3DViewSetLoadedCreated(void *pData)
{
   pNotify3DViewSetLoaded pRecord;
   char tempString[MAX_STRING];
   int  i;

   if((pRecord = pData) != NULL)
   {
      PrintLine(">>> Notify 3D View Set Loaded received.");

      // Print out the information about the view set
      sprintf(tempString, "Model Filename: %s", pRecord->ModelFilename);
      PrintLine(tempString);
        
      sprintf(tempString, "MVS Filename: %s", pRecord->MVSFilename);
      PrintLine(tempString);
        
      sprintf(tempString, "Number Views: %ld", pRecord->NumberViewEntities);
      PrintLine(tempString);

      // Print out all the children
      for(i=0; i < pRecord->NumberViewEntities; i++)
      {
         // Print out the child view information
         sprintf(tempString, "   View Name: %s", pRecord->ViewSetEntities[i].ViewName);
         PrintLine(tempString);

         strcpy(tempString, "   View Type: ");

         switch((NotifyMVSViewTypes)pRecord->ViewSetEntities[i].ViewType)
         {
            case NOTIFY_MVS_VIEW_STANDARD:
            {
               strcat(tempString, "Standard");
            }
            break;
            case NOTIFY_MVS_VIEW_MARKUP:
            {
               strcat(tempString, "Markup");
            }
            break;
         }

         PrintLine(tempString);
      }
   }
}

void HandleViewSetNeedsSaving(void *pData)
{
   struct NotifyViewSetNeedsSavingRequest *pRecord;
   struct NotifyViewSetNeedsSavingReturn ReturnData;
   char tempString[MAX_STRING];

   if((pRecord = pData) != NULL)
   {
      PrintLine(">>> Notify View Set Needs Saving received.");

      // Print out the information about the view set
      sprintf(tempString, "Model Filename: %s", pRecord->ModelFilename);
      PrintLine(tempString);
        
      sprintf(tempString, "MVS Filename: %s", pRecord->MVSFilename);
      PrintLine(tempString);
        
      sprintf(tempString, "MVS Markup Filename: %s", pRecord->MVSMarkupFilename);
      PrintLine(tempString);
        
      sprintf(tempString, "Number Standard Views: %ld", pRecord->NumberStandardViews);
      PrintLine(tempString);
        
      sprintf(tempString, "Number Markup Views: %ld", pRecord->NumberMarkupViews);
      PrintLine(tempString);

      // Set up the reply
      ReturnData.Header.ReplyMessage = INTG_NOTIFY_VIEW_SET_NEEDS_SAVING;

      if(pRecord->MVSFilename[0] != 0)
      {
         strcpy(ReturnData.MVSFilename, pRecord->MVSFilename);
      }
      else
      {
         strcpy(ReturnData.MVSFilename, "c:\\test.mvs");
      }

      if(pRecord->MVSMarkupFilename[0] != 0)
      {
         strcpy(ReturnData.MVSMarkupFilename, pRecord->MVSMarkupFilename);
      }
      else
      {
         strcpy(ReturnData.MVSMarkupFilename, "c:\\test.mrk");
      }
   
      ReturnData.bPerformMVSSave = TRUE;
      ReturnData.bPerformMarkupSave = TRUE;
      ReturnData.bUpdateAllModifiedViews = TRUE;

      if(ProcessExecutionCommand(INTG_EXECUTE_NOTIFY_RETURN, &ReturnData))
      {
         PrintLine("-->Notification returned successfully.");
      }else
      {
         PrintLine("-->Notification returned failure.");
      }
   }else
   {
      PrintLine(">>>Invalid View Set Needs Saving Notification received.");
   }
}

// Callback handler for notification messages sent from Myriad.
void NotifyCallbackHandler(struct NotifyCallbackRecord *pCallbackRecord)
{
   char tempString[MAX_STRING];

   switch(pCallbackRecord->DataStatus){
      case INTG_STATUS_COMPLETE_DATA:{
         if(bOkToDisplay)PrintLine(">>> (Message status : COMPLETE DATA)");
      }
      break;
      case INTG_STATUS_PARTIAL_DATA:{
         PrintLine(">>> (Message status : PARTIAL DATA)");
      }
      break;
      case INTG_STATUS_NO_DATA:{
         PrintLine(">>> (Message status : NO DATA)");
      }
      break;
      case INTG_STATUS_REPLY_REQUESTED:{
         PrintLine(">>> (Message status : REPLY REQUESTED)");
      }
      break;
   }

   switch(pCallbackRecord->Message){
      case INTG_NOTIFY_EXECUTION_RETURN:{
         HandleExecutionReturnPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_EXIT:{
         HandleExitPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_MOUSEMOVE:{
         HandleMouseMovePrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_LBUTTONDOWN:{
         HandleLButtonDownPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_LBUTTONUP:{
         HandleLButtonUpPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_LBUTTONDBLCLICK:{
         HandleLButtonDblClickPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LOAD_FILEBEGIN:{
         HandleLoadFileBeginPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LOAD_BLOCKBEGIN:{
         HandleLoadBlockBeginPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LOAD_ATTRIBUTE:{
         HandleLoadAttributePrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LOAD_BLOCKEND:{
         HandleLoadBlockEndPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LOAD_FILEEND:{
         HandleLoadFileEndPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_DISPLAY_FILEBEGIN:{
         HandleDisplayFileBeginPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_DISPLAY_BLOCKBEGIN:{
         HandleDisplayBlockBeginPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_DISPLAY_ATTRIBUTE:{
         HandleDisplayAttributePrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_DISPLAY_BLOCKEND:{
         HandleDisplayBlockEndPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_DISPLAY_FILEEND:{
         HandleDisplayFileEndPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_LAUNCH_ATTRIBBLOCK:{
         HandleLaunchAttribBlockPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_SET_RETURN_DATA:{
         HandleSetReturnDataPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_FILE_LOADED:{
         HandleFileLoadedPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_VIEWPORT_CLOSE:{
         HandleViewportClosePrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_NEW_MARKUP:{
         HandleNewMarkupPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_OPEN_MARKUP:{
         HandleOpenMarkupPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_SAVE_MARKUP:{
         HandleSaveMarkupPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_MARKUP_SAVED:{
         HandleMarkupSavedPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_MVS_SAVED:{
         HandleMVSSavedPrint(&pCallbackRecord->Data);
      }
      break;      

      case INTG_NOTIFY_CLOSE_MARKUP:{
         HandleCloseMarkupPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_IMAGE_CHANGE:{
         HandleImageChangePrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_GET_LAYER_INFO:{
         HandleGetLayerInfoPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_GET_ISO_STRING:{
         HandleGetISOStringPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_DATABASE_LOOKUP:{
         HandleDatabaseLookupPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_PRINT:{
         HandleNotifyPrintPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_PRINT_COMPLETE:{
         HandleNotifyPrintPrintComplete(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_UD_MENU:{
         HandleNotifyUDMenuPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_DOCUMENT_INFO: {
         HandleInquireDocumentPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_SYSTEM_INFO: {
         HandleInquireSystemPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_OPEN_MARKUP_REQUEST:{
         HandleOpenMarkupRequestPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_OPEN_MVS_REQUEST:{
         HandleOpenMVSRequestPrint(&pCallbackRecord->Data);
      }
      break;      

      case INTG_NOTIFY_SAVEAS_MARKUP_REQUEST:{
         HandleSaveAsMarkupRequestPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_SAVEAS_MVS_REQUEST:{
         HandleSaveAsMVSRequestPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_GET_AUTHORS:{
         HandleGetAuthorsPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_CHANGEMARK_VIEWED:{
         HandleChangemarkViewedPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_GET_CHANGEMARKS:{
         HandleGetChangemarksPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_RUN_SILENT_MSG:{
         HandleRunSilentMsgPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_ISO_DISPLAY:{
         HandleISODisplayPrint(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_ISO_EDIT:{
         HandleISOEditPrint(&pCallbackRecord->Data);
      }
      break;
      
      case INTG_NOTIFY_DATABASE_ISO_LOOKUP:{
         HandleISOLookupPrint(&pCallbackRecord->Data);
      }
      break;
      
      case INTG_NOTIFY_INTEGRATION_ENABLED:{
         HandleIntegrationEnabledPrint(&pCallbackRecord->Data);
      }
      break;
      
      case INTG_NOTIFY_3D_MODEL_LOADED:{
         HandleModelLoaded(&pCallbackRecord->Data);
      }
      break;
      
      case INTG_NOTIFY_3D_COMPONENT_SELECTION_CHANGED:{
         HandleComponentSelectionChanged(&pCallbackRecord->Data);
      }
      break;
      
      case INTG_NOTIFY_3D_COMPONENT_LIST_ENABLED:{
         HandleComponentListEnabled(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_MVS_VIEW_CREATED:{
         HandleMVSViewCreated(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_VIEW_SET_FILE_LOADED:{
         Handle3DViewSetLoadedCreated(&pCallbackRecord->Data);
      }
      break;

      case INTG_NOTIFY_VIEW_SET_NEEDS_SAVING:{
         HandleViewSetNeedsSaving(&pCallbackRecord->Data);
      }
      break;

      default:{
         sprintf(tempString, ">>> Received unhandled notify message %d", (int)pCallbackRecord->Message);
         PrintLine(tempString);
      }
      break;
   }

   if(bOkToDisplay)PrintBlankLine();
}